@@ -1,18 +1,17 @@
 #
-# Cookbook Name:: webapp
+# Cookbook:: base
 # Recipe:: default
 #
-# Copyright (C) 2014
+# Copyright:: 2014-2017, Chef Software, Inc.
 #
 
 hostname "chef-travis-ci.chef.io"
 
-if node["platform_family"] == "debian"
-  include_recipe "ubuntu"
-  apt_update "packages"
-end
+apt_update
 
-if %w{rhel fedora}.include?(node["platform_family"])
+include_recipe "ubuntu" if platform?("ubuntu")
+
+if platform_family?("rhel", "fedora", "amazon")
   include_recipe "selinux::disabled"
 end
 
@@ -23,18 +22,21 @@ yum_repository "epel" do
   gpgkey "https://dl.fedoraproject.org/pub/epel/RPM-GPG-KEY-EPEL-#{node['platform_version'].to_i}"
   gpgcheck true
   mirrorlist "https://mirrors.fedoraproject.org/metalink?repo=epel-#{node['platform_version'].to_i}&arch=$basearch"
-  only_if { node["platform_family"] == "rhel" }
+  only_if { platform_family?("rhel") }
 end
 
 include_recipe "build-essential"
 
-include_recipe "#{cookbook_name}::packages"
+include_recipe "::packages"
 
 include_recipe "ntp"
 
 include_recipe "resolver"
 
-include_recipe "users::sysadmins"
+users_manage "sysadmin" do
+  group_id 2300
+  action [:create]
+end
 
 include_recipe "sudo"
 
@@ -42,6 +44,9 @@ include_recipe "chef-client::delete_validation"
 include_recipe "chef-client::config"
 include_recipe "chef-client"
 
+include_recipe "chef-apt-docker"
+include_recipe "chef-yum-docker"
+
 # hack needed for debian-7 on docker
 directory "/var/run/sshd"
 
@@ -50,3 +55,9 @@ include_recipe "openssh"
 include_recipe "nscd"
 
 include_recipe "logrotate"
+
+include_recipe "cron"
+
+include_recipe "git"
+
+include_recipe "::tests"
