@@ -132,7 +132,7 @@ class Chef::Application::Knife < Chef::Application
   option :listen,
     :long           => "--[no-]listen",
     :description    => "Whether a local mode (-z) server binds to a port",
-    :boolean        => true
+    :boolean        => false
 
   option :version,
     :short        => "-v",
@@ -148,6 +148,10 @@ class Chef::Application::Knife < Chef::Application
     :boolean      => true,
     :default      => nil
 
+  option :profile,
+    :long         => "--profile PROFILE",
+    :description  => "The credentials profile to select"
+
   # Run knife
   def run
     Mixlib::Log::Formatter.show_time = false
@@ -203,11 +207,11 @@ class Chef::Application::Knife < Chef::Application
     Chef::Log.error(fatal_message) if fatal_message
 
     begin
-      self.parse_options
+      parse_options
     rescue OptionParser::InvalidOption => e
       puts "#{e}\n"
     end
-    puts self.opt_parser
+    puts opt_parser
     puts
     Chef::Knife.list_commands
     exit exitcode
