@@ -23,7 +23,6 @@ require "chef/client"
 require "chef/config"
 require "chef/daemon"
 require "chef/log"
-require "chef/rest"
 require "chef/config_fetcher"
 require "fileutils"
 require "chef/mixin/shell_out"
@@ -166,7 +165,7 @@ class Chef::Application::Solo < Chef::Application
     :short        => "-o RunlistItem,RunlistItem...",
     :long         => "--override-runlist RunlistItem,RunlistItem...",
     :description  => "Replace current run list with specified items",
-    :proc         => lambda {|items|
+    :proc         => lambda { |items|
       items = items.split(",")
       items.compact.map do |item|
         Chef::RunList::RunListItem.new(item)
@@ -258,6 +257,7 @@ class Chef::Application::Solo < Chef::Application
       end
 
       Chef::Config[:local_mode] = true
+      Chef::Config[:listen] = false
     else
       configure_legacy_mode!
     end
