@@ -12,7 +12,7 @@ class Chef
         end
 
         def preserve_key?(key)
-          return key == "containername"
+          key == "containername"
         end
 
         # Verify that the JSON hash for this type has a key that matches its name.
