@@ -19,7 +19,7 @@ class Chef
         end
 
         def preserve_key?(key)
-          return key == "name"
+          key == "name"
         end
 
         # There is no chef_class for users, nor does to_ruby work.
