@@ -137,7 +137,7 @@ class Chef
     alias :key? :has_key?
 
     def each
-      @cookbooks_by_name.keys.sort { |a, b| a.to_s <=> b.to_s }.each do |cname|
+      @cookbooks_by_name.keys.sort_by(&:to_s).each do |cname|
         yield(cname, @cookbooks_by_name[cname])
       end
     end
