@@ -1,6 +1,6 @@
 #--
 # Author:: Daniel DeLeo (<dan@chef.io>)
-# Copyright:: Copyright 2012-2016, Chef Software, Inc.
+# Copyright:: Copyright 2012-2017, Chef Software Inc.
 # License:: Apache License, Version 2.0
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -17,6 +17,7 @@
 #
 
 require "chef/node/common_api"
+require "chef/node/mixin/state_tracking"
 
 class Chef
   class Node
@@ -33,7 +34,6 @@ class Chef
         :compact!,
         :default=,
         :default_proc=,
-        :delete,
         :delete_at,
         :delete_if,
         :fill,
@@ -63,16 +63,19 @@ class Chef
       MUTATOR_METHODS.each do |mutator|
         define_method(mutator) do |*args, &block|
           ret = super(*args, &block)
-          root.reset_cache(root.top_level_breadcrumb)
+          send_reset_cache
           ret
         end
       end
 
-      attr_reader :root
+      def delete(key, &block)
+        send_reset_cache(__path__, key)
+        super
+      end
 
-      def initialize(root, data)
-        @root = root
+      def initialize(data = [])
         super(data)
+        map! { |e| convert_value(e) }
       end
 
       # For elements like Fixnums, true, nil...
@@ -86,6 +89,29 @@ class Chef
         Array.new(map { |e| safe_dup(e) })
       end
 
+      private
+
+      def convert_value(value)
+        case value
+        when VividMash
+          value
+        when AttrArray
+          value
+        when Hash
+          VividMash.new(value, __root__, __node__, __precedence__)
+        when Array
+          AttrArray.new(value, __root__, __node__, __precedence__)
+        else
+          value
+        end
+      end
+
+      # needed for __path__
+      def convert_key(key)
+        key
+      end
+
+      prepend Chef::Node::Mixin::StateTracking
     end
 
     # == VividMash
@@ -99,8 +125,6 @@ class Chef
     #   #fetch, work as normal).
     # * attr_accessor style element set and get are supported via method_missing
     class VividMash < Mash
-      attr_reader :root
-
       include CommonAPI
 
       # Methods that mutate a VividMash. Each of them is overridden so that it
@@ -108,7 +132,6 @@ class Chef
       # object.
       MUTATOR_METHODS = [
         :clear,
-        :delete,
         :delete_if,
         :keep_if,
         :merge!,
@@ -122,23 +145,27 @@ class Chef
       # For all of the mutating methods on Mash, override them so that they
       # also invalidate the cached `merged_attributes` on the root Attribute
       # object.
+
+      def delete(key, &block)
+        send_reset_cache(__path__, key)
+        super
+      end
+
       MUTATOR_METHODS.each do |mutator|
         define_method(mutator) do |*args, &block|
-          root.reset_cache(root.top_level_breadcrumb)
+          send_reset_cache
           super(*args, &block)
         end
       end
 
-      def initialize(root, data = {})
-        @root = root
+      def initialize(data = {})
         super(data)
       end
 
       def [](key)
-        root.top_level_breadcrumb ||= key
         value = super
         if !key?(key)
-          value = self.class.new(root)
+          value = self.class.new({}, __root__)
           self[key] = value
         else
           value
@@ -146,32 +173,13 @@ class Chef
       end
 
       def []=(key, value)
-        root.top_level_breadcrumb ||= key
         ret = super
-        root.reset_cache(root.top_level_breadcrumb)
+        send_reset_cache(__path__, key)
         ret
       end
 
       alias :attribute? :has_key?
 
-      def method_missing(symbol, *args)
-        # Calling `puts arg` implicitly calls #to_ary on `arg`. If `arg` does
-        # not implement #to_ary, ruby recognizes it as a single argument, and
-        # if it returns an Array, then ruby prints each element. If we don't
-        # account for that here, we'll auto-vivify a VividMash for the key
-        # :to_ary which creates an unwanted key and raises a TypeError.
-        if symbol == :to_ary
-          super
-        elsif args.empty?
-          self[symbol]
-        elsif symbol.to_s =~ /=$/
-          key_to_set = symbol.to_s[/^(.+)=$/, 1]
-          self[key_to_set] = (args.length == 1 ? args[0] : args)
-        else
-          raise NoMethodError, "Undefined node attribute or method `#{symbol}' on `node'. To set an attribute, use `#{symbol}=value' instead."
-        end
-      end
-
       def convert_key(key)
         super
       end
@@ -184,10 +192,12 @@ class Chef
         case value
         when VividMash
           value
+        when AttrArray
+          value
         when Hash
-          VividMash.new(root, value)
+          VividMash.new(value, __root__, __node__, __precedence__)
         when Array
-          AttrArray.new(root, value)
+          AttrArray.new(value, __root__, __node__, __precedence__)
         else
           value
         end
@@ -197,6 +207,7 @@ class Chef
         Mash.new(self)
       end
 
+      prepend Chef::Node::Mixin::StateTracking
     end
   end
 end
