@@ -51,7 +51,32 @@ class Chef
 
       class PolicyfileError < StandardError; end
 
-      RunListExpansionIsh = Struct.new(:recipes, :roles)
+      RunListExpansionIsh = Struct.new(:recipes, :roles) do
+        # Implementing the parts of the RunListExpansion
+        # interface we need to properly send this through to
+        # events.run_list_expanded as it is expecting a RunListExpansion
+        # object.
+        def to_hash
+          # It looks like version only gets populated in the expanded_run_list when
+          # using a little used feature of roles to version lock cookbooks, so
+          # version is not reliable in here anyway (places like Automate UI are
+          # not getting version out of here.
+          #
+          # Skipped will always be false as it can only be true when two expanded
+          # roles contain the same recipe.
+          expanded_run_list = recipes.map do |r|
+            { type: "recipe", name: r, skipped: false, version: nil }
+          end
+          data_collector_hash = {}
+          data_collector_hash[:id] = "_policy_node"
+          data_collector_hash[:run_list] = expanded_run_list
+          data_collector_hash
+        end
+
+        def to_json(*opts)
+          to_hash.to_json(*opts)
+        end
+      end
 
       attr_reader :events
       attr_reader :node
@@ -137,6 +162,7 @@ class Chef
         Chef::Log.info("Run List expands to [#{run_list_with_versions_for_display.join(', ')}]")
 
         events.node_load_completed(node, run_list_with_versions_for_display, Chef::Config)
+        events.run_list_expanded(run_list_expansion_ish)
 
         node
       rescue Exception => e
@@ -149,7 +175,7 @@ class Chef
       #
       # @return [Chef::RunContext]
       def setup_run_context(specific_recipes = nil)
-        Chef::Cookbook::FileVendor.fetch_from_remote(http_api)
+        Chef::Cookbook::FileVendor.fetch_from_remote(api_service)
         sync_cookbooks
         cookbook_collection = Chef::CookbookCollection.new(cookbooks_to_sync)
         cookbook_collection.validate!
@@ -173,6 +199,7 @@ class Chef
         CookbookCacheCleaner.instance.skip_removal = true if named_run_list_requested?
 
         node.run_list(run_list)
+        node.automatic_attrs[:policy_revision] = revision_id
         node.automatic_attrs[:roles] = []
         node.automatic_attrs[:recipes] = run_list_expansion_ish.recipes
         run_list_expansion_ish
@@ -266,7 +293,7 @@ class Chef
 
       # @api private
       def policy
-        @policy ||= http_api.get(policyfile_location)
+        @policy ||= api_service.get(policyfile_location)
       rescue Net::HTTPServerException => e
         raise ConfigurationError, "Error loading policyfile from `#{policyfile_location}': #{e.class} - #{e.message}"
       end
@@ -451,8 +478,9 @@ class Chef
       end
 
       # @api private
-      def http_api
-        @api_service ||= Chef::ServerAPI.new(config[:chef_server_url])
+      def api_service
+        @api_service ||= Chef::ServerAPI.new(config[:chef_server_url],
+                                             { version_class: Chef::CookbookManifestVersions })
       end
 
       # @api private
@@ -495,7 +523,7 @@ class Chef
       def compat_mode_manifest_for(cookbook_name, lock_data)
         xyz_version = lock_data["dotted_decimal_identifier"]
         rel_url = "cookbooks/#{cookbook_name}/#{xyz_version}"
-        inflate_cbv_object(http_api.get(rel_url))
+        inflate_cbv_object(api_service.get(rel_url))
       rescue Exception => e
         message = "Error loading cookbook #{cookbook_name} at version #{xyz_version} from #{rel_url}: #{e.class} - #{e.message}"
         err = Chef::Exceptions::CookbookNotFound.new(message)
@@ -506,7 +534,7 @@ class Chef
       def artifact_manifest_for(cookbook_name, lock_data)
         identifier = lock_data["identifier"]
         rel_url = "cookbook_artifacts/#{cookbook_name}/#{identifier}"
-        inflate_cbv_object(http_api.get(rel_url))
+        inflate_cbv_object(api_service.get(rel_url))
       rescue Exception => e
         message = "Error loading cookbook #{cookbook_name} with identifier #{identifier} from #{rel_url}: #{e.class} - #{e.message}"
         err = Chef::Exceptions::CookbookNotFound.new(message)
