@@ -1,6 +1,6 @@
 #
 # Author:: Cary Penniman (<cary@rightscale.com>)
-# Copyright:: Copyright 2008-2016, Chef Software Inc.
+# Copyright:: Copyright 2008-2017, Chef Software Inc.
 # License:: Apache License, Version 2.0
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -17,41 +17,27 @@
 #
 
 class Chef
-
   class Provider
-
     class Log
-
-      # Chef log provider, allows logging to chef's logs from recipes
+      # Chef log provider, allows logging to chef's logs
       class ChefLog < Chef::Provider
-
         provides :log
 
-        def whyrun_supported?
-          true
-        end
-
         # No concept of a 'current' resource for logs, this is a no-op
         #
-        # === Return
-        # true:: Always return true
+        # @return [true] Always returns true
         def load_current_resource
           true
         end
 
         # Write the log to Chef's log
         #
-        # === Return
-        # true:: Always return true
+        # @return [true] Always returns true
         def action_write
-          Chef::Log.send(@new_resource.level, @new_resource.message)
-          @new_resource.updated_by_last_action(true)
+          Chef::Log.send(new_resource.level, new_resource.message)
+          new_resource.updated_by_last_action(true) if Chef::Config[:count_log_resource_updates]
         end
-
       end
-
     end
-
   end
-
 end
