@@ -18,7 +18,6 @@
 
 require "chef/resource/service"
 require "chef/provider/service/init"
-require "chef/mixin/command"
 
 class Chef
   class Provider
@@ -74,7 +73,7 @@ class Chef
           end
 
           requirements.assert(:start, :enable, :reload, :restart) do |a|
-            a.assertion { service_enable_variable_name != nil }
+            a.assertion { !service_enable_variable_name.nil? }
             a.failure_message Chef::Exceptions::Service, "Could not find the service name in #{init_command} and rcvar"
             # No recovery in whyrun mode - the init file is present but not correct.
           end
