@@ -18,7 +18,6 @@
 #
 
 require "chef/provider/service/init"
-require "chef/mixin/command"
 require "chef/util/path_helper"
 
 class Chef::Provider::Service::Gentoo < Chef::Provider::Service::Init
@@ -61,11 +60,11 @@ class Chef::Provider::Service::Gentoo < Chef::Provider::Service::Init
     end
   end
 
-  def enable_service()
+  def enable_service
     shell_out!("/sbin/rc-update add #{@new_resource.service_name} default")
   end
 
-  def disable_service()
+  def disable_service
     shell_out!("/sbin/rc-update del #{@new_resource.service_name} default")
   end
 end
