@@ -18,7 +18,6 @@
 
 require "chef/provider/service"
 require "chef/resource/service"
-require "chef/mixin/command"
 
 class Chef
   class Provider
@@ -41,10 +40,6 @@ class Chef
           @current_resource
         end
 
-        def whyrun_supported?
-          true
-        end
-
         def shared_resource_requirements
           super
           requirements.assert(:all_actions) do |a|
