@@ -58,8 +58,9 @@ class Chef
 
     def resolve
       maybe_explicit_provider(resource) ||
+        maybe_custom_resource(resource) ||
         maybe_dynamic_provider_resolution(resource, action) ||
-        maybe_chef_platform_lookup(resource)
+        raise(Chef::Exceptions::ProviderNotFound, "Cannot find a provider for #{resource} on #{node["platform"]} version #{node["platform_version"]}")
     end
 
     # Does NOT call provides? on the resource (it is assumed this is being
@@ -90,8 +91,10 @@ class Chef
       @prioritized_handlers ||= begin
         supported_handlers = self.supported_handlers
         if supported_handlers.empty?
-          # if none of the providers specifically support the resource, we still need to pick one of the providers that are
-          # enabled on the node to handle the why-run use case. FIXME we should only do this in why-run mode then.
+          # We always require a provider to be able to call define_resource_requirements on.  In the why-run case we need
+          # a provider to say "assuming /etc/init.d/whatever would have been installed" and in the non-why-run case we
+          # need to make a best guess at "cannot find /etc/init.d/whatever".  We are essentially defining a "default" provider
+          # for the platform, which is the best we can do, but which might give misleading errors, but we cannot read minds.
           Chef::Log.debug "No providers responded true to `supports?` for action #{action} on resource #{resource}, falling back to enabled handlers so we can return something anyway."
           supported_handlers = enabled_handlers
         end
@@ -103,10 +106,14 @@ class Chef
       end
     end
 
+    # if its a custom resource, just grab the action class
+    def maybe_custom_resource(resource)
+      resource.class.action_class if resource.class.custom_resource?
+    end
+
     # if resource.provider is set, just return one of those objects
     def maybe_explicit_provider(resource)
-      return nil unless resource.provider
-      resource.provider
+      resource.provider if resource.provider
     end
 
     # try dynamically finding a provider based on querying the providers to see what they support
@@ -124,11 +131,6 @@ class Chef
       handler
     end
 
-    # try the old static lookup of providers by platform
-    def maybe_chef_platform_lookup(resource)
-      Chef::Platform.find_provider_for_node(node, resource)
-    end
-
     def priority_map
       Chef.provider_priority_map
     end
@@ -140,31 +142,5 @@ class Chef
     def overrode_provides?(handler)
       handler.method(:provides?).owner != Chef::Provider.method(:provides?).owner
     end
-
-    module Deprecated
-      # return a deterministically sorted list of Chef::Provider subclasses
-      def providers
-        @providers ||= Chef::Provider.descendants
-      end
-
-      def enabled_handlers
-        @enabled_handlers ||= begin
-          handlers = super
-          if handlers.empty?
-            # Look through all providers, and find ones that return true to provides.
-            # Don't bother with ones that don't override provides?, since they
-            # would have been in enabled_handlers already if that were so. (It's a
-            # perf concern otherwise.)
-            handlers = providers.select { |handler| overrode_provides?(handler) && handler.provides?(node, resource) }
-            handlers.each do |handler|
-              Chef.log_deprecation("#{handler}.provides? returned true when asked if it provides DSL #{resource.resource_name}, but provides #{resource.resource_name.inspect} was never called!")
-              Chef.log_deprecation("In Chef 13, this will break: you must call provides to mark the names you provide, even if you also override provides? yourself.")
-            end
-          end
-          handlers
-        end
-      end
-    end
-    prepend Deprecated
   end
 end
