@@ -1,6 +1,6 @@
 #
 # Author:: Thom May (<thom@chef.io>)
-# Copyright:: Copyright (c) 2016 Chef Software, Inc.
+# Copyright:: Copyright (c) 2016-2017, Chef Software Inc.
 # License:: Apache License, Version 2.0
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -20,10 +20,15 @@ require "chef/resource"
 
 class Chef
   class Resource
+    # Use the apt_update resource to manage APT repository updates on Debian and Ubuntu platforms.
+    #
+    # @since 12.7
     class AptUpdate < Chef::Resource
       resource_name :apt_update
-      provides :apt_update, os: "linux"
+      provides :apt_update
 
+      # allow bare apt_update with no name
+      property :name, String, default: ""
       property :frequency, Integer, default: 86_400
 
       default_action :periodic
