@@ -1,6 +1,6 @@
 #
 # Author:: Adam Jacob (<adam@chef.io>)
-# Copyright:: Copyright 2008-2016, Chef Software, Inc.
+# Copyright:: Copyright 2008-2017, Chef Software Inc.
 # License:: Apache License, Version 2.0
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -20,20 +20,22 @@ require "chef/resource/package"
 
 class Chef
   class Resource
+    # Use the chocolatey_package resource to manage packages using Chocolatey on the Microsoft Windows platform.
+    #
+    # @since 12.7
     class ChocolateyPackage < Chef::Resource::Package
 
+      resource_name :chocolatey_package
       provides :chocolatey_package, os: "windows"
 
       allowed_actions :install, :upgrade, :remove, :uninstall, :purge, :reconfig
 
-      def initialize(name, run_context = nil)
-        super
-        @resource_name = :chocolatey_package
-      end
+      # windows can't take Array options yet
+      property :options, String
 
       property :package_name, [String, Array], coerce: proc { |x| [x].flatten }
-
       property :version, [String, Array], coerce: proc { |x| [x].flatten }
+      property :returns, [Integer, Array], default: [ 0 ], desired_state: false
     end
   end
 end
