@@ -19,6 +19,11 @@ require "chef/dsl/powershell"
 
 class Chef
   class Resource
+    # The dsc_resource resource allows any DSC resource to be used in a Chef recipe, as well as any custom resources
+    # that have been added to your Windows PowerShell environment. Microsoft frequently adds new resources to the DSC
+    # resource collection.
+    #
+    # @since 12.2
     class DscResource < Chef::Resource
       provides :dsc_resource, os: "windows"
 
@@ -29,7 +34,7 @@ class Chef
       # to dump the actual ivars
       class ToTextHash < Hash
         def to_text
-          descriptions = self.map do |(property, obj)|
+          descriptions = map do |(property, obj)|
             obj_text = if obj.respond_to?(:to_text)
                          obj.to_text
                        else
@@ -68,6 +73,14 @@ class Chef
         end
       end
 
+      def module_version(arg = nil)
+        set_or_return(
+          :module_version,
+          arg,
+          :kind_of => [ String ]
+        )
+      end
+
       def property(property_name, value = nil)
         if not property_name.is_a?(Symbol)
           raise TypeError, "A property name of type Symbol must be specified, '#{property_name}' of type #{property_name.class} was given"
