@@ -21,9 +21,15 @@ require "chef/dsl/powershell"
 
 class Chef
   class Resource
+    # Many DSC resources are comparable to built-in Chef resources. For example, both DSC and Chef have file, package,
+    # and service resources. The dsc_script resource is most useful for those DSC resources that do not have a direct
+    # comparison to a resource in Chef, such as the Archive resource, a custom DSC resource, an existing DSC script
+    # that performs an important task, and so on. Use the dsc_script resource to embed the code that defines a DSC
+    # configuration directly within a Chef recipe.
     class DscScript < Chef::Resource
       include Chef::DSL::Powershell
 
+      resource_name :dsc_script
       provides :dsc_script, os: "windows"
 
       default_action :run
