@@ -1,7 +1,7 @@
 #
 # Author:: Joshua Timberman (<joshua@chef.io>)
 # Author:: Tyler Cloke (<tyler@chef.io>)
-# Copyright:: Copyright 2009-2016, Chef Software Inc.
+# Copyright:: Copyright 2009-2017, Chef Software Inc.
 # License:: Apache License, Version 2.0
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -21,6 +21,7 @@ require "chef/resource"
 
 class Chef
   class Resource
+    # Use the mount resource to manage a mounted file system.
     class Mount < Chef::Resource
 
       identity_attr :device
@@ -28,7 +29,13 @@ class Chef
       state_attrs :mount_point, :device_type, :fstype, :username, :password, :domain
 
       default_action :mount
-      allowed_actions :mount, :umount, :remount, :enable, :disable
+      allowed_actions :mount, :umount, :unmount, :remount, :enable, :disable
+
+      # this is a poor API please do not re-use this pattern
+      property :supports, Hash, default: lazy { { remount: false } },
+                                coerce: proc { |x| x.is_a?(Array) ? x.each_with_object({}) { |i, m| m[i] = true } : x }
+
+      property :password, String, sensitive: true
 
       def initialize(name, run_context = nil)
         super
@@ -42,7 +49,6 @@ class Chef
         @pass = 2
         @mounted = false
         @enabled = false
-        @supports = { :remount => false }
         @username = nil
         @password = nil
         @domain = nil
@@ -140,16 +146,6 @@ class Chef
         )
       end
 
-      def supports(args = {})
-        if args.is_a? Array
-          args.each { |arg| @supports[arg] = true }
-        elsif args.any?
-          @supports = args
-        else
-          @supports
-        end
-      end
-
       def username(arg = nil)
         set_or_return(
           :username,
@@ -158,14 +154,6 @@ class Chef
         )
       end
 
-      def password(arg = nil)
-        set_or_return(
-          :password,
-          arg,
-          :kind_of => [ String ]
-        )
-      end
-
       def domain(arg = nil)
         set_or_return(
           :domain,
