@@ -19,35 +19,17 @@
 
 class Chef
   class Resource
+    # Use the ohai resource to reload the Ohai configuration on a node. This allows recipes that change system attributes
+    # (like a recipe that adds a user) to refer to those attributes later on during the chef-client run.
     class Ohai < Chef::Resource
+      resource_name :ohai
+      provides :ohai
 
-      identity_attr :name
-
-      state_attrs :plugin
+      property :ohai_name, name_property: true
+      property :plugin, [String]
 
       default_action :reload
-
-      def initialize(name, run_context = nil)
-        super
-        @name = name
-        @plugin = nil
-      end
-
-      def plugin(arg = nil)
-        set_or_return(
-          :plugin,
-          arg,
-          :kind_of => [ String ]
-        )
-      end
-
-      def name(arg = nil)
-        set_or_return(
-          :name,
-          arg,
-          :kind_of => [ String ]
-        )
-      end
+      allowed_actions :reload
     end
   end
 end
