@@ -1,5 +1,5 @@
 #
-# Copyright:: Copyright 2016, Chef Software Inc.
+# Copyright:: Copyright 2016-2017, Chef Software Inc.
 # License:: Apache License, Version 2.0
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -26,25 +26,6 @@ class Chef
         provides :linux_user
         provides :user, os: "linux"
 
-        def initialize(name, run_context = nil)
-          super
-          @supports = {
-            manage_home: true,
-            non_unique: true,
-          }
-          @manage_home = false
-        end
-
-        def supports(args = {})
-          Chef.log_deprecation "setting supports on the linux_user resource is deprecated"
-          # setting is deliberately disabled
-          super({})
-        end
-
-        def supports=(args)
-          # setting is deliberately disabled
-          supports({})
-        end
       end
     end
   end
