@@ -15,14 +15,17 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+
+require "chef/json_compat"
+
 class Chef
   class ResourceCollection
     module ResourceCollectionSerialization
       # Serialize this object as a hash
       def to_hash
         instance_vars = Hash.new
-        self.instance_variables.each do |iv|
-          instance_vars[iv] = self.instance_variable_get(iv)
+        instance_variables.each do |iv|
+          instance_vars[iv] = instance_variable_get(iv)
         end
         {
             "json_class" => self.class.name,
@@ -39,13 +42,17 @@ class Chef
       end
 
       module ClassMethods
-        def json_create(o)
-          collection = self.new()
+        def from_hash(o)
+          collection = new()
           o["instance_vars"].each do |k, v|
             collection.instance_variable_set(k.to_sym, v)
           end
           collection
         end
+
+        def from_json(j)
+          from_hash(Chef::JSONCompat.parse(j))
+        end
       end
 
       def is_chef_resource!(arg)
