@@ -95,6 +95,12 @@ class Chef
         end
       end
 
+      def self.from_hash(o)
+        collection = new()
+        resources = o["instance_vars"]["@resources"].map { |r| Chef::Resource.from_hash(r) }
+        collection.instance_variable_set(:@resources, resources)
+        collection
+      end
     end
   end
 end
