@@ -2,7 +2,7 @@
 # Author:: Adam Jacob (<adam@chef.io>)
 # Author:: Christopher Walters (<cw@chef.io>)
 # Author:: Tim Hinderliter (<tim@chef.io>)
-# Copyright:: Copyright 2008-2016, Chef Software Inc.
+# Copyright:: Copyright 2008-2017, Chef Software Inc.
 # License:: Apache License, Version 2.0
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -29,7 +29,6 @@ require "forwardable"
 
 class Chef
 
-  # == Chef::RunContext
   # Value object that loads and tracks the context of a Chef run
   class RunContext
     #
@@ -84,6 +83,17 @@ class Chef
     #
     attr_reader :parent_run_context
 
+    #
+    # The root run context.
+    #
+    # @return [Chef::RunContext] The root run context.
+    #
+    def root_run_context
+      rc = self
+      rc = rc.parent_run_context until rc.parent_run_context.nil?
+      rc
+    end
+
     #
     # The collection of resources intended to be converged (and able to be
     # notified).
@@ -99,6 +109,11 @@ class Chef
     #
     attr_reader :audits
 
+    #
+    # Pointer back to the Chef::Runner that created this
+    #
+    attr_accessor :runner
+
     #
     # Notification handling
     #
@@ -242,7 +257,7 @@ class Chef
     # @return [Array[Notification]]
     #
     def before_notifications(resource)
-      return before_notification_collection[resource.declared_key]
+      before_notification_collection[resource.declared_key]
     end
 
     #
@@ -251,7 +266,7 @@ class Chef
     # @return [Array[Notification]]
     #
     def immediate_notifications(resource)
-      return immediate_notification_collection[resource.declared_key]
+      immediate_notification_collection[resource.declared_key]
     end
 
     #
@@ -261,7 +276,7 @@ class Chef
     # @return [Array[Notification]]
     #
     def delayed_notifications(resource)
-      return delayed_notification_collection[resource.declared_key]
+      delayed_notification_collection[resource.declared_key]
     end
 
     #
@@ -296,7 +311,7 @@ class Chef
     #
     # @param recipe_names [Array[String]] The recipe name (e.g 'my_cookbook' or
     #   'my_cookbook::my_resource').
-    # @param current_cookbook The cookbook we are currently running in.
+    # @param current_cookbook [String] The cookbook we are currently running in.
     #
     # @return A truthy value if the load occurred; `false` if already loaded.
     #
@@ -540,11 +555,18 @@ ERROR_MESSAGE
       @reboot_info = reboot_info
     end
 
+    #
+    # Cancels a pending reboot
+    #
     def cancel_reboot
       Chef::Log.info "Changing reboot status from #{reboot_info.inspect} to {}"
       @reboot_info = {}
     end
 
+    #
+    # Checks to see if a reboot has been requested
+    # @return [Boolean]
+    #
     def reboot_requested?
       reboot_info.size > 0
     end
@@ -565,27 +587,6 @@ ERROR_MESSAGE
     attr_reader :loaded_attributes_hash
     attr_reader :loaded_recipes_hash
 
-    module Deprecated
-      ###
-      # These need to be settable so deploy can run a resource_collection
-      # independent of any cookbooks via +recipe_eval+
-      def audits=(value)
-        Chef.log_deprecation("Setting run_context.audits will be removed in a future Chef.  Use run_context.create_child to create a new RunContext instead.")
-        @audits = value
-      end
-
-      def immediate_notification_collection=(value)
-        Chef.log_deprecation("Setting run_context.immediate_notification_collection will be removed in a future Chef.  Use run_context.create_child to create a new RunContext instead.")
-        @immediate_notification_collection = value
-      end
-
-      def delayed_notification_collection=(value)
-        Chef.log_deprecation("Setting run_context.delayed_notification_collection will be removed in a future Chef.  Use run_context.create_child to create a new RunContext instead.")
-        @delayed_notification_collection = value
-      end
-    end
-    prepend Deprecated
-
     #
     # A child run context.  Delegates all root context calls to its parent.
     #
@@ -653,8 +654,11 @@ ERROR_MESSAGE
         notifies_immediately
         notifies_delayed
         parent_run_context
+        root_run_context
         resource_collection
         resource_collection=
+        runner
+        runner=
       }.map { |x| x.to_sym }
 
       # Verify that we didn't miss any methods
