@@ -40,13 +40,13 @@ module FFI
         last_char = nil
         while last_char != "\000\000"
           length += 1
-          last_char = self.get_bytes(0, length * 2)[-2..-1]
+          last_char = get_bytes(0, length * 2)[-2..-1]
         end
 
         num_wchars = length
       end
 
-      wide_to_utf8(self.get_bytes(0, num_wchars * 2))
+      wide_to_utf8(get_bytes(0, num_wchars * 2))
     end
   end
 end
