@@ -21,7 +21,7 @@
 #
 current_file = __FILE__
 chef_project_contents = IO.read(File.expand_path("../chef.rb", __FILE__))
-self.instance_eval chef_project_contents
+instance_eval chef_project_contents
 
 name "angrychef"
 friendly_name "Angry Chef Client"
