@@ -1,6 +1,6 @@
 #
 # Author:: John Keiser (<jkeiser@chef.io>)
-# Copyright:: Copyright 2011-2016, Chef Software Inc.
+# Copyright:: Copyright 2011-2017, Chef Software Inc.
 # License:: Apache License, Version 2.0
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -20,6 +20,7 @@ require "spec_helper"
 
 if windows?
   require "chef/win32/file" #probably need this in spec_helper
+  require "chef/win32/security"
 end
 
 describe Chef::Resource::Link do
@@ -62,6 +63,18 @@ describe Chef::Resource::Link do
     end
   end
 
+  def node
+    node = Chef::Node.new
+    node.consume_external_attrs(ohai.data, {})
+    node
+  end
+
+  def user(user)
+    usr = Chef::Resource.resource_for_node(:user, node).new(user, run_context)
+    usr.password("ComplexPass11!") if windows?
+    usr
+  end
+
   def cleanup_link(path)
     if windows? && File.directory?(path)
       # If the link target is a directory rm_rf doesn't work all the
@@ -108,6 +121,42 @@ describe Chef::Resource::Link do
     end
   end
 
+  let(:test_user) { windows? ? nil : ENV["USER"] }
+
+  def expected_owner
+    if windows?
+      get_sid(test_user)
+    else
+      test_user
+    end
+  end
+
+  def get_sid(value)
+    if value.kind_of?(String)
+      Chef::ReservedNames::Win32::Security::SID.from_account(value)
+    elsif value.kind_of?(Chef::ReservedNames::Win32::Security::SID)
+      value
+    else
+      raise "Must specify username or SID: #{value}"
+    end
+  end
+
+  def chown(file, user)
+    if windows?
+      Chef::ReservedNames::Win32::Security::SecurableObject.new(file).owner = get_sid(user)
+    else
+      File.lchown(Etc.getpwnam(user).uid, Etc.getpwnam(user).gid, file)
+    end
+  end
+
+  def owner(file)
+    if windows?
+      Chef::ReservedNames::Win32::Security::SecurableObject.new(file).security_descriptor.owner
+    else
+      Etc.getpwuid(File.lstat(file).uid).name
+    end
+  end
+
   def create_resource
     node = Chef::Node.new
     events = Chef::EventDispatch::Dispatcher.new
@@ -184,6 +233,7 @@ describe Chef::Resource::Link do
         it "links to the target file" do
           expect(symlink?(target_file)).to be_truthy
           expect(readlink(target_file)).to eq(canonicalize(to))
+          expect(owner(target_file)).to eq(expected_owner) unless test_user.nil?
         end
         it "marks the resource updated" do
           expect(resource).to be_updated
@@ -205,6 +255,7 @@ describe Chef::Resource::Link do
         it "leaves the file linked" do
           expect(symlink?(target_file)).to be_truthy
           expect(readlink(target_file)).to eq(canonicalize(to))
+          expect(owner(target_file)).to eq(expected_owner) unless test_user.nil?
         end
         it "does not mark the resource updated" do
           expect(resource).not_to be_updated
@@ -291,13 +342,23 @@ describe Chef::Resource::Link do
               expect(File.exists?(to)).to be_truthy
             end
           end
-          context "pointing somewhere else" do
+          context "pointing somewhere else", :requires_root_or_running_windows do
+            let(:test_user) { "test-link-user" }
+            before do
+              user(test_user).run_action(:create)
+            end
+            after do
+              user(test_user).run_action(:remove)
+            end
             before(:each) do
+              resource.owner(test_user)
               @other_target = File.join(test_file_dir, make_tmpname("other_spec"))
               File.open(@other_target, "w") { |file| file.write("eek") }
               symlink(@other_target, target_file)
+              chown(target_file, test_user)
               expect(symlink?(target_file)).to be_truthy
               expect(readlink(target_file)).to eq(canonicalize(@other_target))
+              expect(owner(target_file)).to eq(expected_owner)
             end
             after(:each) do
               File.delete(@other_target)
@@ -593,7 +654,7 @@ describe Chef::Resource::Link do
           end
           context "and the link does not yet exist" do
             it "links to the target file" do
-              skip("OS X/FreeBSD/AIX symlink? and readlink working on hard links to symlinks") if os_x? || freebsd? || aix?
+              skip("OS X/FreeBSD/AIX/Solaris symlink? and readlink working on hard links to symlinks") if os_x? || freebsd? || aix? || solaris?
               resource.run_action(:create)
               expect(File.exists?(target_file)).to be_truthy
               # OS X gets angry about this sort of link.  Bug in OS X, IMO.
@@ -612,7 +673,7 @@ describe Chef::Resource::Link do
           end
           context "and the link does not yet exist" do
             it "links to the target file" do
-              skip("OS X/FreeBSD/AIX fails to create hardlinks to broken symlinks") if os_x? || freebsd? || aix?
+              skip("OS X/FreeBSD/AIX/Solaris fails to create hardlinks to broken symlinks") if os_x? || freebsd? || aix? || solaris?
               resource.run_action(:create)
               expect(File.exists?(target_file) || File.symlink?(target_file)).to be_truthy
               expect(symlink?(target_file)).to be_truthy
