@@ -12,7 +12,7 @@ describe "Recipe DSL methods" do
   before { Namer.current_index += 1 }
 
   context "with resource 'base_thingy' declared as BaseThingy" do
-    before(:context) do
+    before(:each) do
 
       class BaseThingy < Chef::Resource
         resource_name "base_thingy"
@@ -59,21 +59,30 @@ describe "Recipe DSL methods" do
       expect(BaseThingy.created_resource).to eq BaseThingy
     end
 
-    it "errors out when you call base_thingy do ... end in a recipe" do
+    it "errors when you call base_thingy do ... end in a recipe" do
       expect_converge do
         base_thingy { ; }
-      end.to raise_error(ArgumentError, "You must supply a name when declaring a base_thingy resource")
+      end.to raise_error(Chef::Exceptions::ValidationFailed)
     end
 
-    it "emits a warning when you call base_thingy 'foo', 'bar' do ... end in a recipe" do
-      Chef::Config[:treat_deprecation_warnings_as_errors] = false
-      recipe = converge do
-        base_thingy "foo", "bar" do
+    context "nameless resources" do
+      before(:each) do
+        class NamelessThingy < BaseThingy
+          resource_name :nameless_thingy
+          provides :nameless_thingy
+
+          property :name, String, default: ""
         end
       end
-      expect(recipe.logged_warnings).to match(/Cannot create resource base_thingy with more than one argument. All arguments except the name \("foo"\) will be ignored. This will cause an error in Chef 13. Arguments: \["foo", "bar"\]/)
-      expect(BaseThingy.created_name).to eq "foo"
-      expect(BaseThingy.created_resource).to eq BaseThingy
+
+      it "does not error when not given a name" do
+        recipe = converge do
+          nameless_thingy {}
+        end
+        expect(recipe.logged_warnings).to eq ""
+        expect(BaseThingy.created_name).to eq ""
+        expect(BaseThingy.created_resource).to eq NamelessThingy
+      end
     end
 
     context "Deprecated automatic resource DSL" do
@@ -81,54 +90,8 @@ describe "Recipe DSL methods" do
         Chef::Config[:treat_deprecation_warnings_as_errors] = false
       end
 
-      context "with a resource 'backcompat_thingy' declared in Chef::Resource and Chef::Provider" do
-        before(:context) do
-
-          class Chef::Resource::BackcompatThingy < Chef::Resource
-            default_action :create
-          end
-          class Chef::Provider::BackcompatThingy < Chef::Provider
-            def load_current_resource
-            end
-
-            def action_create
-              BaseThingy.created_resource = new_resource.class
-              BaseThingy.created_provider = self.class
-            end
-          end
-
-        end
-
-        it "backcompat_thingy creates a Chef::Resource::BackcompatThingy" do
-          recipe = converge do
-            backcompat_thingy("blah") {}
-          end
-          expect(BaseThingy.created_resource).to eq Chef::Resource::BackcompatThingy
-          expect(BaseThingy.created_provider).to eq Chef::Provider::BackcompatThingy
-        end
-
-        context "and another resource 'backcompat_thingy' in BackcompatThingy with 'provides'" do
-          before(:context) do
-
-            class RecipeDSLSpecNamespace::BackcompatThingy < BaseThingy
-              provides :backcompat_thingy
-              resource_name :backcompat_thingy
-            end
-
-          end
-
-          it "backcompat_thingy creates a BackcompatThingy" do
-            recipe = converge do
-              backcompat_thingy("blah") {}
-            end
-            expect(recipe.logged_warnings).to match(/Class Chef::Provider::BackcompatThingy does not declare 'provides :backcompat_thingy'./)
-            expect(BaseThingy.created_resource).not_to be_nil
-          end
-        end
-      end
-
       context "with a resource named RecipeDSLSpecNamespace::Bar::BarThingy" do
-        before(:context) do
+        before(:each) do
 
           class RecipeDSLSpecNamespace::Bar::BarThingy < BaseThingy
           end
@@ -143,7 +106,7 @@ describe "Recipe DSL methods" do
       end
 
       context "with a resource named Chef::Resource::NoNameThingy with resource_name nil" do
-        before(:context) do
+        before(:each) do
 
           class Chef::Resource::NoNameThingy < BaseThingy
             resource_name nil
@@ -159,7 +122,7 @@ describe "Recipe DSL methods" do
       end
 
       context "with a resource named AnotherNoNameThingy with resource_name :another_thingy_name" do
-        before(:context) do
+        before(:each) do
 
           class AnotherNoNameThingy < BaseThingy
             resource_name :another_thingy_name
@@ -183,7 +146,7 @@ describe "Recipe DSL methods" do
       end
 
       context "with a resource named AnotherNoNameThingy2 with resource_name :another_thingy_name2; resource_name :another_thingy_name3" do
-        before(:context) do
+        before(:each) do
 
           class AnotherNoNameThingy2 < BaseThingy
             resource_name :another_thingy_name2
@@ -215,7 +178,7 @@ describe "Recipe DSL methods" do
 
       context "provides overriding resource_name" do
         context "with a resource named AnotherNoNameThingy3 with provides :another_no_name_thingy3, os: 'blarghle'" do
-          before(:context) do
+          before(:each) do
 
             class AnotherNoNameThingy3 < BaseThingy
               resource_name :another_no_name_thingy_3
@@ -244,7 +207,7 @@ describe "Recipe DSL methods" do
         end
 
         context "with a resource named AnotherNoNameThingy4 with two provides" do
-          before(:context) do
+          before(:each) do
 
             class AnotherNoNameThingy4 < BaseThingy
               resource_name :another_no_name_thingy_4
@@ -284,7 +247,7 @@ describe "Recipe DSL methods" do
         end
 
         context "with a resource named AnotherNoNameThingy5, a different resource_name, and a provides with the original resource_name" do
-          before(:context) do
+          before(:each) do
 
             class AnotherNoNameThingy5 < BaseThingy
               resource_name :another_thingy_name_for_another_no_name_thingy5
@@ -321,7 +284,7 @@ describe "Recipe DSL methods" do
         end
 
         context "with a resource named AnotherNoNameThingy6, a provides with the original resource name, and a different resource_name" do
-          before(:context) do
+          before(:each) do
 
             class AnotherNoNameThingy6 < BaseThingy
               provides :another_no_name_thingy6, os: "blarghle"
@@ -358,7 +321,7 @@ describe "Recipe DSL methods" do
         end
 
         context "with a resource named AnotherNoNameThingy7, a new resource_name, and provides with that new resource name" do
-          before(:context) do
+          before(:each) do
 
             class AnotherNoNameThingy7 < BaseThingy
               resource_name :another_thingy_name_for_another_no_name_thingy7
@@ -396,7 +359,7 @@ describe "Recipe DSL methods" do
 
         # opposite order from the previous test (provides, then resource_name)
         context "with a resource named AnotherNoNameThingy8, a provides with a new resource name, and resource_name with that new resource name" do
-          before(:context) do
+          before(:each) do
 
             class AnotherNoNameThingy8 < BaseThingy
               provides :another_thingy_name_for_another_no_name_thingy8, os: "blarghle"
@@ -436,7 +399,7 @@ describe "Recipe DSL methods" do
 
     context "provides" do
       context "when MySupplier provides :hemlock" do
-        before(:context) do
+        before(:each) do
 
           class RecipeDSLSpecNamespace::MySupplier < BaseThingy
             resource_name :hemlock
@@ -459,7 +422,7 @@ describe "Recipe DSL methods" do
       end
 
       context "when Thingy3 has resource_name :thingy3" do
-        before(:context) do
+        before(:each) do
 
           class RecipeDSLSpecNamespace::Thingy3 < BaseThingy
             resource_name :thingy3
@@ -475,7 +438,7 @@ describe "Recipe DSL methods" do
         end
 
         context "and Thingy4 has resource_name :thingy3" do
-          before(:context) do
+          before(:each) do
 
             class RecipeDSLSpecNamespace::Thingy4 < BaseThingy
               resource_name :thingy3
@@ -503,7 +466,7 @@ describe "Recipe DSL methods" do
       end
 
       context "when Thingy5 has resource_name :thingy5 and provides :thingy5reverse, :thingy5_2 and :thingy5_2reverse" do
-        before(:context) do
+        before(:each) do
 
           class RecipeDSLSpecNamespace::Thingy5 < BaseThingy
             resource_name :thingy5
@@ -522,7 +485,7 @@ describe "Recipe DSL methods" do
         end
 
         context "and Thingy6 provides :thingy5" do
-          before(:context) do
+          before(:each) do
 
             class RecipeDSLSpecNamespace::Thingy6 < BaseThingy
               resource_name :thingy6
@@ -550,7 +513,7 @@ describe "Recipe DSL methods" do
           end
 
           context "and AThingy5 provides :thingy5reverse" do
-            before(:context) do
+            before(:each) do
 
               class RecipeDSLSpecNamespace::AThingy5 < BaseThingy
                 resource_name :thingy5reverse
@@ -567,7 +530,7 @@ describe "Recipe DSL methods" do
           end
 
           context "and ZRecipeDSLSpecNamespace::Thingy5 provides :thingy5_2" do
-            before(:context) do
+            before(:each) do
 
               module ZRecipeDSLSpecNamespace
                 class Thingy5 < BaseThingy
@@ -586,7 +549,7 @@ describe "Recipe DSL methods" do
           end
 
           context "and ARecipeDSLSpecNamespace::Thingy5 provides :thingy5_2" do
-            before(:context) do
+            before(:each) do
 
               module ARecipeDSLSpecNamespace
                 class Thingy5 < BaseThingy
@@ -606,7 +569,7 @@ describe "Recipe DSL methods" do
         end
 
         context "when Thingy3 has resource_name :thingy3" do
-          before(:context) do
+          before(:each) do
 
             class RecipeDSLSpecNamespace::Thingy3 < BaseThingy
               resource_name :thingy3
@@ -622,7 +585,7 @@ describe "Recipe DSL methods" do
           end
 
           context "and Thingy4 has resource_name :thingy3" do
-            before(:context) do
+            before(:each) do
 
               class RecipeDSLSpecNamespace::Thingy4 < BaseThingy
                 resource_name :thingy3
@@ -649,7 +612,7 @@ describe "Recipe DSL methods" do
           end
 
           context "and Thingy4 has resource_name :thingy3" do
-            before(:context) do
+            before(:each) do
 
               class RecipeDSLSpecNamespace::Thingy4 < BaseThingy
                 resource_name :thingy3
@@ -679,7 +642,7 @@ describe "Recipe DSL methods" do
       end
 
       context "when Thingy7 provides :thingy8" do
-        before(:context) do
+        before(:each) do
 
           class RecipeDSLSpecNamespace::Thingy7 < BaseThingy
             resource_name :thingy7
@@ -689,7 +652,7 @@ describe "Recipe DSL methods" do
         end
 
         context "and Thingy8 has resource_name :thingy8" do
-          before(:context) do
+          before(:each) do
 
             class RecipeDSLSpecNamespace::Thingy8 < BaseThingy
               resource_name :thingy8
@@ -718,7 +681,7 @@ describe "Recipe DSL methods" do
       end
 
       context "when Thingy12 provides :thingy12, :twizzle and :twizzle2" do
-        before(:context) do
+        before(:each) do
 
           class RecipeDSLSpecNamespace::Thingy12 < BaseThingy
             resource_name :thingy12
@@ -751,7 +714,7 @@ describe "Recipe DSL methods" do
       end
 
       context "with platform-specific resources 'my_super_thingy_foo' and 'my_super_thingy_bar'" do
-        before(:context) do
+        before(:each) do
           class MySuperThingyFoo < BaseThingy
             resource_name :my_super_thingy_foo
             provides :my_super_thingy, platform: "foo"
@@ -797,7 +760,7 @@ describe "Recipe DSL methods" do
       end
 
       context "when Thingy10 provides :thingy10" do
-        before(:context) do
+        before(:each) do
           class RecipeDSLSpecNamespace::Thingy10 < BaseThingy
             resource_name :thingy10
           end
@@ -812,7 +775,7 @@ describe "Recipe DSL methods" do
       end
 
       context "when Thingy11 provides :thingy11" do
-        before(:context) do
+        before(:each) do
           class RecipeDSLSpecNamespace::Thingy11 < BaseThingy
             resource_name :thingy10
           end
@@ -861,9 +824,9 @@ describe "Recipe DSL methods" do
         before { resource_class_a } # pull on it so it gets defined before the recipe runs
 
         it "two_classes_one_dsl resolves to A (alphabetically earliest)" do
-          two_classes_one_dsl = self.two_classes_one_dsl
+          temp_two_classes_one_dsl = two_classes_one_dsl
           recipe = converge do
-            instance_eval("#{two_classes_one_dsl} 'blah'")
+            instance_eval("#{temp_two_classes_one_dsl} 'blah'")
           end
           expect(recipe.logged_warnings).to eq ""
           expect(BaseThingy.created_resource).to eq resource_class_a
@@ -891,9 +854,9 @@ describe "Recipe DSL methods" do
         before { resource_class_z } # pull on it so it gets defined before the recipe runs
 
         it "two_classes_one_dsl resolves to B (alphabetically earliest)" do
-          two_classes_one_dsl = self.two_classes_one_dsl
+          temp_two_classes_one_dsl = two_classes_one_dsl
           recipe = converge do
-            instance_eval("#{two_classes_one_dsl} 'blah'")
+            instance_eval("#{temp_two_classes_one_dsl} 'blah'")
           end
           expect(recipe.logged_warnings).to eq ""
           expect(BaseThingy.created_resource).to eq resource_class
@@ -909,9 +872,9 @@ describe "Recipe DSL methods" do
           end
 
           it "two_classes_one_dsl resolves to Z (respects the priority array)" do
-            two_classes_one_dsl = self.two_classes_one_dsl
+            temp_two_classes_one_dsl = two_classes_one_dsl
             recipe = converge do
-              instance_eval("#{two_classes_one_dsl} 'blah'")
+              instance_eval("#{temp_two_classes_one_dsl} 'blah'")
             end
             expect(recipe.logged_warnings).to eq ""
             expect(BaseThingy.created_resource).to eq resource_class_z
@@ -927,9 +890,9 @@ describe "Recipe DSL methods" do
             end
 
             it "two_classes_one_dsl resolves to B (picks the next thing in the priority array)" do
-              two_classes_one_dsl = self.two_classes_one_dsl
+              temp_two_classes_one_dsl = two_classes_one_dsl
               recipe = converge do
-                instance_eval("#{two_classes_one_dsl} 'blah'")
+                instance_eval("#{temp_two_classes_one_dsl} 'blah'")
               end
               expect(recipe.logged_warnings).to eq ""
               expect(BaseThingy.created_resource).to eq resource_class
@@ -948,9 +911,9 @@ describe "Recipe DSL methods" do
           end
 
           it "two_classes_one_dsl resolves to Z (respects the most recent priority array)" do
-            two_classes_one_dsl = self.two_classes_one_dsl
+            temp_two_classes_one_dsl = two_classes_one_dsl
             recipe = converge do
-              instance_eval("#{two_classes_one_dsl} 'blah'")
+              instance_eval("#{temp_two_classes_one_dsl} 'blah'")
             end
             expect(recipe.logged_warnings).to eq ""
             expect(BaseThingy.created_resource).to eq resource_class_z
@@ -966,9 +929,9 @@ describe "Recipe DSL methods" do
             end
 
             it "two_classes_one_dsl resolves to B (picks the first match from the other priority array)" do
-              two_classes_one_dsl = self.two_classes_one_dsl
+              temp_two_classes_one_dsl = two_classes_one_dsl
               recipe = converge do
-                instance_eval("#{two_classes_one_dsl} 'blah'")
+                instance_eval("#{temp_two_classes_one_dsl} 'blah'")
               end
               expect(recipe.logged_warnings).to eq ""
               expect(BaseThingy.created_resource).to eq resource_class
@@ -991,9 +954,9 @@ describe "Recipe DSL methods" do
             end
 
             it "two_classes_one_dsl resolves to B (picks the first match outside the priority array)" do
-              two_classes_one_dsl = self.two_classes_one_dsl
+              temp_two_classes_one_dsl = two_classes_one_dsl
               recipe = converge do
-                instance_eval("#{two_classes_one_dsl} 'blah'")
+                instance_eval("#{temp_two_classes_one_dsl} 'blah'")
               end
               expect(recipe.logged_warnings).to eq ""
               expect(BaseThingy.created_resource).to eq resource_class
@@ -1044,9 +1007,9 @@ describe "Recipe DSL methods" do
             before { provider_class_a.provides two_classes_one_dsl }
 
             it "two_classes_one_dsl resolves to A (alphabetically earliest)" do
-              two_classes_one_dsl = self.two_classes_one_dsl
+              temp_two_classes_one_dsl = two_classes_one_dsl
               recipe = converge do
-                instance_eval("#{two_classes_one_dsl} 'blah'")
+                instance_eval("#{temp_two_classes_one_dsl} 'blah'")
               end
               expect(recipe.logged_warnings).to eq ""
               expect(BaseThingy.created_provider).to eq provider_class_a
@@ -1056,9 +1019,9 @@ describe "Recipe DSL methods" do
             before { provider_class_a.provides(two_classes_one_dsl) { false } }
 
             it "two_classes_one_dsl resolves to B (since A declined)" do
-              two_classes_one_dsl = self.two_classes_one_dsl
+              temp_two_classes_one_dsl = two_classes_one_dsl
               recipe = converge do
-                instance_eval("#{two_classes_one_dsl} 'blah'")
+                instance_eval("#{temp_two_classes_one_dsl} 'blah'")
               end
               expect(recipe.logged_warnings).to eq ""
               expect(BaseThingy.created_provider).to eq provider_class
@@ -1085,9 +1048,9 @@ describe "Recipe DSL methods" do
             before { provider_class_z.provides two_classes_one_dsl }
 
             it "two_classes_one_dsl resolves to B (alphabetically earliest)" do
-              two_classes_one_dsl = self.two_classes_one_dsl
+              temp_two_classes_one_dsl = two_classes_one_dsl
               recipe = converge do
-                instance_eval("#{two_classes_one_dsl} 'blah'")
+                instance_eval("#{temp_two_classes_one_dsl} 'blah'")
               end
               expect(recipe.logged_warnings).to eq ""
               expect(BaseThingy.created_provider).to eq provider_class
@@ -1097,9 +1060,9 @@ describe "Recipe DSL methods" do
               before { Chef.set_provider_priority_array two_classes_one_dsl, [ provider_class_z, provider_class ] }
 
               it "two_classes_one_dsl resolves to Z (respects the priority map)" do
-                two_classes_one_dsl = self.two_classes_one_dsl
+                temp_two_classes_one_dsl = two_classes_one_dsl
                 recipe = converge do
-                  instance_eval("#{two_classes_one_dsl} 'blah'")
+                  instance_eval("#{temp_two_classes_one_dsl} 'blah'")
                 end
                 expect(recipe.logged_warnings).to eq ""
                 expect(BaseThingy.created_provider).to eq provider_class_z
@@ -1114,9 +1077,9 @@ describe "Recipe DSL methods" do
               before { Chef.set_provider_priority_array two_classes_one_dsl, [ provider_class_z, provider_class ] }
 
               it "two_classes_one_dsl resolves to B (the next one in the priority map)" do
-                two_classes_one_dsl = self.two_classes_one_dsl
+                temp_two_classes_one_dsl = two_classes_one_dsl
                 recipe = converge do
-                  instance_eval("#{two_classes_one_dsl} 'blah'")
+                  instance_eval("#{temp_two_classes_one_dsl} 'blah'")
                 end
                 expect(recipe.logged_warnings).to eq ""
                 expect(BaseThingy.created_provider).to eq provider_class
@@ -1128,9 +1091,9 @@ describe "Recipe DSL methods" do
               before { Chef.set_provider_priority_array two_classes_one_dsl, [ provider_class ] }
 
               it "two_classes_one_dsl resolves to B (the one in the next priority map)" do
-                two_classes_one_dsl = self.two_classes_one_dsl
+                temp_two_classes_one_dsl = two_classes_one_dsl
                 recipe = converge do
-                  instance_eval("#{two_classes_one_dsl} 'blah'")
+                  instance_eval("#{temp_two_classes_one_dsl} 'blah'")
                 end
                 expect(recipe.logged_warnings).to eq ""
                 expect(BaseThingy.created_provider).to eq provider_class
@@ -1158,22 +1121,22 @@ describe "Recipe DSL methods" do
         before { resource_class_blarghle } # pull on it so it gets defined before the recipe runs
 
         it "on os = blarghle, two_classes_one_dsl resolves to Blarghle" do
-          two_classes_one_dsl = self.two_classes_one_dsl
+          temp_two_classes_one_dsl = two_classes_one_dsl
           recipe = converge do
             # this is an ugly way to test, make Cheffish expose node attrs
             run_context.node.automatic[:os] = "blarghle"
-            instance_eval("#{two_classes_one_dsl} 'blah' do; end")
+            instance_eval("#{temp_two_classes_one_dsl} 'blah' do; end")
           end
           expect(recipe.logged_warnings).to eq ""
           expect(BaseThingy.created_resource).to eq resource_class_blarghle
         end
 
         it "on os = linux, two_classes_one_dsl resolves to B" do
-          two_classes_one_dsl = self.two_classes_one_dsl
+          temp_two_classes_one_dsl = two_classes_one_dsl
           recipe = converge do
             # this is an ugly way to test, make Cheffish expose node attrs
             run_context.node.automatic[:os] = "linux"
-            instance_eval("#{two_classes_one_dsl} 'blah' do; end")
+            instance_eval("#{temp_two_classes_one_dsl} 'blah' do; end")
           end
           expect(recipe.logged_warnings).to eq ""
           expect(BaseThingy.created_resource).to eq resource_class
@@ -1202,15 +1165,15 @@ describe "Recipe DSL methods" do
 
         context "with provides? returning true to my_resource" do
           before do
-            my_resource = self.my_resource
+            temp_my_resource = my_resource
             resource_class.define_singleton_method(:provides?) do |node, resource_name|
               @called_provides = true
-              resource_name == my_resource
+              resource_name == temp_my_resource
             end
           end
 
           it "my_resource returns the resource and calls provides?, but does not emit a warning" do
-            dsl_name = self.my_resource
+            dsl_name = my_resource
             recipe = converge do
               instance_eval("#{dsl_name} 'foo'")
             end
@@ -1220,35 +1183,6 @@ describe "Recipe DSL methods" do
           end
         end
 
-        context "with provides? returning true to blarghle_blarghle_little_star and not resource_name" do
-          before do
-            blarghle_blarghle_little_star = self.blarghle_blarghle_little_star
-            resource_class.define_singleton_method(:provides?) do |node, resource_name|
-              @called_provides = true
-              resource_name == blarghle_blarghle_little_star
-            end
-          end
-
-          it "my_resource does not return the resource" do
-            dsl_name = self.my_resource
-            expect_converge do
-              instance_eval("#{dsl_name} 'foo'")
-            end.to raise_error(Chef::Exceptions::NoSuchResourceType)
-            expect(resource_class.called_provides).to be_truthy
-          end
-
-          it "blarghle_blarghle_little_star 'foo' returns the resource and emits a warning" do
-            Chef::Config[:treat_deprecation_warnings_as_errors] = false
-            dsl_name = self.blarghle_blarghle_little_star
-            recipe = converge do
-              instance_eval("#{dsl_name} 'foo'")
-            end
-            expect(recipe.logged_warnings).to include "WARN: #{resource_class}.provides? returned true when asked if it provides DSL #{dsl_name}, but provides :#{dsl_name} was never called!"
-            expect(BaseThingy.created_resource).to eq resource_class
-            expect(resource_class.called_provides).to be_truthy
-          end
-        end
-
         context "and a provider" do
           let(:provider_class) do
             Class.new(BaseThingy::Provider) do
@@ -1281,9 +1215,9 @@ describe "Recipe DSL methods" do
               end
 
               it "my_resource runs the provider and does not emit a warning" do
-                my_resource = self.my_resource
+                temp_my_resource = my_resource
                 recipe = converge do
-                  instance_eval("#{my_resource} 'foo'")
+                  instance_eval("#{temp_my_resource} 'foo'")
                 end
                 expect(recipe.logged_warnings).to eq ""
                 expect(BaseThingy.created_provider).to eq provider_class
@@ -1311,9 +1245,9 @@ describe "Recipe DSL methods" do
                 end
 
                 it "my_resource runs the first provider" do
-                  my_resource = self.my_resource
+                  temp_my_resource = my_resource
                   recipe = converge do
-                    instance_eval("#{my_resource} 'foo'")
+                    instance_eval("#{temp_my_resource} 'foo'")
                   end
                   expect(recipe.logged_warnings).to eq ""
                   expect(BaseThingy.created_provider).to eq provider_class
@@ -1328,9 +1262,9 @@ describe "Recipe DSL methods" do
 
               # TODO no warning? ick
               it "my_resource runs the provider anyway" do
-                my_resource = self.my_resource
+                temp_my_resource = my_resource
                 recipe = converge do
-                  instance_eval("#{my_resource} 'foo'")
+                  instance_eval("#{temp_my_resource} 'foo'")
                 end
                 expect(recipe.logged_warnings).to eq ""
                 expect(BaseThingy.created_provider).to eq provider_class
@@ -1338,7 +1272,7 @@ describe "Recipe DSL methods" do
 
               context "and another provider supporting :my_resource with supports? true" do
                 let(:provider_class2) do
-                  my_resource = self.my_resource
+                  temp_my_resource = my_resource
                   Class.new(BaseThingy::Provider) do
                     def self.name
                       "MyProvider2"
@@ -1351,7 +1285,7 @@ describe "Recipe DSL methods" do
                     def self.called_provides
                       @called_provides
                     end
-                    provides my_resource
+                    provides temp_my_resource
                     def self.supports?(resource, action)
                       true
                     end
@@ -1360,9 +1294,9 @@ describe "Recipe DSL methods" do
                 before { provider_class2 } # make sure the provider class shows up
 
                 it "my_resource runs the other provider" do
-                  my_resource = self.my_resource
+                  temp_my_resource = my_resource
                   recipe = converge do
-                    instance_eval("#{my_resource} 'foo'")
+                    instance_eval("#{temp_my_resource} 'foo'")
                   end
                   expect(recipe.logged_warnings).to eq ""
                   expect(BaseThingy.created_provider).to eq provider_class2
@@ -1370,82 +1304,26 @@ describe "Recipe DSL methods" do
               end
             end
           end
-
-          context "with provides? returning true" do
-            before do
-              my_resource = self.my_resource
-              provider_class.define_singleton_method(:provides?) do |node, resource|
-                @called_provides = true
-                resource.declared_type == my_resource
-              end
-            end
-
-            context "that provides :my_resource" do
-              before do
-                provider_class.provides my_resource
-              end
-
-              it "my_resource calls the provider (and calls provides?), but does not emit a warning" do
-                my_resource = self.my_resource
-                recipe = converge do
-                  instance_eval("#{my_resource} 'foo'")
-                end
-                expect(recipe.logged_warnings).to eq ""
-                expect(BaseThingy.created_provider).to eq provider_class
-                expect(provider_class.called_provides).to be_truthy
-              end
-            end
-
-            context "that does not call provides :my_resource" do
-              it "my_resource calls the provider (and calls provides?), and emits a warning" do
-                Chef::Config[:treat_deprecation_warnings_as_errors] = false
-                my_resource = self.my_resource
-                recipe = converge do
-                  instance_eval("#{my_resource} 'foo'")
-                end
-                expect(recipe.logged_warnings).to include("WARN: #{provider_class}.provides? returned true when asked if it provides DSL #{my_resource}, but provides :#{my_resource} was never called!")
-                expect(BaseThingy.created_provider).to eq provider_class
-                expect(provider_class.called_provides).to be_truthy
-              end
-            end
-          end
-
-          context "with provides? returning false to my_resource" do
-            before do
-              my_resource = self.my_resource
-              provider_class.define_singleton_method(:provides?) do |node, resource|
-                @called_provides = true
-                false
-              end
-            end
-
-            context "that provides :my_resource" do
-              before do
-                provider_class.provides my_resource
-              end
-
-              it "my_resource fails to find a provider (and calls provides)" do
-                my_resource = self.my_resource
-                expect_converge do
-                  instance_eval("#{my_resource} 'foo'")
-                end.to raise_error(Chef::Exceptions::ProviderNotFound)
-                expect(provider_class.called_provides).to be_truthy
-              end
-            end
-
-            context "that does not provide :my_resource" do
-              it "my_resource fails to find a provider (and calls provides)" do
-                my_resource = self.my_resource
-                expect_converge do
-                  instance_eval("#{my_resource} 'foo'")
-                end.to raise_error(Chef::Exceptions::ProviderNotFound)
-                expect(provider_class.called_provides).to be_truthy
-              end
-            end
-          end
         end
       end
     end
+
+    context "with UTF-8 provides" do
+      before(:each) do
+        class UTF8Thingy < BaseThingy
+          resource_name :Straße
+          provides :Straße
+        end
+      end
+
+      it "utf-8 dsl names work" do
+        recipe = converge do
+          Straße("blah") {}
+        end
+        expect(recipe.logged_warnings).to eq ""
+        expect(BaseThingy.created_resource).to eq(UTF8Thingy)
+      end
+    end
   end
 
   before(:all) { Namer.current_index = 0 }
@@ -1492,29 +1370,4 @@ describe "Recipe DSL methods" do
     end
   end
 
-  context "with a dynamically defined resource and regular provider" do
-    before(:context) do
-      Class.new(Chef::Resource) do
-        resource_name :lw_resource_with_hw_provider_test_case
-        default_action :create
-        attr_accessor :created_provider
-      end
-      class Chef::Provider::LwResourceWithHwProviderTestCase < Chef::Provider
-        def load_current_resource
-        end
-
-        def action_create
-          new_resource.created_provider = self.class
-        end
-      end
-    end
-
-    it "looks up the provider in Chef::Provider converting the resource name from snake case to camel case" do
-      resource = nil
-      recipe = converge do
-        resource = lw_resource_with_hw_provider_test_case("blah") {}
-      end
-      expect(resource.created_provider).to eq(Chef::Provider::LwResourceWithHwProviderTestCase)
-    end
-  end
 end
