@@ -9,54 +9,70 @@ module ResourceActionSpec
     shared_context "ActionJackson" do
       it "the default action is the first declared action" do
         converge <<-EOM, __FILE__, __LINE__ + 1
-        #{resource_dsl} "hi" do
-          foo "foo!"
-        end
-      EOM
+          #{resource_dsl} "hi" do
+            foo "foo!"
+          end
+        EOM
         expect(ActionJackson.ran_action).to eq :access_recipe_dsl
         expect(ActionJackson.succeeded).to eq true
       end
 
+      context "when running in whyrun mode" do
+        before do
+          Chef::Config[:why_run] = true
+        end
+
+        it "the default action runs" do
+          converge <<-EOM, __FILE__, __LINE__ + 1
+            #{resource_dsl} "hi" do
+              foo "foo!"
+            end
+          EOM
+          expect(ActionJackson.ran_action).to eq :access_recipe_dsl
+          expect(ActionJackson.succeeded).to eq true
+        end
+      end
+
       it "the action can access recipe DSL" do
         converge <<-EOM, __FILE__, __LINE__ + 1
-        #{resource_dsl} "hi" do
-          foo "foo!"
-          action :access_recipe_dsl
-        end
-      EOM
+          #{resource_dsl} "hi" do
+            foo "foo!"
+            action :access_recipe_dsl
+          end
+        EOM
         expect(ActionJackson.ran_action).to eq :access_recipe_dsl
         expect(ActionJackson.succeeded).to eq true
       end
 
       it "the action can access attributes" do
         converge <<-EOM, __FILE__, __LINE__ + 1
-        #{resource_dsl} "hi" do
-          foo "foo!"
-          action :access_attribute
-        end
-      EOM
+          #{resource_dsl} "hi" do
+            foo "foo!"
+            action :access_attribute
+          end
+        EOM
         expect(ActionJackson.ran_action).to eq :access_attribute
         expect(ActionJackson.succeeded).to eq "foo!"
       end
 
       it "the action can access public methods" do
         converge <<-EOM, __FILE__, __LINE__ + 1
-        #{resource_dsl} "hi" do
-          foo "foo!"
-          action :access_method
-        end
-      EOM
+          #{resource_dsl} "hi" do
+            foo "foo!"
+            action :access_method
+          end
+        EOM
         expect(ActionJackson.ran_action).to eq :access_method
         expect(ActionJackson.succeeded).to eq "foo_public!"
       end
 
       it "the action can access protected methods" do
         converge <<-EOM, __FILE__, __LINE__ + 1
-        #{resource_dsl} "hi" do
-          foo "foo!"
-          action :access_protected_method
-        end
-      EOM
+          #{resource_dsl} "hi" do
+            foo "foo!"
+            action :access_protected_method
+          end
+        EOM
         expect(ActionJackson.ran_action).to eq :access_protected_method
         expect(ActionJackson.succeeded).to eq "foo_protected!"
       end
@@ -64,39 +80,39 @@ module ResourceActionSpec
       it "the action cannot access private methods" do
         expect do
           converge(<<-EOM, __FILE__, __LINE__ + 1)
-          #{resource_dsl} "hi" do
-            foo "foo!"
-            action :access_private_method
-          end
-        EOM
+            #{resource_dsl} "hi" do
+              foo "foo!"
+              action :access_private_method
+            end
+          EOM
         end.to raise_error(NameError)
         expect(ActionJackson.ran_action).to eq :access_private_method
       end
 
       it "the action cannot access resource instance variables" do
         converge <<-EOM, __FILE__, __LINE__ + 1
-        #{resource_dsl} "hi" do
-          foo "foo!"
-          action :access_instance_variable
-        end
-      EOM
+          #{resource_dsl} "hi" do
+            foo "foo!"
+            action :access_instance_variable
+          end
+        EOM
         expect(ActionJackson.ran_action).to eq :access_instance_variable
         expect(ActionJackson.succeeded).to be_nil
       end
 
       it "the action does not compile until the prior resource has converged" do
         converge <<-EOM, __FILE__, __LINE__ + 1
-        ruby_block "wow" do
-          block do
-            ResourceActionSpec::ActionJackson.ruby_block_converged = "ruby_block_converged!"
+          ruby_block "wow" do
+            block do
+              ResourceActionSpec::ActionJackson.ruby_block_converged = "ruby_block_converged!"
+            end
           end
-        end
 
-        #{resource_dsl} "hi" do
-          foo "foo!"
-          action :access_class_method
-        end
-      EOM
+          #{resource_dsl} "hi" do
+            foo "foo!"
+            action :access_class_method
+          end
+        EOM
         expect(ActionJackson.ran_action).to eq :access_class_method
         expect(ActionJackson.succeeded).to eq "ruby_block_converged!"
       end
@@ -141,7 +157,7 @@ module ResourceActionSpec
 
         action :access_recipe_dsl do
           ActionJackson.ran_action = :access_recipe_dsl
-          ruby_block "hi there" do
+          whyrun_safe_ruby_block "hi there" do
             block do
               ActionJackson.succeeded = true
             end
@@ -213,7 +229,7 @@ module ResourceActionSpec
       end
 
       context "And 'action_jackgrandson' inheriting from ActionJackson and changing nothing" do
-        before(:context) do
+        before(:each) do
           class ActionJackgrandson < ActionJackson
             use_automatic_resource_name
           end
@@ -341,7 +357,7 @@ module ResourceActionSpec
       end
     end
 
-    context "With a resource with action a-b-c d" do
+    context "With a resource with a UTF-8 action" do
       class WeirdActionJackson < Chef::Resource
         use_automatic_resource_name
 
@@ -349,7 +365,7 @@ module ResourceActionSpec
           attr_accessor :action_was
         end
 
-        action "a-b-c d" do
+        action :Straße do
           WeirdActionJackson.action_was = action
         end
       end
@@ -358,7 +374,7 @@ module ResourceActionSpec
         expect_recipe do
           weird_action_jackson "hi"
         end.to be_up_to_date
-        expect(WeirdActionJackson.action_was).to eq :"a-b-c d"
+        expect(WeirdActionJackson.action_was).to eq :Straße
       end
     end
 
@@ -400,6 +416,7 @@ module ResourceActionSpec
         attr_reader :x_warning_line
 
         it "Using the enclosing resource to set x to x emits a warning that you're using the wrong x" do
+          Chef::Config[:treat_deprecation_warnings_as_errors] = false
           recipe = converge do
             resource_action_spec_also_with_x "hi" do
               x 1
@@ -407,34 +424,43 @@ module ResourceActionSpec
             end
           end
           warnings = recipe.logs.lines.select { |l| l =~ /warn/i }
-          expect(warnings.size).to eq 1
+          expect(warnings.size).to eq 2
           expect(warnings[0]).to match(/property x is declared in both resource_action_spec_with_x\[hi\] and resource_action_spec_also_with_x\[hi\] action :set_x_to_x. Use new_resource.x instead. At #{__FILE__}:#{ResourceActionSpecAlsoWithX.x_warning_line}/)
         end
 
         it "Using the enclosing resource to set x to x outside the initializer emits no warning" do
-          expect_recipe do
+          Chef::Config[:treat_deprecation_warnings_as_errors] = false
+          recipe = converge do
             resource_action_spec_also_with_x "hi" do
               x 1
               action :set_x_to_x_in_non_initializer
             end
-          end.to emit_no_warnings_or_errors
+          end
+          warnings = recipe.logs.lines.select { |l| l =~ /warn/i }
+          expect(warnings.size).to eq 1  # the deprecation warning, not the property masking one
         end
 
         it "Using the enclosing resource to set x to 10 emits no warning" do
-          expect_recipe do
+          Chef::Config[:treat_deprecation_warnings_as_errors] = false
+          recipe = converge do
             resource_action_spec_also_with_x "hi" do
               x 1
               action :set_x_to_10
             end
-          end.to emit_no_warnings_or_errors
+          end
+          warnings = recipe.logs.lines.select { |l| l =~ /warn/i }
+          expect(warnings.size).to eq 1  # the deprecation warning, not the property masking one
         end
 
         it "Using the enclosing resource to set x to 10 emits no warning" do
-          expect_recipe do
+          Chef::Config[:treat_deprecation_warnings_as_errors] = false
+          recipe = converge do
             r = resource_action_spec_also_with_x "hi"
             r.x 1
             r.action :set_x_to_10
-          end.to emit_no_warnings_or_errors
+          end
+          warnings = recipe.logs.lines.select { |l| l =~ /warn/i }
+          expect(warnings.size).to eq 1  # the deprecation warning, not the property masking one
         end
       end
 
@@ -480,46 +506,35 @@ module ResourceActionSpec
       end
 
       it "Raises an error when attempting to use a template in the action" do
+        Chef::Config[:treat_deprecation_warnings_as_errors] = false
         expect_converge do
           has_property_named_template "hi"
-        end.to raise_error(/Property template of has_property_named_template\[hi\] cannot be passed a block! If you meant to create a resource named template instead, you'll need to first rename the property./)
+        end.to raise_error(/Property `template` of `has_property_named_template\[hi\]` was incorrectly passed a block. Possible property-resource collision. To call a resource named `template` either rename the property or else use `declare_resource\(:template, ...\)`/)
       end
     end
 
-    context "When a resource declares methods in action_class and declare_action_class" do
+    context "When a resource declares methods in action_class" do
       class DeclaresActionClassMethods < Chef::Resource
         use_automatic_resource_name
         property :x
-        action :create do
-          new_resource.x = a + b + c + d
-        end
         action_class do
           def a
             1
           end
         end
-        declare_action_class do
-          def b
-            2
-          end
-        end
-        action_class do
+        action_class.class_eval <<-EOM
           def c
             3
           end
-        end
-        declare_action_class do
-          def d
-            4
-          end
+        EOM
+        action :create do
+          new_resource.x = a + c
         end
       end
 
       it "the methods are not available on the resource" do
         expect { DeclaresActionClassMethods.new("hi").a }.to raise_error(NameError)
-        expect { DeclaresActionClassMethods.new("hi").b }.to raise_error(NameError)
         expect { DeclaresActionClassMethods.new("hi").c }.to raise_error(NameError)
-        expect { DeclaresActionClassMethods.new("hi").d }.to raise_error(NameError)
       end
 
       it "the methods are available to the action" do
@@ -527,17 +542,14 @@ module ResourceActionSpec
         expect_recipe do
           r = declares_action_class_methods "hi"
         end.to emit_no_warnings_or_errors
-        expect(r.x).to eq(10)
+        expect(r.x).to eq(4)
       end
 
-      context "And a subclass also creates a method" do
+      context "And a subclass overrides a method with an action_class block" do
         class DeclaresActionClassMethodsToo < DeclaresActionClassMethods
           use_automatic_resource_name
-          action :create do
-            new_resource.x a + b + c + d + e
-          end
           action_class do
-            def e
+            def a
               5
             end
           end
@@ -545,10 +557,7 @@ module ResourceActionSpec
 
         it "the methods are not available on the resource" do
           expect { DeclaresActionClassMethods.new("hi").a }.to raise_error(NameError)
-          expect { DeclaresActionClassMethods.new("hi").b }.to raise_error(NameError)
           expect { DeclaresActionClassMethods.new("hi").c }.to raise_error(NameError)
-          expect { DeclaresActionClassMethods.new("hi").d }.to raise_error(NameError)
-          expect { DeclaresActionClassMethods.new("hi").e }.to raise_error(NameError)
         end
 
         it "the methods are available to the action" do
@@ -556,7 +565,32 @@ module ResourceActionSpec
           expect_recipe do
             r = declares_action_class_methods_too "hi"
           end.to emit_no_warnings_or_errors
-          expect(r.x).to eq(15)
+          expect(r.x).to eq(8)
+        end
+      end
+
+      context "And a subclass overrides a method with class_eval" do
+        # this tests inheritance with *only* an action_class accessor that does not declare a block
+        class DeclaresActionClassMethodsToo < DeclaresActionClassMethods
+          use_automatic_resource_name
+          action_class.class_eval <<-EOM
+            def a
+              5
+            end
+          EOM
+        end
+
+        it "the methods are not available on the resource" do
+          expect { DeclaresActionClassMethods.new("hi").a }.to raise_error(NameError)
+          expect { DeclaresActionClassMethods.new("hi").c }.to raise_error(NameError)
+        end
+
+        it "the methods are available to the action" do
+          r = nil
+          expect_recipe do
+            r = declares_action_class_methods_too "hi"
+          end.to emit_no_warnings_or_errors
+          expect(r.x).to eq(8)
         end
       end
     end
