@@ -1,6 +1,6 @@
 #
 # Author:: Adam Jacob (<adam@chef.io>)
-# Copyright:: Copyright 2008-2016, Chef Software, Inc.
+# Copyright:: Copyright 2008-2018, Chef Software Inc.
 # License:: Apache License, Version 2.0
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -30,6 +30,8 @@ $:.unshift File.expand_path("../..", __FILE__)
 require "rubygems"
 require "rspec/mocks"
 
+require "webmock/rspec"
+
 $:.unshift(File.join(File.dirname(__FILE__), "..", "lib"))
 $:.unshift(File.expand_path("../lib", __FILE__))
 $:.unshift(File.dirname(__FILE__))
@@ -68,6 +70,11 @@ require "chef/config"
 
 require "chef/chef_fs/file_system_cache"
 
+require "chef/api_client_v1"
+
+require "chef/mixin/versioned_api"
+require "chef/server_api_versions"
+
 if ENV["CHEF_FIPS"] == "1"
   Chef::Config.init_openssl
 end
@@ -104,6 +111,11 @@ TEST_PLATFORM = TEST_NODE["platform"]
 TEST_PLATFORM_VERSION = TEST_NODE["platform_version"]
 TEST_PLATFORM_FAMILY = TEST_NODE["platform_family"]
 
+provider_priority_map ||= nil
+resource_priority_map ||= nil
+provider_handler_map ||= nil
+resource_handler_map ||= nil
+
 RSpec.configure do |config|
   config.include(Matchers)
   config.include(MockShellout::RSpec)
@@ -139,16 +151,23 @@ RSpec.configure do |config|
   config.filter_run_excluding :not_supported_on_gce => true if gce?
   config.filter_run_excluding :not_supported_on_nano => true if windows_nano_server?
   config.filter_run_excluding :win2k3_only => true unless windows_win2k3?
+  config.filter_run_excluding :win2012r2_only => true unless windows_2012r2?
   config.filter_run_excluding :windows_2008r2_or_later => true unless windows_2008r2_or_later?
   config.filter_run_excluding :windows64_only => true unless windows64?
   config.filter_run_excluding :windows32_only => true unless windows32?
   config.filter_run_excluding :windows_nano_only => true unless windows_nano_server?
+  config.filter_run_excluding :windows_gte_10 => true unless windows_gte_10?
+  config.filter_run_excluding :windows_lt_10 => true if windows_gte_10?
   config.filter_run_excluding :ruby64_only => true unless ruby_64bit?
   config.filter_run_excluding :ruby32_only => true unless ruby_32bit?
   config.filter_run_excluding :windows_powershell_dsc_only => true unless windows_powershell_dsc?
   config.filter_run_excluding :windows_powershell_no_dsc_only => true unless ! windows_powershell_dsc?
   config.filter_run_excluding :windows_domain_joined_only => true unless windows_domain_joined?
   config.filter_run_excluding :windows_not_domain_joined_only => true if windows_domain_joined?
+  # We think this line was causing rspec tests to not run on the Jenkins windows
+  # testers. If we ever fix it we should restore it.
+  # config.filter_run_excluding :windows_service_requires_assign_token => true if !STDOUT.isatty && !windows_user_right?("SeAssignPrimaryTokenPrivilege")
+  config.filter_run_excluding :windows_service_requires_assign_token => true
   config.filter_run_excluding :solaris_only => true unless solaris?
   config.filter_run_excluding :system_windows_service_gem_only => true unless system_windows_service_gem?
   config.filter_run_excluding :unix_only => true unless unix?
@@ -172,15 +191,17 @@ RSpec.configure do |config|
   config.filter_run_excluding chef: DependencyProc.with(Chef::VERSION)
   config.filter_run_excluding ruby: DependencyProc.with(RUBY_VERSION)
 
+  config.filter_run_excluding :choco_installed => true unless choco_installed?
+
   running_platform_arch = `uname -m`.strip unless windows?
 
-  config.filter_run_excluding :arch => lambda {|target_arch|
+  config.filter_run_excluding :arch => lambda { |target_arch|
     running_platform_arch != target_arch
   }
 
   # Functional Resource tests that are provider-specific:
   # context "on platforms that use useradd", :provider => {:user => Chef::Provider::User::Useradd}} do #...
-  config.filter_run_excluding :provider => lambda {|criteria|
+  config.filter_run_excluding :provider => lambda { |criteria|
     type, target_provider = criteria.first
 
     node = TEST_NODE.dup
@@ -201,6 +222,11 @@ RSpec.configure do |config|
   config.run_all_when_everything_filtered = true
 
   config.before(:each) do
+    # it'd be nice to run this with connections blocked or only to localhost, but we do make lots
+    # of real connections, so cannot.  we reset it to allow connections every time to avoid
+    # tests setting connections to be disabled and that state leaking into other tests.
+    WebMock.allow_net_connect!
+
     Chef.reset!
 
     Chef::ChefFS::FileSystemCache.instance.reset!
@@ -212,12 +238,46 @@ RSpec.configure do |config|
 
     # Set environment variable so the setting persists in child processes
     ENV["CHEF_TREAT_DEPRECATION_WARNINGS_AS_ERRORS"] = "1"
+
+    # we don't perfectly reset the priority/handler maps here, but by dup'ing the top level hash we
+    # throw away all the garbage resources and providers that we setup.  if we mutate something like
+    # :package then that'll carry over from test-to-test, but the solution would be to deep-dup on every
+    # single test we run which is much more expensive.  by throwing away the garbage top level keys we
+    # significantly speed up test runs.
+    provider_handler_map ||= Chef.provider_handler_map.send(:map).dup
+    resource_handler_map ||= Chef.resource_handler_map.send(:map).dup
+    provider_priority_map ||= Chef.provider_priority_map.send(:map).dup
+    resource_priority_map ||= Chef.resource_priority_map.send(:map).dup
+    Chef.provider_handler_map.instance_variable_set(:@map, provider_handler_map.dup)
+    Chef.resource_handler_map.instance_variable_set(:@map, resource_handler_map.dup)
+    Chef.provider_priority_map.instance_variable_set(:@map, provider_priority_map.dup)
+    Chef.resource_priority_map.instance_variable_set(:@map, resource_priority_map.dup)
+  end
+
+  # This bit of jankiness guards against specs which accidentally drop privs when running as
+  # root -- which are nearly impossible to debug and so we bail out very hard if this
+  # condition ever happens.  If a spec stubs Process.[e]uid this can throw a false positive
+  # which the spec must work around by unmocking Process.[e]uid to and_call_original in its
+  # after block.
+  if Process.euid == 0 && Process.uid == 0
+    config.after(:each) do
+      if Process.uid != 0
+        RSpec.configure { |c| c.fail_fast = true }
+        raise "rspec was invoked as root, but the last test dropped real uid to #{Process.uid}"
+      end
+      if Process.euid != 0
+        RSpec.configure { |c| c.fail_fast = true }
+        raise "rspec was invoked as root, but the last test dropped effective uid to #{Process.euid}"
+      end
+    end
   end
 
   # raise if anyone commits any test to CI with :focus set on it
-  config.before(:example, :focus) do
-    raise "This example was committed with `:focus` and should not have been"
-  end if ENV["CI"]
+  if ENV["CI"]
+    config.before(:example, :focus) do
+      raise "This example was committed with `:focus` and should not have been"
+    end
+  end
 
   config.before(:suite) do
     ARGV.clear
