@@ -1,9 +1,12 @@
 require "fcntl"
 require "chef/mixin/shell_out"
+require "ohai/mixin/http_helper"
 require "ohai/mixin/gce_metadata"
+require "chef/mixin/powershell_out"
 
 class ShellHelpers
   extend Chef::Mixin::ShellOut
+  extend Chef::Mixin::PowershellOut
 end
 
 # magic stolen from bundler/spec/support/less_than_proc.rb
@@ -50,23 +53,36 @@ end
 
 def windows_win2k3?
   return false unless windows?
-  wmi = WmiLite::Wmi.new
-  host = wmi.first_of("Win32_OperatingSystem")
-  (host["version"] && host["version"].start_with?("5.2"))
+  (host_version && host_version.start_with?("5.2"))
 end
 
 def windows_2008r2_or_later?
   return false unless windows?
-  wmi = WmiLite::Wmi.new
-  host = wmi.first_of("Win32_OperatingSystem")
-  version = host["version"]
-  return false unless version
-  components = version.split(".").map do |component|
+  return false unless host_version
+  components = host_version.split(".").map do |component|
     component.to_i
   end
   components.length >= 2 && components[0] >= 6 && components[1] >= 1
 end
 
+def windows_2012r2?
+  return false unless windows?
+  (host_version && host_version.start_with?("6.3"))
+end
+
+def windows_gte_10?
+  return false unless windows?
+  Gem::Requirement.new(">= 10").satisfied_by?(Gem::Version.new(host_version))
+end
+
+def host_version
+  @host_version ||= begin
+    wmi = WmiLite::Wmi.new
+    host = wmi.first_of("Win32_OperatingSystem")
+    host["version"]
+  end
+end
+
 def windows_powershell_dsc?
   return false unless windows?
   supports_dsc = false
@@ -84,6 +100,12 @@ def windows_nano_server?
   Chef::Platform.windows_nano_server?
 end
 
+def windows_user_right?(right)
+  return false unless windows?
+  require "chef/win32/security"
+  Chef::ReservedNames::Win32::Security.get_account_right(ENV["USERNAME"]).include?(right)
+end
+
 def mac_osx_106?
   if File.exists? "/usr/bin/sw_vers"
     result = ShellHelpers.shell_out("/usr/bin/sw_vers")
@@ -207,12 +229,17 @@ def fips?
   ENV["CHEF_FIPS"] == "1"
 end
 
-class GCEDetector
-  extend Ohai::Mixin::GCEMetadata
+class HttpHelper
+  extend Ohai::Mixin::HttpHelper
 end
 
 def gce?
-  GCEDetector.can_metadata_connect?(Ohai::Mixin::GCEMetadata::GCE_METADATA_ADDR, 80)
+  HttpHelper.can_socket_connect?(Ohai::Mixin::GCEMetadata::GCE_METADATA_ADDR, 80)
 rescue SocketError
   false
 end
+
+def choco_installed?
+  result = ShellHelpers.powershell_out("choco --version")
+  result.stderr.empty? ? true : false
+end
