@@ -75,9 +75,9 @@ shared_examples_for "a useradd-based user provider" do |supported_useradd_option
       end
 
       it "should set the option for #{attribute} if the new resources #{attribute} is not nil, without homedir management (using real attributes)" do
-        allow(@new_resource).to receive(:manage_home).and_return(false)
-        allow(@new_resource).to receive(:non_unique).and_return(false)
-        allow(@new_resource).to receive(:non_unique).and_return(false)
+        @new_resource.manage_home(false)
+        @new_resource.non_unique(false)
+        @new_resource.non_unique(false)
         allow(@new_resource).to receive(attribute).and_return("hola")
         expect(provider.universal_options).to eql([option, "hola"])
       end
@@ -85,7 +85,7 @@ shared_examples_for "a useradd-based user provider" do |supported_useradd_option
 
     it "should combine all the possible options" do
       combined_opts = []
-      supported_useradd_options.sort { |a, b| a[0] <=> b[0] }.each do |attribute, option|
+      supported_useradd_options.sort_by { |a| a[0] }.each do |attribute, option|
         allow(@new_resource).to receive(attribute).and_return("hola")
         combined_opts << option << "hola"
       end
