@@ -65,7 +65,7 @@ describe Chef::CookbookUploader do
 
   it "creates an HTTP client with default configuration when not initialized with one" do
     default_http_client = double("Chef::ServerAPI")
-    expect(Chef::ServerAPI).to receive(:new).with(Chef::Config[:chef_server_url]).and_return(default_http_client)
+    expect(Chef::ServerAPI).to receive(:new).with(Chef::Config[:chef_server_url], version_class: Chef::CookbookManifestVersions).and_return(default_http_client)
     uploader = described_class.new(cookbooks_to_upload)
     expect(uploader.rest).to eq(default_http_client)
   end
