@@ -23,177 +23,204 @@ describe Chef::CookbookVersion, "file specificity" do
   before(:each) do
     @cookbook = Chef::CookbookVersion.new("test-cookbook", "/cookbook-folder")
     @cookbook.manifest = {
-      "files" =>
+      "all_files" =>
       [
        # afile.rb
        {
-         :name => "afile.rb",
+         :name => "files/afile.rb",
          :path => "files/host-examplehost.example.org/afile.rb",
+         :full_path => "/cookbook-folder/files/host-examplehost.example.org/afile.rb",
          :checksum => "csum-host",
          :specificity => "host-examplehost.example.org",
        },
        {
-         :name => "afile.rb",
+         :name => "files/afile.rb",
          :path => "files/ubuntu-9.10/afile.rb",
+         :full_path => "/cookbook-folder/files/ubuntu-9.10/afile.rb",
          :checksum => "csum-platver-full",
          :specificity => "ubuntu-9.10",
        },
        {
-         :name => "afile.rb",
+         :name => "files/afile.rb",
          :path => "files/newubuntu-9/afile.rb",
+         :full_path => "/cookbook-folder/files/newubuntu-9/afile.rb",
          :checksum => "csum-platver-partial",
          :specificity => "newubuntu-9",
        },
        {
-         :name => "afile.rb",
+         :name => "files/afile.rb",
          :path => "files/ubuntu/afile.rb",
+         :full_path => "/cookbook-folder/files/ubuntu/afile.rb",
          :checksum => "csum-plat",
          :specificity => "ubuntu",
        },
        {
-         :name => "afile.rb",
+         :name => "files/afile.rb",
          :path => "files/default/afile.rb",
+         :full_path => "/cookbook-folder/files/default/afile.rb",
          :checksum => "csum-default",
          :specificity => "default",
        },
 
        # for different/odd platform_versions
        {
-         :name => "bfile.rb",
+         :name => "files/bfile.rb",
          :path => "files/fakeos-2.0.rc.1/bfile.rb",
+         :full_path => "/cookbook-folder/files/fakeos-2.0.rc.1/bfile.rb",
          :checksum => "csum2-platver-full",
          :specificity => "fakeos-2.0.rc.1",
        },
        {
-         :name => "bfile.rb",
+         :name => "files/bfile.rb",
          :path => "files/newfakeos-2.0.rc/bfile.rb",
+         :full_path => "/cookbook-folder/files/newfakeos-2.0.rc/bfile.rb",
          :checksum => "csum2-platver-partial",
          :specificity => "newfakeos-2.0.rc",
        },
        {
-         :name => "bfile.rb",
+         :name => "files/bfile.rb",
          :path => "files/fakeos-maple tree/bfile.rb",
+         :full_path => "/cookbook-folder/files/fakeos-maple tree/bfile.rb",
          :checksum => "csum3-platver-full",
          :specificity => "maple tree",
        },
        {
-         :name => "bfile.rb",
+         :name => "files/bfile.rb",
          :path => "files/fakeos-1/bfile.rb",
+         :full_path => "/cookbook-folder/files/fakeos-1/bfile.rb",
          :checksum => "csum4-platver-full",
          :specificity => "fakeos-1",
        },
 
        # directory adirectory
        {
-         :name => "anotherfile1.rb",
+         :name => "files/anotherfile1.rb",
          :path => "files/host-examplehost.example.org/adirectory/anotherfile1.rb.host",
+         :full_path => "/cookbook-folder/files/host-examplehost.example.org/adirectory/anotherfile1.rb.host",
          :checksum => "csum-host-1",
          :specificity => "host-examplehost.example.org",
        },
        {
-         :name => "anotherfile2.rb",
+         :name => "files/anotherfile2.rb",
          :path => "files/host-examplehost.example.org/adirectory/anotherfile2.rb.host",
+         :full_path => "/cookbook-folder/files/host-examplehost.example.org/adirectory/anotherfile2.rb.host",
          :checksum => "csum-host-2",
          :specificity => "host-examplehost.example.org",
        },
 
        {
-         :name => "anotherfile1.rb",
+         :name => "files/anotherfile1.rb",
          :path => "files/ubuntu-9.10/adirectory/anotherfile1.rb.platform-full-version",
+         :full_path => "/cookbook-folder/files/ubuntu-9.10/adirectory/anotherfile1.rb.platform-full-version",
          :checksum => "csum-platver-full-1",
          :specificity => "ubuntu-9.10",
        },
        {
-         :name => "anotherfile2.rb",
+         :name => "files/anotherfile2.rb",
          :path => "files/ubuntu-9.10/adirectory/anotherfile2.rb.platform-full-version",
+         :full_path => "/cookbook-folder/files/ubuntu-9.10/adirectory/anotherfile2.rb.platform-full-version",
          :checksum => "csum-platver-full-2",
          :specificity => "ubuntu-9.10",
        },
 
        {
-         :name => "anotherfile1.rb",
+         :name => "files/anotherfile1.rb",
          :path => "files/newubuntu-9/adirectory/anotherfile1.rb.platform-partial-version",
+         :full_path => "/cookbook-folder/files/newubuntu-9/adirectory/anotherfile1.rb.platform-partial-version",
          :checksum => "csum-platver-partial-1",
          :specificity => "newubuntu-9",
        },
        {
-         :name => "anotherfile2.rb",
+         :name => "files/anotherfile2.rb",
          :path => "files/newubuntu-9/adirectory/anotherfile2.rb.platform-partial-version",
+         :full_path => "/cookbook-folder/files/newubuntu-9/adirectory/anotherfile2.rb.platform-partial-version",
          :checksum => "csum-platver-partial-2",
          :specificity => "nweubuntu-9",
        },
 
        {
-         :name => "anotherfile1.rb",
+         :name => "files/anotherfile1.rb",
          :path => "files/ubuntu/adirectory/anotherfile1.rb.platform",
+         :full_path => "/cookbook-folder/files/ubuntu/adirectory/anotherfile1.rb.platform",
          :checksum => "csum-plat-1",
          :specificity => "ubuntu",
        },
        {
-         :name => "anotherfile2.rb",
+         :name => "files/anotherfile2.rb",
          :path => "files/ubuntu/adirectory/anotherfile2.rb.platform",
+         :full_path => "/cookbook-folder/files/ubuntu/adirectory/anotherfile2.rb.platform",
          :checksum => "csum-plat-2",
          :specificity => "ubuntu",
        },
 
        {
-         :name => "anotherfile1.rb",
+         :name => "files/anotherfile1.rb",
          :path => "files/default/adirectory/anotherfile1.rb.default",
+         :full_path => "/cookbook-folder/files/default/adirectory/anotherfile1.rb.default",
          :checksum => "csum-default-1",
          :specificity => "default",
        },
        {
-         :name => "anotherfile2.rb",
+         :name => "files/anotherfile2.rb",
          :path => "files/default/adirectory/anotherfile2.rb.default",
+         :full_path => "/cookbook-folder/files/default/adirectory/anotherfile2.rb.default",
          :checksum => "csum-default-2",
          :specificity => "default",
        },
        # for different/odd platform_versions
        {
-         :name => "anotherfile1.rb",
+         :name => "files/anotherfile1.rb",
          :path => "files/fakeos-2.0.rc.1/adirectory/anotherfile1.rb.platform-full-version",
+         :full_path => "/cookbook-folder/files/fakeos-2.0.rc.1/adirectory/anotherfile1.rb.platform-full-version",
          :checksum => "csum2-platver-full-1",
          :specificity => "fakeos-2.0.rc.1",
        },
        {
-         :name => "anotherfile2.rb",
+         :name => "files/anotherfile2.rb",
          :path => "files/fakeos-2.0.rc.1/adirectory/anotherfile2.rb.platform-full-version",
+         :full_path => "/cookbook-folder/files/fakeos-2.0.rc.1/adirectory/anotherfile2.rb.platform-full-version",
          :checksum => "csum2-platver-full-2",
          :specificity => "fakeos-2.0.rc.1",
        },
        {
-         :name => "anotherfile1.rb",
+         :name => "files/anotherfile1.rb",
          :path => "files/newfakeos-2.0.rc.1/adirectory/anotherfile1.rb.platform-partial-version",
+         :full_path => "/cookbook-folder/files/newfakeos-2.0.rc.1/adirectory/anotherfile1.rb.platform-partial-version",
          :checksum => "csum2-platver-partial-1",
          :specificity => "newfakeos-2.0.rc",
        },
        {
-         :name => "anotherfile2.rb",
+         :name => "files/anotherfile2.rb",
          :path => "files/newfakeos-2.0.rc.1/adirectory/anotherfile2.rb.platform-partial-version",
+         :full_path => "/cookbook-folder/files/newfakeos-2.0.rc.1/adirectory/anotherfile2.rb.platform-partial-version",
          :checksum => "csum2-platver-partial-2",
          :specificity => "newfakeos-2.0.rc",
        },
        {
-         :name => "anotherfile1.rb",
+         :name => "files/anotherfile1.rb",
          :path => "files/fakeos-maple tree/adirectory/anotherfile1.rb.platform-full-version",
+         :full_path => "/cookbook-folder/files/fakeos-maple tree/adirectory/anotherfile1.rb.platform-full-version",
          :checksum => "csum3-platver-full-1",
          :specificity => "fakeos-maple tree",
        },
        {
-         :name => "anotherfile2.rb",
+         :name => "files/anotherfile2.rb",
          :path => "files/fakeos-maple tree/adirectory/anotherfile2.rb.platform-full-version",
+         :full_path => "/cookbook-folder/files/fakeos-maple tree/adirectory/anotherfile2.rb.platform-full-version",
          :checksum => "csum3-platver-full-2",
          :specificity => "fakeos-maple tree",
        },
        {
-         :name => "anotherfile1.rb",
+         :name => "files/anotherfile1.rb",
          :path => "files/fakeos-1/adirectory/anotherfile1.rb.platform-full-version",
+         :full_path => "/cookbook-folder/files/fakeos-1/adirectory/anotherfile1.rb.platform-full-version",
          :checksum => "csum4-platver-full-1",
          :specificity => "fakeos-1",
        },
        {
-         :name => "anotherfile2.rb",
+         :name => "files/anotherfile2.rb",
          :path => "files/fakeos-1/adirectory/anotherfile2.rb.platform-full-version",
+         :full_path => "/cookbook-folder/files/fakeos-1/adirectory/anotherfile2.rb.platform-full-version",
          :checksum => "csum4-platver-full-2",
          :specificity => "fakeos-1",
        },
