@@ -1,6 +1,6 @@
 #
-# Author:: Daniel DeLeo (<dan@getchef.com>)
-# Copyright:: Copyright (c) 2014 Chef Software, Inc.
+# Author:: Daniel DeLeo (<dan@chef.io>)
+# Copyright:: Copyright 2014-2016, Chef Software, Inc.
 # License:: Apache License, Version 2.0
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -16,15 +16,19 @@
 # limitations under the License.
 #
 
-require 'spec_helper'
-require 'chef/dsl/recipe'
-
+require "spec_helper"
+require "chef/dsl/recipe"
 
 RecipeDSLExampleClass = Struct.new(:cookbook_name, :recipe_name)
 class RecipeDSLExampleClass
   include Chef::DSL::Recipe
 end
 
+FullRecipeDSLExampleClass = Struct.new(:cookbook_name, :recipe_name)
+class FullRecipeDSLExampleClass
+  include Chef::DSL::Recipe::FullDSL
+end
+
 RecipeDSLBaseAPI = Struct.new(:cookbook_name, :recipe_name)
 class RecipeDSLExampleSubclass < RecipeDSLBaseAPI
   include Chef::DSL::Recipe
@@ -37,6 +41,14 @@ describe Chef::DSL::Recipe do
   let(:cookbook_name) { "example_cb" }
   let(:recipe_name) { "example_recipe" }
 
+  it "tracks when it is included via FullDSL" do
+    expect(Chef::DSL::Recipe::FullDSL.descendants).to include(FullRecipeDSLExampleClass)
+  end
+
+  it "doesn't track what is included via only the recipe DSL" do
+    expect(Chef::DSL::Recipe::FullDSL.descendants).not_to include(RecipeDSLExampleClass)
+  end
+
   shared_examples_for "A Recipe DSL Implementation" do
 
     it "responds to cookbook_name" do
@@ -79,4 +91,3 @@ describe Chef::DSL::Recipe do
   end
 
 end
-
