@@ -38,7 +38,7 @@ describe Chef::Knife::Configure do
   let(:default_validator_key) { "/etc/chef-server/chef-validator.pem" }
   let(:default_validator_key_win32) { File.expand_path(default_validator_key) }
 
-  let(:default_server_url) { "https://#{fqdn}:443" }
+  let(:default_server_url) { "https://#{fqdn}/organizations/myorg" }
 
   it "asks the user for the URL of the chef server" do
     @knife.ask_user_for_config
@@ -124,55 +124,12 @@ describe Chef::Knife::Configure do
     end
   end
 
-  it "asks the user for the location of a chef repo" do
-    @knife.ask_user_for_config
-    expect(@out.string).to match(Regexp.escape("Please enter the path to a chef repository (or leave blank):"))
-    expect(@knife.chef_repo).to eq("")
-  end
-
-  it "asks the users for the name of the validation client" do
-    @knife.ask_user_for_config
-    expect(@out.string).to match(Regexp.escape("Please enter the validation clientname: [chef-validator]"))
-    expect(@knife.validation_client_name).to eq("chef-validator")
-  end
-
-  it "should not ask the users for the name of the validation client if --validation_client_name is specified" do
-    @knife.config[:validation_client_name] = "my-validator"
-    @knife.ask_user_for_config
-    expect(@out.string).not_to match(Regexp.escape("Please enter the validation clientname:"))
-    expect(@knife.validation_client_name).to eq("my-validator")
-  end
-
-  it "asks the users for the location of the validation key" do
-    @knife.ask_user_for_config
-    expect(@out.string).to match(Regexp.escape("Please enter the location of the validation key: [#{default_validator_key}]"))
-    if windows?
-      expect(@knife.validation_key.capitalize).to eq(default_validator_key_win32.capitalize)
-    else
-      expect(@knife.validation_key).to eq(default_validator_key)
-    end
-  end
-
-  it "should not ask the users for the location of the validation key if --validation_key is specified" do
-    @knife.config[:validation_key] = "/home/you/.chef/my-validation.pem"
-    @knife.ask_user_for_config
-    expect(@out.string).not_to match(Regexp.escape("Please enter the location of the validation key:"))
-    if windows?
-      expect(@knife.validation_key).to match %r{^[A-Za-z]:/home/you/\.chef/my-validation\.pem$}
-    else
-      expect(@knife.validation_key).to eq("/home/you/.chef/my-validation.pem")
-    end
-  end
-
   it "should not ask the user for anything if -i and all other properties are specified" do
     @knife.config[:initial] = true
     @knife.config[:chef_server_url] = "http://localhost:5000"
     @knife.config[:node_name] = "testnode"
     @knife.config[:admin_client_name] = "my-webui"
     @knife.config[:admin_client_key] = "/home/you/.chef/my-webui.pem"
-    @knife.config[:validation_client_name] = "my-validator"
-    @knife.config[:validation_key] = "/home/you/.chef/my-validation.pem"
-    @knife.config[:repository] = ""
     @knife.config[:client_key] = "/home/you/a-new-user.pem"
     allow(Etc).to receive(:getlogin).and_return("a-new-user")
 
@@ -184,40 +141,33 @@ describe Chef::Knife::Configure do
     expect(@knife.admin_client_name).to eq("my-webui")
     if windows?
       expect(@knife.admin_client_key).to match %r{^[A-Za-z]:/home/you/\.chef/my-webui\.pem$}
-      expect(@knife.validation_key).to match %r{^[A-Za-z]:/home/you/\.chef/my-validation\.pem$}
       expect(@knife.new_client_key).to match %r{^[A-Za-z]:/home/you/a-new-user\.pem$}
     else
       expect(@knife.admin_client_key).to eq("/home/you/.chef/my-webui.pem")
-      expect(@knife.validation_key).to eq("/home/you/.chef/my-validation.pem")
       expect(@knife.new_client_key).to eq("/home/you/a-new-user.pem")
     end
-    expect(@knife.validation_client_name).to eq("my-validator")
-    expect(@knife.chef_repo).to eq("")
   end
 
   it "writes the new data to a config file" do
-    allow(File).to receive(:expand_path).with("/home/you/.chef/knife.rb").and_return("/home/you/.chef/knife.rb")
+    allow(Chef::Util::PathHelper).to receive(:home).with(".chef").and_return("/home/you/.chef")
+    allow(File).to receive(:expand_path).with("/home/you/.chef/credentials").and_return("/home/you/.chef/credentials")
     allow(File).to receive(:expand_path).with("/home/you/.chef/#{Etc.getlogin}.pem").and_return("/home/you/.chef/#{Etc.getlogin}.pem")
-    allow(File).to receive(:expand_path).with(default_validator_key).and_return(default_validator_key)
     allow(File).to receive(:expand_path).with(default_admin_key).and_return(default_admin_key)
     expect(FileUtils).to receive(:mkdir_p).with("/home/you/.chef")
     config_file = StringIO.new
-    expect(::File).to receive(:open).with("/home/you/.chef/knife.rb", "w").and_yield config_file
+    expect(::File).to receive(:open).with("/home/you/.chef/credentials", "w").and_yield config_file
     @knife.config[:repository] = "/home/you/chef-repo"
     @knife.run
-    expect(config_file.string).to match(/^node_name[\s]+'#{Etc.getlogin}'$/)
-    expect(config_file.string).to match(%r{^client_key[\s]+'/home/you/.chef/#{Etc.getlogin}.pem'$})
-    expect(config_file.string).to match(/^validation_client_name\s+'chef-validator'$/)
-    expect(config_file.string).to match(%r{^validation_key\s+'#{default_validator_key}'$})
-    expect(config_file.string).to match(%r{^chef_server_url\s+'#{default_server_url}'$})
-    expect(config_file.string).to match(%r{cookbook_path\s+\[ '/home/you/chef-repo/cookbooks' \]})
+    expect(config_file.string).to match(/^client_name[\s]+=[\s]+'#{Etc.getlogin}'$/)
+    expect(config_file.string).to match(%r{^client_key[\s]+=[\s]+'/home/you/.chef/#{Etc.getlogin}.pem'$})
+    expect(config_file.string).to match(%r{^chef_server_url\s+=[\s]+'#{default_server_url}'$})
   end
 
   it "creates a new client when given the --initial option" do
-    expect(File).to receive(:expand_path).with("/home/you/.chef/knife.rb").and_return("/home/you/.chef/knife.rb")
+    allow(Chef::Util::PathHelper).to receive(:home).with(".chef").and_return("/home/you/.chef")
+    expect(File).to receive(:expand_path).with("/home/you/.chef/credentials").and_return("/home/you/.chef/credentials")
     expect(File).to receive(:expand_path).with("/home/you/.chef/a-new-user.pem").and_return("/home/you/.chef/a-new-user.pem")
-    expect(File).to receive(:expand_path).with(default_validator_key).and_return(default_validator_key)
-    expect(File).to receive(:expand_path).with(default_admin_key).and_return(default_admin_key)
+    allow(File).to receive(:expand_path).with(default_admin_key).and_return(default_admin_key)
     Chef::Config[:node_name] = "webmonkey.example.com"
 
     user_command = Chef::Knife::UserCreate.new
@@ -227,7 +177,7 @@ describe Chef::Knife::Configure do
 
     allow(Chef::Knife::UserCreate).to receive(:new).and_return(user_command)
     expect(FileUtils).to receive(:mkdir_p).with("/home/you/.chef")
-    expect(::File).to receive(:open).with("/home/you/.chef/knife.rb", "w")
+    expect(::File).to receive(:open).with("/home/you/.chef/credentials", "w")
     @knife.config[:initial] = true
     @knife.config[:user_password] = "blah"
     @knife.run
