@@ -3,7 +3,7 @@
 # Author:: Tim Hinderliter (<tim@chef.io>)
 # Author:: Daniel DeLeo (<dan@chef.io>)
 # Author:: John Keiser (<jkeiser@chef.io>)
-# Copyright:: Copyright 2008-2016, Chef Software Inc.
+# Copyright:: Copyright 2008-2017, Chef Software Inc.
 # License:: Apache License, Version 2.0
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -28,21 +28,29 @@ describe Chef::Knife::UI do
       :verbosity => 0,
       :yes => nil,
       :format => "summary",
+      :field_separator => ".",
     }
     @ui = Chef::Knife::UI.new(@out, @err, @in, @config)
-    Chef::Config[:treat_deprecation_warnings_as_errors] = false
+  end
+
+  class TestObject < OpenStruct
+    def self.from_hash(hsh)
+      new(hsh)
+    end
   end
 
   describe "edit" do
     ruby_for_json = { "foo" => "bar" }
+    ruby_from_json = TestObject.from_hash(ruby_for_json)
     json_from_ruby = "{\n  \"foo\": \"bar\"\n}"
     json_from_editor = "{\n  \"bar\": \"foo\"\n}"
-    ruby_from_editor = { "bar" => "foo" }
+    ruby_from_editor = TestObject.from_hash({ "bar" => "foo" })
     my_editor = "veeeye"
     temp_path = "/tmp/bar/baz"
 
-    let(:subject) { @ui.edit_data(ruby_for_json, parse_output) }
+    let(:subject) { @ui.edit_data(ruby_for_json, parse_output, object_class: klass) }
     let(:parse_output) { false }
+    let(:klass) { nil }
 
     context "when editing is disabled" do
       before do
@@ -56,17 +64,18 @@ describe Chef::Knife::UI do
       end
       context "when parse_output is true" do
         let(:parse_output) { true }
+        let(:klass) { TestObject }
         it "returns a ruby object" do
-          expect(subject).to eql(ruby_for_json)
+          expect(subject).to eql(ruby_from_json)
         end
-
-        it "gives a deprecation error" do
-          Chef::Config[:treat_deprecation_warnings_as_errors] = true
-          expect { subject }.to raise_error Chef::Exceptions::DeprecatedFeatureError,
-            /Auto inflation of JSON data is deprecated./
+        context "but no object class is provided" do
+          let(:klass) { nil }
+          it "raises an error" do
+            expect { subject }.to raise_error ArgumentError,
+              /Please pass in the object class to hydrate or use #edit_hash/
+          end
         end
       end
-
     end
 
     context "when editing is enabled" do
@@ -93,6 +102,7 @@ describe Chef::Knife::UI do
         end
         context "when parse_output is true" do
           let(:parse_output) { true }
+          let(:klass) { TestObject }
           it "returns an edited ruby object" do
             expect(subject).to eql(ruby_from_editor)
           end
@@ -144,6 +154,7 @@ describe Chef::Knife::UI do
 
         context "when parse_output is true" do
           let(:parse_output) { true }
+          let(:klass) { TestObject }
           it "returns an edited ruby object" do
             expect(subject).to eql(ruby_from_editor)
           end
@@ -377,18 +388,48 @@ EOM
       end
 
       it "should return the name attribute" do
-        allow_any_instance_of(Chef::Node).to receive(:name).and_return("chef.localdomain")
         input = Chef::Node.new
+        input.name("chef.localdomain")
         @ui.config[:attribute] = "name"
         expect(@ui.format_for_display(input)).to eq( { "chef.localdomain" => { "name" => "chef.localdomain" } })
       end
 
+      it "should return a 'class' attribute and not the node.class" do
+        input = Chef::Node.new
+        input.default["class"] = "classy!"
+        @ui.config[:attribute] = "class"
+        expect(@ui.format_for_display(input)).to eq( { nil => { "class" => "classy!" } } )
+      end
+
+      it "should return the chef_environment attribute" do
+        input = Chef::Node.new
+        input.chef_environment = "production-partner-load-integration-preview-testing"
+        @ui.config[:attribute] = "chef_environment"
+        expect(@ui.format_for_display(input)).to eq( { nil => { "chef_environment" => "production-partner-load-integration-preview-testing" } } )
+      end
+
+      it "works with arrays" do
+        input = Chef::Node.new
+        input.default["array"] = %w{zero one two}
+        @ui.config[:attribute] = "array.1"
+        expect(@ui.format_for_display(input)).to eq( { nil => { "array.1" => "one" } } )
+      end
+
       it "returns nil when given an attribute path that isn't a name or attribute" do
         input = { "keys" => { "keys" => "values" }, "hi" => "ho", "id" => "sample-data-bag-item" }
         non_existing_path = "nope.nada.nothingtoseehere"
         @ui.config[:attribute] = non_existing_path
         expect(@ui.format_for_display(input)).to eq({ "sample-data-bag-item" => { non_existing_path => nil } })
       end
+
+      describe "when --field-separator is passed" do
+        it "honors that separator" do
+          input = { "keys" => { "with spaces" => { "open" => { "doors" => { "with many.dots" => "when asked" } } } } }
+          @ui.config[:field_separator] = ";"
+          @ui.config[:attribute] = "keys;with spaces;open;doors;with many.dots"
+          expect(@ui.format_for_display(input)).to eq({ nil => { "keys;with spaces;open;doors;with many.dots" => "when asked" } })
+        end
+      end
     end
 
     describe "with --run-list passed" do
