@@ -1,6 +1,6 @@
 #
 # Author:: Matthew Kent (<mkent@magoazul.com>)
-# Copyright:: Copyright (c) 2011 Opscode, Inc.
+# Copyright:: Copyright 2011-2016, Chef Software Inc.
 # License:: Apache License, Version 2.0
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -16,12 +16,12 @@
 # limitations under the License.
 #
 
-require 'spec_helper'
-require 'chef/mash'
+require "spec_helper"
+require "chef/mash"
 
 describe Mash do
   it "should duplicate a simple key/value mash to a new mash" do
-    data = {:x=>"one", :y=>"two", :z=>"three"}
+    data = { :x => "one", :y => "two", :z => "three" }
     @orig = Mash.new(data)
     @copy = @orig.dup
     expect(@copy.to_hash).to eq(Mash.new(data).to_hash)
@@ -30,21 +30,21 @@ describe Mash do
   end
 
   it "should duplicate a mash with an array to a new mash" do
-    data = {:x=>"one", :y=>"two", :z=>[1,2,3]}
+    data = { :x => "one", :y => "two", :z => [1, 2, 3] }
     @orig = Mash.new(data)
     @copy = @orig.dup
     expect(@copy.to_hash).to eq(Mash.new(data).to_hash)
     @copy[:z] << 4
-    expect(@orig[:z]).to eq([1,2,3])
+    expect(@orig[:z]).to eq([1, 2, 3])
   end
 
   it "should duplicate a nested mash to a new mash" do
-    data = {:x=>"one", :y=>"two", :z=>Mash.new({:a=>[1,2,3]})}
+    data = { :x => "one", :y => "two", :z => Mash.new({ :a => [1, 2, 3] }) }
     @orig = Mash.new(data)
     @copy = @orig.dup
     expect(@copy.to_hash).to eq(Mash.new(data).to_hash)
     @copy[:z][:a] << 4
-    expect(@orig[:z][:a]).to eq([1,2,3])
+    expect(@orig[:z][:a]).to eq([1, 2, 3])
   end
 
   # add more!
