@@ -1,6 +1,6 @@
 #
 # Author:: Adam Jacob (<adam@chef.io>)
-# Copyright:: Copyright 2008-2016, Chef Software Inc.
+# Copyright:: Copyright 2008-2018, Chef Software Inc.
 # License:: Apache License, Version 2.0
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -342,6 +342,17 @@ describe Chef::Mixin::ParamsValidate do
     end.to raise_error(Chef::Exceptions::ValidationFailed)
   end
 
+  it "allows a custom validation message" do
+    expect do
+      @vo.validate({ :not_blank => "should pass" },
+                   { :not_blank => { :cannot_be => [ :nil, :empty ], validation_message: "my validation message" } })
+    end.not_to raise_error
+    expect do
+      @vo.validate({ :not_blank => "" },
+                   { :not_blank => { :cannot_be => [ :nil, :empty ], validation_message: "my validation message" } })
+    end.to raise_error(Chef::Exceptions::ValidationFailed, "my validation message")
+  end
+
   it "should set and return a value, then return the same value" do
     value = "meow"
     expect(@vo.set_or_return(:test, value, {}).object_id).to eq(value.object_id)
