@@ -556,7 +556,7 @@ describe Chef::Provider::Deploy do
       @resource.deploy_to("/my/app")
       expect(mock_execution).to receive(:user).with("notCoolMan")
       expect(mock_execution).to receive(:group).with("Ggroup")
-      expect(mock_execution).to receive(:cwd) {|*args|
+      expect(mock_execution).to receive(:cwd) { |*args|
         if args.empty?
           nil
         else
@@ -595,7 +595,7 @@ describe Chef::Provider::Deploy do
 
       callback_code = Proc.new do
         snitch = 42
-        temp_collection = self.resource_collection
+        temp_collection = resource_collection
         run("tehMice")
         snitch = temp_collection.lookup("execute[tehMice]")
       end
