@@ -28,12 +28,12 @@ describe Chef::Provider::Group::Dscl do
     @provider = Chef::Provider::Group::Dscl.new(@new_resource, @run_context)
     @provider.current_resource = @current_resource
 
-    @status = double(:stdout => "\n", :stderr => "", :exitstatus => 0)
+    @status = double(stdout: "\n", stderr: "", exitstatus: 0)
     allow(@provider).to receive(:shell_out).and_return(@status)
   end
 
   it "should run shell_out with the supplied array of arguments appended to the dscl command" do
-    expect(@provider).to receive(:shell_out).with("dscl . -cmd /Path arg1 arg2")
+    expect(@provider).to receive(:shell_out).with("dscl", ".", "-cmd", "/Path", "arg1", "arg2")
     @provider.dscl("cmd", "/Path", "arg1", "arg2")
   end
 
@@ -51,24 +51,24 @@ describe Chef::Provider::Group::Dscl do
     end
 
     it "should run dscl with the supplied cmd /Path args" do
-      expect(@provider).to receive(:dscl).with("cmd /Path args")
-      @provider.safe_dscl("cmd /Path args")
+      expect(@provider).to receive(:dscl).with(*"cmd /Path args".split(" "))
+      @provider.safe_dscl(*"cmd /Path args".split(" "))
     end
 
     describe "with the dscl command returning a non zero exit status for a delete" do
       before do
-        @status = double("Process::Status", :exitstatus => 1)
+        @status = double("Process::Status", exitstatus: 1)
         allow(@provider).to receive(:dscl).and_return(["cmd", @status, "stdout", "stderr"])
       end
 
       it "should return an empty string of standard output for a delete" do
-        safe_dscl_retval = @provider.safe_dscl("delete /Path args")
+        safe_dscl_retval = @provider.safe_dscl(*"delete /Path args".split(" "))
         expect(safe_dscl_retval).to be_a_kind_of(String)
         expect(safe_dscl_retval).to eq("")
       end
 
       it "should raise an exception for any other command" do
-        expect { @provider.safe_dscl("cmd /Path arguments") }.to raise_error(Chef::Exceptions::Group)
+        expect { @provider.safe_dscl(*"cmd /Path arguments".split(" ")) }.to raise_error(Chef::Exceptions::Group)
       end
     end
 
@@ -78,13 +78,13 @@ describe Chef::Provider::Group::Dscl do
       end
 
       it "should raise an exception" do
-        expect { @provider.safe_dscl("cmd /Path arguments") }.to raise_error(Chef::Exceptions::Group)
+        expect { @provider.safe_dscl(*"cmd /Path arguments".split(" ")) }.to raise_error(Chef::Exceptions::Group)
       end
     end
 
     describe "with the dscl command returning a zero exit status" do
       it "should return the third array element, the string of standard output" do
-        safe_dscl_retval = @provider.safe_dscl("cmd /Path args")
+        safe_dscl_retval = @provider.safe_dscl(*"cmd /Path args".split(" "))
         expect(safe_dscl_retval).to be_a_kind_of(String)
         expect(safe_dscl_retval).to eq("stdout")
       end
@@ -99,7 +99,7 @@ describe Chef::Provider::Group::Dscl do
     end
 
     it "should run safe_dscl with list /Groups gid" do
-      expect(@provider).to receive(:safe_dscl).with("list /Groups gid")
+      expect(@provider).to receive(:safe_dscl).with(*"list /Groups gid".split(" "))
       @provider.get_free_gid
     end
 
@@ -117,11 +117,16 @@ describe Chef::Provider::Group::Dscl do
     before do
       @node = Chef::Node.new
       @provider = Chef::Provider::Group::Dscl.new(@node, @new_resource)
-      allow(@provider).to receive(:safe_dscl).and_return("\naj      500\n")
+      allow(@provider).to receive(:safe_dscl).and_return(<<-eos
+        someprogram		somethingElse:gid = (
+            500
+        )
+        eos
+      )
     end
 
-    it "should run safe_dscl with list /Groups gid" do
-      expect(@provider).to receive(:safe_dscl).with("list /Groups gid")
+    it "should run safe_dscl with search /Groups gid" do
+      expect(@provider).to receive(:safe_dscl).with(*"search /Groups PrimaryGroupID 500".split(" "))
       @provider.gid_used?(500)
     end
 
@@ -130,7 +135,11 @@ describe Chef::Provider::Group::Dscl do
     end
 
     it "should return false for an unused gid number" do
-      expect(@provider.gid_used?(501)).to be_falsey
+      expect(@provider.gid_used?(0)).to be_falsey
+      expect(@provider.gid_used?(50)).to be_falsey
+      expect(@provider.gid_used?(5000)).to be_falsey
+      expect(@provider.gid_used?(1500)).to be_falsey
+      expect(@provider.gid_used?(18)).to be_falsey
     end
 
     it "should return false if not given any valid gid number" do
@@ -171,8 +180,8 @@ describe Chef::Provider::Group::Dscl do
     describe "with a valid gid number which is not already in use" do
       it "should run safe_dscl with create /Groups/group PrimaryGroupID gid" do
         allow(@provider).to receive(:get_free_gid).and_return(50)
-        expect(@provider).to receive(:safe_dscl).with("list /Groups gid")
-        expect(@provider).to receive(:safe_dscl).with("create /Groups/aj PrimaryGroupID 50").and_return(true)
+        expect(@provider).to receive(:safe_dscl).with(*"search /Groups PrimaryGroupID 50".split(" ")).and_return("")
+        expect(@provider).to receive(:safe_dscl).with("create", "/Groups/aj", "PrimaryGroupID", 50).and_return(true)
         @provider.set_gid
       end
     end
@@ -182,8 +191,8 @@ describe Chef::Provider::Group::Dscl do
 
     describe "with existing members in the current resource and append set to false in the new resource" do
       before do
-        allow(@new_resource).to receive(:members).and_return([])
-        allow(@new_resource).to receive(:append).and_return(false)
+        @new_resource.members([])
+        @new_resource.append(false)
         allow(@current_resource).to receive(:members).and_return(%w{all your base})
       end
 
@@ -193,8 +202,8 @@ describe Chef::Provider::Group::Dscl do
       end
 
       it "should run safe_dscl with create /Groups/group GroupMembership to clear the Group's UID list" do
-        expect(@provider).to receive(:safe_dscl).with("create /Groups/aj GroupMembers ''").and_return(true)
-        expect(@provider).to receive(:safe_dscl).with("create /Groups/aj GroupMembership ''").and_return(true)
+        expect(@provider).to receive(:safe_dscl).with("create", "/Groups/aj", "GroupMembers", "").and_return(true)
+        expect(@provider).to receive(:safe_dscl).with("create", "/Groups/aj", "GroupMembership", "").and_return(true)
         @provider.set_members
       end
     end
@@ -211,9 +220,9 @@ describe Chef::Provider::Group::Dscl do
       end
 
       it "should run safe_dscl with append /Groups/group GroupMembership and group members all, your, base" do
-        expect(@provider).to receive(:safe_dscl).with("create /Groups/aj GroupMembers ''").and_return(true)
-        expect(@provider).to receive(:safe_dscl).with("append /Groups/aj GroupMembership all your base").and_return(true)
-        expect(@provider).to receive(:safe_dscl).with("create /Groups/aj GroupMembership ''").and_return(true)
+        expect(@provider).to receive(:safe_dscl).with("create", "/Groups/aj", "GroupMembers", "").and_return(true)
+        expect(@provider).to receive(:safe_dscl).with(*"append /Groups/aj GroupMembership all your base".split(" ")).and_return(true)
+        expect(@provider).to receive(:safe_dscl).with("create", "/Groups/aj", "GroupMembership", "").and_return(true)
         @provider.set_members
       end
     end
@@ -232,20 +241,20 @@ describe Chef::Provider::Group::Dscl do
   end
 
   describe "when loading the current system state" do
-    before (:each) do
+    before(:each) do
       @provider.action = :create
       @provider.load_current_resource
       @provider.define_resource_requirements
     end
 
     it "raises an error if the required binary /usr/bin/dscl doesn't exist" do
-      expect(File).to receive(:exists?).with("/usr/bin/dscl").and_return(false)
+      expect(File).to receive(:exist?).with("/usr/bin/dscl").and_return(false)
 
       expect { @provider.process_resource_requirements }.to raise_error(Chef::Exceptions::Group)
     end
 
     it "doesn't raise an error if /usr/bin/dscl exists" do
-      allow(File).to receive(:exists?).and_return(true)
+      allow(File).to receive(:exist?).and_return(true)
       expect { @provider.process_resource_requirements }.not_to raise_error
     end
   end
@@ -254,8 +263,8 @@ describe Chef::Provider::Group::Dscl do
     it "creates the group, password field, gid, and sets group membership" do
       expect(@provider).to receive(:set_gid).and_return(true)
       expect(@provider).to receive(:set_members).and_return(true)
-      expect(@provider).to receive(:safe_dscl).with("create /Groups/aj Password '*'")
-      expect(@provider).to receive(:safe_dscl).with("create /Groups/aj")
+      expect(@provider).to receive(:safe_dscl).with(*"create /Groups/aj Password *".split(" "))
+      expect(@provider).to receive(:safe_dscl).with(*"create /Groups/aj".split(" "))
       @provider.create_group
     end
   end
@@ -265,8 +274,8 @@ describe Chef::Provider::Group::Dscl do
       @current_resource.group_name("oldval")
       @new_resource.group_name("newname")
       expect(@provider).to receive(:set_members).and_return(true)
-      expect(@provider).to receive(:safe_dscl).with("create /Groups/newname")
-      expect(@provider).to receive(:safe_dscl).with("create /Groups/newname Password '*'")
+      expect(@provider).to receive(:safe_dscl).with(*"create /Groups/newname".split(" "))
+      expect(@provider).to receive(:safe_dscl).with(*"create /Groups/newname Password *".split(" "))
       @provider.manage_group
     end
 
@@ -287,7 +296,7 @@ describe Chef::Provider::Group::Dscl do
 
   describe "remove_group" do
     it "should run safe_dscl with delete /Groups/group and with the new resources group name" do
-      expect(@provider).to receive(:safe_dscl).with("delete /Groups/aj").and_return(true)
+      expect(@provider).to receive(:safe_dscl).with(*"delete /Groups/aj".split(" ")).and_return(true)
       @provider.remove_group
     end
   end
@@ -315,17 +324,17 @@ RecordName: com.apple.aj
 RecordType: dsRecTypeStandard:Groups
 GroupMembership: waka bar
 EOF
-    allow(@provider).to receive(:safe_dscl).with("read /Groups/aj").and_return(@output)
+    allow(@provider).to receive(:safe_dscl).with(*"read /Groups/aj".split(" ")).and_return(@output)
     @current_resource = @provider.load_current_resource
 
   end
 
   it "should parse gid properly" do
-    allow(File).to receive(:exists?).and_return(true)
+    allow(File).to receive(:exist?).and_return(true)
     expect(@current_resource.gid).to eq("999")
   end
   it "should parse members properly" do
-    allow(File).to receive(:exists?).and_return(true)
+    allow(File).to receive(:exist?).and_return(true)
     expect(@current_resource.members).to eq(%w{waka bar})
   end
 end
