@@ -103,26 +103,26 @@ describe Chef::Provider::User do
 
     it "should return false if append is true and the group member(s) already exists" do
       @current_resource.members << "extra_user"
-      allow(@new_resource).to receive(:append).and_return(true)
+      @new_resource.append(true)
       expect(@provider.compare_group).to be_falsey
     end
 
     it "should return true if append is true and the group member(s) do not already exist" do
       @new_resource.members << "extra_user"
-      allow(@new_resource).to receive(:append).and_return(true)
+      @new_resource.append(true)
       expect(@provider.compare_group).to be_truthy
     end
 
     it "should return false if append is true and excluded_members include a non existing member" do
       @new_resource.excluded_members << "extra_user"
-      allow(@new_resource).to receive(:append).and_return(true)
+      @new_resource.append(true)
       expect(@provider.compare_group).to be_falsey
     end
 
     it "should return true if the append is true and excluded_members include an existing user" do
       @new_resource.members.each { |m| @new_resource.excluded_members << m }
       @new_resource.members.clear
-      allow(@new_resource).to receive(:append).and_return(true)
+      @new_resource.append(true)
       expect(@provider.compare_group).to be_truthy
     end
 
