@@ -16,7 +16,7 @@
 # limitations under the License.
 #
 
-#require File.expand_path(File.join(File.dirname(__FILE__), "..", "..", "spec_helper"))
+# require File.expand_path(File.join(File.dirname(__FILE__), "..", "..", "spec_helper"))
 require "spec_helper"
 require "chef/exceptions"
 
@@ -26,7 +26,7 @@ describe Chef::Provider::Ifconfig do
     @cookbook_collection = Chef::CookbookCollection.new([])
     @events = Chef::EventDispatch::Dispatcher.new
     @run_context = Chef::RunContext.new(@node, @cookbook_collection, @events)
-    #This new_resource can be called anything --> it is not the same as in ifconfig.rb
+    # This new_resource can be called anything --> it is not the same as in ifconfig.rb
     @new_resource = Chef::Resource::Ifconfig.new("10.0.0.1", @run_context)
     @new_resource.mask "255.255.254.0"
     @new_resource.metric "1"
@@ -35,15 +35,22 @@ describe Chef::Provider::Ifconfig do
     @provider = Chef::Provider::Ifconfig.new(@new_resource, @run_context)
     @current_resource = Chef::Resource::Ifconfig.new("10.0.0.1", @run_context)
 
-    status = double("Status", :exitstatus => 0)
+    status = double("Status", exitstatus: 0)
     @provider.instance_variable_set("@status", status)
     @provider.current_resource = @current_resource
-
   end
+
   describe Chef::Provider::Ifconfig, "load_current_resource" do
+    let(:net_tools_version) { StringIO.new <<-EOS }
+net-tools 1.60
+ifconfig 1.42 (2001-04-13)
+EOS
+
     before do
-      @status = double(:stdout => "", :exitstatus => 1)
-      allow(@provider).to receive(:shell_out).and_return(@status)
+      ifconfig = double(stdout: "", exitstatus: 1)
+      allow(@provider).to receive(:shell_out).and_return(ifconfig)
+      ifconfig_version = double(stdout: "", stderr: net_tools_version, exitstatus: 4)
+      allow(@provider).to receive(:shell_out).with("ifconfig --version").and_return(ifconfig_version)
       @provider.load_current_resource
     end
     it "should track state of ifconfig failure" do
@@ -57,11 +64,10 @@ describe Chef::Provider::Ifconfig do
   describe Chef::Provider::Ifconfig, "action_add" do
 
     it "should add an interface if it does not exist" do
-      #@provider.stub(:run_command).and_return(true)
       allow(@provider).to receive(:load_current_resource)
       @current_resource.inet_addr nil
       command = "ifconfig eth0 10.0.0.1 netmask 255.255.254.0 metric 1 mtu 1500"
-      expect(@provider).to receive(:run_command).with(:command => command)
+      expect(@provider).to receive(:shell_out!).with(*command.split(" "))
       expect(@provider).to receive(:generate_config)
 
       @provider.run_action(:add)
@@ -72,7 +78,7 @@ describe Chef::Provider::Ifconfig do
       allow(@provider).to receive(:load_current_resource)
       @new_resource.target "172.16.32.2"
       command = "ifconfig eth0 172.16.32.2 netmask 255.255.254.0 metric 1 mtu 1500"
-      expect(@provider).to receive(:run_command).with(:command => command)
+      expect(@provider).to receive(:shell_out!).with(*command.split(" "))
 
       @provider.run_action(:add)
       expect(@new_resource).to be_updated
@@ -80,7 +86,7 @@ describe Chef::Provider::Ifconfig do
 
     it "should not add an interface if it already exists" do
       allow(@provider).to receive(:load_current_resource)
-      expect(@provider).not_to receive(:run_command)
+      expect(@provider).not_to receive(:shell_out!)
       @current_resource.inet_addr "10.0.0.1"
       expect(@provider).to receive(:generate_config)
 
@@ -88,9 +94,9 @@ describe Chef::Provider::Ifconfig do
       expect(@new_resource).not_to be_updated
     end
 
-    #We are not testing this case with the assumption that anyone writing the cookbook would not make a typo == lo
-    #it "should add a blank command if the #{@new_resource.device} == lo" do
-    #end
+    # We are not testing this case with the assumption that anyone writing the cookbook would not make a typo == lo
+    # it "should add a blank command if the #{@new_resource.device} == lo" do
+    # end
   end
 
   describe Chef::Provider::Ifconfig, "action_enable" do
@@ -99,7 +105,7 @@ describe Chef::Provider::Ifconfig do
       allow(@provider).to receive(:load_current_resource)
       @current_resource.inet_addr nil
       command = "ifconfig eth0 10.0.0.1 netmask 255.255.254.0 metric 1 mtu 1500"
-      expect(@provider).to receive(:run_command).with(:command => command)
+      expect(@provider).to receive(:shell_out!).with(*command.split(" "))
       expect(@provider).not_to receive(:generate_config)
 
       @provider.run_action(:enable)
@@ -110,7 +116,7 @@ describe Chef::Provider::Ifconfig do
       allow(@provider).to receive(:load_current_resource)
       @new_resource.target "172.16.32.2"
       command = "ifconfig eth0 172.16.32.2 netmask 255.255.254.0 metric 1 mtu 1500"
-      expect(@provider).to receive(:run_command).with(:command => command)
+      expect(@provider).to receive(:shell_out!).with(*command.split(" "))
 
       @provider.run_action(:enable)
       expect(@new_resource).to be_updated
@@ -133,7 +139,7 @@ describe Chef::Provider::Ifconfig do
       allow(@provider).to receive(:load_current_resource)
       @current_resource.device "eth0"
       command = "ifconfig #{@new_resource.device} down"
-      expect(@provider).to receive(:run_command).with(:command => command)
+      expect(@provider).to receive(:shell_out!).with(*command.split(" "))
       expect(@provider).to receive(:delete_config)
 
       @provider.run_action(:delete)
@@ -142,7 +148,7 @@ describe Chef::Provider::Ifconfig do
 
     it "should not delete interface if it does not exist" do
       allow(@provider).to receive(:load_current_resource)
-      expect(@provider).not_to receive(:run_command)
+      expect(@provider).not_to receive(:shell_out!)
       expect(@provider).to receive(:delete_config)
 
       @provider.run_action(:delete)
@@ -156,7 +162,7 @@ describe Chef::Provider::Ifconfig do
       allow(@provider).to receive(:load_current_resource)
       @current_resource.device "eth0"
       command = "ifconfig #{@new_resource.device} down"
-      expect(@provider).to receive(:run_command).with(:command => command)
+      expect(@provider).to receive(:shell_out!).with(*command.split(" "))
       expect(@provider).not_to receive(:delete_config)
 
       @provider.run_action(:disable)
@@ -165,7 +171,7 @@ describe Chef::Provider::Ifconfig do
 
     it "should not delete interface if it does not exist" do
       allow(@provider).to receive(:load_current_resource)
-      expect(@provider).not_to receive(:run_command)
+      expect(@provider).not_to receive(:shell_out!)
       expect(@provider).not_to receive(:delete_config)
 
       @provider.run_action(:disable)
@@ -179,7 +185,7 @@ describe Chef::Provider::Ifconfig do
       allow(@provider).to receive(:load_current_resource)
       @current_resource.device "eth0"
       command = "ifconfig #{@new_resource.device} down"
-      expect(@provider).to receive(:run_command).with(:command => command)
+      expect(@provider).to receive(:shell_out!).with(*command.split(" "))
       expect(@provider).to receive(:delete_config)
 
       @provider.run_action(:delete)
@@ -190,7 +196,7 @@ describe Chef::Provider::Ifconfig do
       # This is so that our fake values do not get overwritten
       allow(@provider).to receive(:load_current_resource)
       # This is so that nothing actually runs
-      expect(@provider).not_to receive(:run_command)
+      expect(@provider).not_to receive(:shell_out!)
       expect(@provider).to receive(:delete_config)
 
       @provider.run_action(:delete)
