@@ -1,6 +1,6 @@
 #
 # Author:: Adam Jacob (<adam@chef.io>)
-# Copyright:: Copyright 2008-2016, Chef Software Inc.
+# Copyright:: Copyright 2008-2017, Chef Software Inc.
 # License:: Apache License, Version 2.0
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -51,7 +51,7 @@ irssi:
 
         it "should create a current resource with the name of the new_resource" do
           expect(@provider).to receive(:shell_out!).with(
-            "apt-cache policy #{@new_resource.package_name}",
+            "apt-cache", "policy", @new_resource.package_name,
             :env => { "DEBIAN_FRONTEND" => "noninteractive" },
             :timeout => @timeout
           ).and_return(@shell_out)
@@ -91,7 +91,7 @@ N: Unable to locate package conic-smarms
           POLICY_STDOUT
           policy = double(:stdout => policy_out, :exitstatus => 0)
           expect(@provider).to receive(:shell_out!).with(
-            "apt-cache policy conic-smarms",
+            "apt-cache", "policy", "conic-smarms",
             :env => { "DEBIAN_FRONTEND" => "noninteractive" },
             :timeout => @timeout
           ).and_return(policy)
@@ -100,7 +100,7 @@ N: Unable to locate package conic-smarms
           SHOWPKG_STDOUT
           showpkg = double(:stdout => showpkg_out, :exitstatus => 0)
           expect(@provider).to receive(:shell_out!).with(
-            "apt-cache showpkg conic-smarms",
+            "apt-cache", "showpkg", "conic-smarms",
             :env => { "DEBIAN_FRONTEND" => "noninteractive" },
             :timeout => @timeout
           ).and_return(showpkg)
@@ -119,7 +119,7 @@ libmysqlclient15-dev:
           VPKG_STDOUT
           virtual_package = double(:stdout => virtual_package_out, :exitstatus => 0)
           expect(@provider).to receive(:shell_out!).with(
-            "apt-cache policy libmysqlclient15-dev",
+            "apt-cache", "policy", "libmysqlclient15-dev",
             :env => { "DEBIAN_FRONTEND" => "noninteractive" },
             :timeout => @timeout
           ).and_return(virtual_package)
@@ -143,7 +143,7 @@ libmysqlclient-dev 5.1.41-3ubuntu12
           SHOWPKG_STDOUT
           showpkg = double(:stdout => showpkg_out, :exitstatus => 0)
           expect(@provider).to receive(:shell_out!).with(
-            "apt-cache showpkg libmysqlclient15-dev",
+            "apt-cache", "showpkg", "libmysqlclient15-dev",
             :env => { "DEBIAN_FRONTEND" => "noninteractive" },
             :timeout => @timeout
           ).and_return(showpkg)
@@ -162,7 +162,7 @@ libmysqlclient-dev:
           RPKG_STDOUT
           real_package = double(:stdout => real_package_out, :exitstatus => 0)
           expect(@provider).to receive(:shell_out!).with(
-            "apt-cache policy libmysqlclient-dev",
+            "apt-cache", "policy", "libmysqlclient-dev",
             :env => { "DEBIAN_FRONTEND" => "noninteractive" },
             :timeout => @timeout
           ).and_return(real_package)
@@ -179,7 +179,7 @@ mp3-decoder:
           VPKG_STDOUT
           virtual_package = double(:stdout => virtual_package_out, :exitstatus => 0)
           expect(@provider).to receive(:shell_out!).with(
-            "apt-cache policy mp3-decoder",
+            "apt-cache", "policy", "mp3-decoder",
             :env => { "DEBIAN_FRONTEND" => "noninteractive" },
             :timeout => @timeout
           ).and_return(virtual_package)
@@ -206,7 +206,7 @@ mpg123 1.12.1-0ubuntu1
           SHOWPKG_STDOUT
           showpkg = double(:stdout => showpkg_out, :exitstatus => 0)
           expect(@provider).to receive(:shell_out!).with(
-            "apt-cache showpkg mp3-decoder",
+            "apt-cache", "showpkg", "mp3-decoder",
             :env => { "DEBIAN_FRONTEND" => "noninteractive" },
             :timeout => @timeout
           ).and_return(showpkg)
@@ -217,10 +217,10 @@ mpg123 1.12.1-0ubuntu1
           @new_resource = Chef::Resource::AptPackage.new("irssi", @run_context)
           @provider = Chef::Provider::Package::Apt.new(@new_resource, @run_context)
 
-          allow(@new_resource).to receive(:default_release).and_return("lenny-backports")
-          allow(@new_resource).to receive(:provider).and_return(nil)
+          @new_resource.default_release("lenny-backports")
+          @new_resource.provider(nil)
           expect(@provider).to receive(:shell_out!).with(
-            "apt-cache -o APT::Default-Release=lenny-backports policy irssi",
+            "apt-cache", "-o", "APT::Default-Release=lenny-backports", "policy", "irssi",
             :env => { "DEBIAN_FRONTEND" => "noninteractive" },
             :timeout => @timeout
           ).and_return(@shell_out)
@@ -230,7 +230,7 @@ mpg123 1.12.1-0ubuntu1
         it "raises an exception if a source is specified (CHEF-5113)" do
           @new_resource.source "pluto"
           expect(@provider).to receive(:shell_out!).with(
-            "apt-cache policy #{@new_resource.package_name}",
+            "apt-cache", "policy", @new_resource.package_name,
             :env => { "DEBIAN_FRONTEND" => "noninteractive" } ,
             :timeout => @timeout
           ).and_return(@shell_out)
@@ -259,7 +259,7 @@ mpg123 1.12.1-0ubuntu1
         describe "install_package" do
           it "should run apt-get install with the package name and version" do
             expect(@provider).to receive(:shell_out!). with(
-              "apt-get -q -y install irssi=0.8.12-7",
+              "apt-get", "-q", "-y", "install", "irssi=0.8.12-7",
               :env => { "DEBIAN_FRONTEND" => "noninteractive" },
               :timeout => @timeout
             )
@@ -268,7 +268,7 @@ mpg123 1.12.1-0ubuntu1
 
           it "should run apt-get install with the package name and version and options if specified" do
             expect(@provider).to receive(:shell_out!).with(
-              "apt-get -q -y --force-yes install irssi=0.8.12-7",
+              "apt-get", "-q", "-y", "--force-yes", "install", "irssi=0.8.12-7",
               :env => { "DEBIAN_FRONTEND" => "noninteractive" },
               :timeout => @timeout
             )
@@ -284,13 +284,23 @@ mpg123 1.12.1-0ubuntu1
             @provider.new_resource = @new_resource
 
             expect(@provider).to receive(:shell_out!).with(
-              "apt-get -q -y -o APT::Default-Release=lenny-backports install irssi=0.8.12-7",
+              "apt-get", "-q", "-y", "-o", "APT::Default-Release=lenny-backports", "install", "irssi=0.8.12-7",
               :env => { "DEBIAN_FRONTEND" => "noninteractive" },
               :timeout => @timeout
             )
 
             @provider.install_package(["irssi"], ["0.8.12-7"])
           end
+
+          it "should run apt-get install with the package name and quotes options if specified" do
+            expect(@provider).to receive(:shell_out!).with(
+              "apt-get", "-q", "-y", "--force-yes", "-o", "Dpkg::Options::=--force-confdef", "-o", "Dpkg::Options::=--force-confnew", "install", "irssi=0.8.12-7",
+              :env => { "DEBIAN_FRONTEND" => "noninteractive" },
+              :timeout => @timeout
+            )
+            @new_resource.options('--force-yes -o Dpkg::Options::="--force-confdef" -o Dpkg::Options::="--force-confnew"')
+            @provider.install_package(["irssi"], ["0.8.12-7"])
+          end
         end
 
         describe resource_klass, "upgrade_package" do
@@ -305,7 +315,7 @@ mpg123 1.12.1-0ubuntu1
 
           it "should run apt-get remove with the package name" do
             expect(@provider).to receive(:shell_out!).with(
-              "apt-get -q -y remove irssi",
+              "apt-get", "-q", "-y", "remove", "irssi",
               :env => { "DEBIAN_FRONTEND" => "noninteractive" },
               :timeout => @timeout
             )
@@ -314,7 +324,7 @@ mpg123 1.12.1-0ubuntu1
 
           it "should run apt-get remove with the package name and options if specified" do
             expect(@provider).to receive(:shell_out!).with(
-              "apt-get -q -y --force-yes remove irssi",
+              "apt-get", "-q", "-y", "--force-yes", "remove", "irssi",
               :env => { "DEBIAN_FRONTEND" => "noninteractive" },
               :timeout => @timeout
             )
@@ -328,7 +338,7 @@ mpg123 1.12.1-0ubuntu1
 
           it "should run apt-get purge with the package name" do
             expect(@provider).to receive(:shell_out!).with(
-              "apt-get -q -y purge irssi",
+              "apt-get", "-q", "-y", "purge", "irssi",
               :env => { "DEBIAN_FRONTEND" => "noninteractive" },
               :timeout => @timeout
             )
@@ -337,7 +347,7 @@ mpg123 1.12.1-0ubuntu1
 
           it "should run apt-get purge with the package name and options if specified" do
             expect(@provider).to receive(:shell_out!).with(
-              "apt-get -q -y --force-yes purge irssi",
+              "apt-get", "-q", "-y", "--force-yes", "purge", "irssi",
               :env => { "DEBIAN_FRONTEND" => "noninteractive" },
               :timeout => @timeout
             )
@@ -356,7 +366,7 @@ mpg123 1.12.1-0ubuntu1
             file = "/tmp/irssi-0.8.12-7.seed"
 
             expect(@provider).to receive(:shell_out!).with(
-              "debconf-set-selections /tmp/irssi-0.8.12-7.seed",
+              "debconf-set-selections", "/tmp/irssi-0.8.12-7.seed",
               :env => { "DEBIAN_FRONTEND" => "noninteractive" },
               :timeout => @timeout
             )
@@ -366,7 +376,7 @@ mpg123 1.12.1-0ubuntu1
 
           it "should run debconf-set-selections on the preseed file if it has changed" do
             expect(@provider).to receive(:shell_out!).with(
-              "debconf-set-selections /tmp/irssi-0.8.12-7.seed",
+              "debconf-set-selections", "/tmp/irssi-0.8.12-7.seed",
               :env => { "DEBIAN_FRONTEND" => "noninteractive" },
               :timeout => @timeout
             )
@@ -387,7 +397,7 @@ mpg123 1.12.1-0ubuntu1
         describe "when reconfiguring a package" do
           it "should run dpkg-reconfigure package" do
             expect(@provider).to receive(:shell_out!).with(
-              "dpkg-reconfigure irssi",
+              "dpkg-reconfigure", "irssi",
               :env => { "DEBIAN_FRONTEND" => "noninteractive" },
               :timeout => @timeout
             )
@@ -395,11 +405,33 @@ mpg123 1.12.1-0ubuntu1
           end
         end
 
+        describe "when locking a package" do
+          it "should run apt-mark hold package" do
+            expect(@provider).to receive(:shell_out!).with(
+              "apt-mark", "hold", "irssi",
+              :env => { "DEBIAN_FRONTEND" => "noninteractive" },
+              :timeout => @timeout
+            )
+            @provider.lock_package("irssi", "0.8.12-7")
+          end
+        end
+
+        describe "when unlocking a package" do
+          it "should run apt-mark unhold package" do
+            expect(@provider).to receive(:shell_out!).with(
+              "apt-mark", "unhold", "irssi",
+              :env => { "DEBIAN_FRONTEND" => "noninteractive" },
+              :timeout => @timeout
+            )
+            @provider.unlock_package("irssi", "0.8.12-7")
+          end
+        end
+
         describe "when installing a virtual package" do
           it "should install the package without specifying a version" do
             @provider.package_data["libmysqlclient15-dev"][:virtual] = true
             expect(@provider).to receive(:shell_out!).with(
-              "apt-get -q -y install libmysqlclient15-dev",
+              "apt-get", "-q", "-y", "install", "libmysqlclient15-dev",
               :env => { "DEBIAN_FRONTEND" => "noninteractive" },
               :timeout => @timeout
             )
@@ -411,7 +443,7 @@ mpg123 1.12.1-0ubuntu1
           it "should remove the resolved name instead of the virtual package name" do
             expect(@provider).to receive(:resolve_virtual_package_name).with("libmysqlclient15-dev").and_return("libmysqlclient-dev")
             expect(@provider).to receive(:shell_out!).with(
-              "apt-get -q -y remove libmysqlclient-dev",
+              "apt-get", "-q", "-y", "remove", "libmysqlclient-dev",
               :env => { "DEBIAN_FRONTEND" => "noninteractive" },
               :timeout => @timeout
             )
@@ -423,7 +455,7 @@ mpg123 1.12.1-0ubuntu1
           it "should purge the resolved name instead of the virtual package name" do
             expect(@provider).to receive(:resolve_virtual_package_name).with("libmysqlclient15-dev").and_return("libmysqlclient-dev")
             expect(@provider).to receive(:shell_out!).with(
-              "apt-get -q -y purge libmysqlclient-dev",
+              "apt-get", "-q", "-y", "purge", "libmysqlclient-dev",
               :env => { "DEBIAN_FRONTEND" => "noninteractive" },
               :timeout => @timeout
             )
@@ -435,7 +467,7 @@ mpg123 1.12.1-0ubuntu1
           it "can install a virtual package followed by a non-virtual package" do
             # https://github.com/chef/chef/issues/2914
             expect(@provider).to receive(:shell_out!).with(
-              "apt-get -q -y install libmysqlclient15-dev irssi=0.8.12-7",
+              "apt-get", "-q", "-y", "install", "libmysqlclient15-dev", "irssi=0.8.12-7",
               :env => { "DEBIAN_FRONTEND" => "noninteractive" },
               :timeout => @timeout
             )
@@ -443,6 +475,40 @@ mpg123 1.12.1-0ubuntu1
           end
         end
 
+        describe "#action_install" do
+          it "should run dpkg to compare versions if an existing version is installed" do
+            allow(@provider).to receive(:get_current_versions).and_return("1.4.0")
+            allow(@new_resource).to receive(:allow_downgrade).and_return(false)
+            expect(@provider).to receive(:shell_out_compact_timeout).with(
+              "dpkg", "--compare-versions", "1.4.0", "gt", "0.8.12-7"
+            ).and_return(double(error?: false))
+            @provider.run_action(:upgrade)
+          end
+
+          it "should install the package if the installed version is older" do
+            allow(@provider).to receive(:get_current_versions).and_return("0.4.0")
+            allow(@new_resource).to receive(:allow_downgrade).and_return(false)
+            expect(@provider).to receive(:version_compare).and_return(-1)
+            expect(@provider).to receive(:shell_out!).with(
+              "apt-get", "-q", "-y", "install", "irssi=0.8.12-7",
+              :env => { "DEBIAN_FRONTEND" => "noninteractive" },
+              :timeout => @timeout
+            )
+            @provider.run_action(:upgrade)
+          end
+
+          it "should not compare versions if an existing version is not installed" do
+            allow(@provider).to receive(:get_current_versions).and_return(nil)
+            allow(@new_resource).to receive(:allow_downgrade).and_return(false)
+            expect(@provider).not_to receive(:version_compare)
+            expect(@provider).to receive(:shell_out!).with(
+              "apt-get", "-q", "-y", "install", "irssi=0.8.12-7",
+              :env => { "DEBIAN_FRONTEND" => "noninteractive" },
+              :timeout => @timeout
+            )
+            @provider.run_action(:upgrade)
+          end
+        end
       end
     end
   end
