@@ -209,7 +209,7 @@ describe Chef::Provider::Package::Homebrew do
         allow(provider.new_resource).to receive(:version).and_return("24.3")
         allow(provider.current_resource).to receive(:version).and_return(nil)
         allow(provider).to receive(:brew_info).and_return(uninstalled_brew_info)
-        expect(provider).to receive(:get_response_from_command).with("brew install  emacs")
+        expect(provider).to receive(:get_response_from_command).with("brew", "install", nil, "emacs")
         provider.install_package("emacs", "24.3")
       end
 
@@ -221,9 +221,9 @@ describe Chef::Provider::Package::Homebrew do
       end
 
       it "uses options to the brew command if specified" do
-        allow(provider.new_resource).to receive(:options).and_return("--cocoa")
+        new_resource.options "--cocoa"
         allow(provider.current_resource).to receive(:version).and_return("24.3")
-        allow(provider).to receive(:get_response_from_command).with("brew install --cocoa emacs")
+        allow(provider).to receive(:get_response_from_command).with("brew", "install", "--cocoa", "emacs")
         provider.install_package("emacs", "24.3")
       end
     end
@@ -232,7 +232,7 @@ describe Chef::Provider::Package::Homebrew do
       it "uses brew upgrade to upgrade the package if it is installed" do
         allow(provider.current_resource).to receive(:version).and_return("24")
         allow(provider).to receive(:brew_info).and_return(installed_brew_info)
-        expect(provider).to receive(:get_response_from_command).with("brew upgrade  emacs")
+        expect(provider).to receive(:get_response_from_command).with("brew", "upgrade", nil, "emacs")
         provider.upgrade_package("emacs", "24.3")
       end
 
@@ -246,15 +246,15 @@ describe Chef::Provider::Package::Homebrew do
       it "uses brew install to install the package if it is not installed" do
         allow(provider.current_resource).to receive(:version).and_return(nil)
         allow(provider).to receive(:brew_info).and_return(uninstalled_brew_info)
-        expect(provider).to receive(:get_response_from_command).with("brew install  emacs")
+        expect(provider).to receive(:get_response_from_command).with("brew", "install", nil, "emacs")
         provider.upgrade_package("emacs", "24.3")
       end
 
       it "uses options to the brew command if specified" do
         allow(provider.current_resource).to receive(:version).and_return("24")
         allow(provider).to receive(:brew_info).and_return(installed_brew_info)
-        allow(provider.new_resource).to receive(:options).and_return("--cocoa")
-        expect(provider).to receive(:get_response_from_command).with("brew upgrade --cocoa emacs")
+        new_resource.options "--cocoa"
+        expect(provider).to receive(:get_response_from_command).with("brew", "upgrade", [ "--cocoa" ], "emacs")
         provider.upgrade_package("emacs", "24.3")
       end
     end
@@ -263,7 +263,7 @@ describe Chef::Provider::Package::Homebrew do
       it "uninstalls the package with brew uninstall" do
         allow(provider.current_resource).to receive(:version).and_return("24.3")
         allow(provider).to receive(:brew_info).and_return(installed_brew_info)
-        expect(provider).to receive(:get_response_from_command).with("brew uninstall  emacs")
+        expect(provider).to receive(:get_response_from_command).with("brew", "uninstall", nil, "emacs")
         provider.remove_package("emacs", "24.3")
       end
 
@@ -278,7 +278,7 @@ describe Chef::Provider::Package::Homebrew do
       it "uninstalls the package with brew uninstall --force" do
         allow(provider.current_resource).to receive(:version).and_return("24.3")
         allow(provider).to receive(:brew_info).and_return(installed_brew_info)
-        expect(provider).to receive(:get_response_from_command).with("brew uninstall  --force emacs")
+        expect(provider).to receive(:get_response_from_command).with("brew", "uninstall", "--force", nil, "emacs")
         provider.purge_package("emacs", "24.3")
       end
 
