@@ -29,9 +29,14 @@ describe Chef::Provider::Route do
     @new_resource.gateway "10.0.0.9"
     @current_resource = Chef::Resource::Route.new("10.0.0.10")
     @current_resource.gateway "10.0.0.9"
+    @default_resource = Chef::Resource::Route.new("default")
+    @default_resource.gateway "10.0.0.9"
 
     @provider = Chef::Provider::Route.new(@new_resource, @run_context)
     @provider.current_resource = @current_resource
+
+    @default_provider = Chef::Provider::Route.new(@default_resource, @run_context)
+    @default_provider.current_resource = @default_resource
   end
 
   describe Chef::Provider::Route, "hex2ip" do
@@ -51,7 +56,7 @@ describe Chef::Provider::Route do
     context "on linux" do
       before do
         @node.automatic_attrs[:os] = "linux"
-        routing_table = "Iface	Destination	Gateway 	Flags	RefCnt	Use	Metric	Mask		MTU	Window	IRTT\n" +
+        routing_table = "Iface	Destination	Gateway 	Flags	RefCnt	Use	Metric	Mask		MTU	Window	IRTT\n" \
           "eth0	0064A8C0	0984A8C0	0003	0	0	0	00FFFFFF	0	0	0\n"
         route_file = StringIO.new(routing_table)
         allow(File).to receive(:open).with("/proc/net/route", "r").and_return(route_file)
@@ -91,16 +96,16 @@ describe Chef::Provider::Route do
 
   describe Chef::Provider::Route, "action_add" do
     it "should add the route if it does not exist" do
-      allow(@provider).to receive(:run_command).and_return(true)
+      allow(@provider).to receive(:shell_out!)
       allow(@current_resource).to receive(:gateway).and_return(nil)
-      expect(@provider).to receive(:generate_command).once.with(:add)
+      expect(@provider).to receive(:generate_command).with(:add).and_return(["command"])
       expect(@provider).to receive(:generate_config)
       @provider.run_action(:add)
       expect(@new_resource).to be_updated
     end
 
     it "should not add the route if it exists" do
-      allow(@provider).to receive(:run_command).and_return(true)
+      allow(@provider).to receive(:shell_out!)
       allow(@provider).to receive(:is_running).and_return(true)
       expect(@provider).not_to receive(:generate_command).with(:add)
       expect(@provider).to receive(:generate_config)
@@ -115,7 +120,7 @@ describe Chef::Provider::Route do
       expect(File).to receive(:new).and_return(route_file)
       @resource_add = Chef::Resource::Route.new("192.168.1.0/24 via 192.168.0.1")
       @run_context.resource_collection << @resource_add
-      allow(@provider).to receive(:run_command).and_return(true)
+      allow(@provider).to receive(:shell_out!).and_return(true)
 
       @resource_add.action(:add)
       @provider.run_action(:add)
@@ -126,8 +131,8 @@ describe Chef::Provider::Route do
 
   describe Chef::Provider::Route, "action_delete" do
     it "should delete the route if it exists" do
-      allow(@provider).to receive(:run_command).and_return(true)
-      expect(@provider).to receive(:generate_command).once.with(:delete)
+      allow(@provider).to receive(:shell_out!).and_return(true)
+      expect(@provider).to receive(:generate_command).with(:delete).and_return(["command"])
       allow(@provider).to receive(:is_running).and_return(true)
       @provider.run_action(:delete)
       expect(@new_resource).to be_updated
@@ -135,7 +140,7 @@ describe Chef::Provider::Route do
 
     it "should not delete the route if it does not exist" do
       allow(@current_resource).to receive(:gateway).and_return(nil)
-      allow(@provider).to receive(:run_command).and_return(true)
+      allow(@provider).to receive(:shell_out!).and_return(true)
       expect(@provider).not_to receive(:generate_command).with(:add)
       @provider.run_action(:delete)
       expect(@new_resource).not_to be_updated
@@ -144,62 +149,67 @@ describe Chef::Provider::Route do
 
   describe Chef::Provider::Route, "generate_command for action_add" do
     it "should include a netmask when a one is specified" do
-      allow(@new_resource).to receive(:netmask).and_return("255.255.0.0")
-      expect(@provider.generate_command(:add)).to match(/\/\d{1,2}\s/)
+      @new_resource.netmask("255.255.0.0")
+      expect(@provider.generate_command(:add).join(" ")).to match(/\/\d{1,2}/)
     end
 
     it "should not include a netmask when a one is specified" do
-      allow(@new_resource).to receive(:netmask).and_return(nil)
-      expect(@provider.generate_command(:add)).not_to match(/\/\d{1,2}\s/)
+      @new_resource.netmask(nil)
+      expect(@provider.generate_command(:add).join(" ")).not_to match(/\/\d{1,2}/)
     end
 
     it "should include ' via $gateway ' when a gateway is specified" do
-      expect(@provider.generate_command(:add)).to match(/\svia\s#{Regexp.escape(@new_resource.gateway.to_s)}\s/)
+      expect(@provider.generate_command(:add).join(" ")).to match(/\svia\s#{Regexp.escape(@new_resource.gateway.to_s)}/)
     end
 
     it "should not include ' via $gateway ' when a gateway is not specified" do
-      allow(@new_resource).to receive(:gateway).and_return(nil)
-      expect(@provider.generate_command(:add)).not_to match(/\svia\s#{Regexp.escape(@new_resource.gateway.to_s)}\s/)
+      @new_resource.gateway(nil)
+      expect(@provider.generate_command(:add).join(" ")).not_to match(/\svia\s#{Regexp.escape(@new_resource.gateway.to_s)}/)
+    end
+
+    it "should use the gatway when target is default" do
+      @default_resource.gateway("10.0.0.10")
+      expect(@default_provider.generate_command(:add).join(" ")).to match(/10.0.0.10/)
     end
   end
 
   describe Chef::Provider::Route, "generate_command for action_delete" do
     it "should include a netmask when a one is specified" do
-      allow(@new_resource).to receive(:netmask).and_return("255.255.0.0")
-      expect(@provider.generate_command(:delete)).to match(/\/\d{1,2}\s/)
+      @new_resource.netmask("255.255.0.0")
+      expect(@provider.generate_command(:delete).join(" ")).to match(/\/\d{1,2}/)
     end
 
     it "should not include a netmask when a one is specified" do
-      allow(@new_resource).to receive(:netmask).and_return(nil)
-      expect(@provider.generate_command(:delete)).not_to match(/\/\d{1,2}\s/)
+      @new_resource.netmask(nil)
+      expect(@provider.generate_command(:delete).join(" ")).not_to match(/\/\d{1,2}/)
     end
 
     it "should include ' via $gateway ' when a gateway is specified" do
-      expect(@provider.generate_command(:delete)).to match(/\svia\s#{Regexp.escape(@new_resource.gateway.to_s)}\s/)
+      expect(@provider.generate_command(:delete).join(" ")).to match(/\svia\s#{Regexp.escape(@new_resource.gateway.to_s)}/)
     end
 
     it "should not include ' via $gateway ' when a gateway is not specified" do
-      allow(@new_resource).to receive(:gateway).and_return(nil)
-      expect(@provider.generate_command(:delete)).not_to match(/\svia\s#{Regexp.escape(@new_resource.gateway.to_s)}\s/)
+      @new_resource.gateway(nil)
+      expect(@provider.generate_command(:delete).join(" ")).not_to match(/\svia\s#{Regexp.escape(@new_resource.gateway.to_s)}/)
     end
   end
 
   describe Chef::Provider::Route, "config_file_contents for action_add" do
     it "should include a netmask when a one is specified" do
-      allow(@new_resource).to receive(:netmask).and_return("255.255.0.0")
-      expect(@provider.config_file_contents(:add, { :target => @new_resource.target, :netmask => @new_resource.netmask })).to match(/\/\d{1,2}.*\n$/)
+      @new_resource.netmask("255.255.0.0")
+      expect(@provider.config_file_contents(:add, target: @new_resource.target, netmask: @new_resource.netmask)).to match(/\/\d{1,2}.*\n$/)
     end
 
     it "should not include a netmask when a one is specified" do
-      expect(@provider.config_file_contents(:add, { :target => @new_resource.target })).not_to match(/\/\d{1,2}.*\n$/)
+      expect(@provider.config_file_contents(:add, target: @new_resource.target)).not_to match(/\/\d{1,2}.*\n$/)
     end
 
     it "should include ' via $gateway ' when a gateway is specified" do
-      expect(@provider.config_file_contents(:add, { :target => @new_resource.target, :gateway => @new_resource.gateway })).to match(/\svia\s#{Regexp.escape(@new_resource.gateway.to_s)}\n/)
+      expect(@provider.config_file_contents(:add, target: @new_resource.target, gateway: @new_resource.gateway)).to match(/\svia\s#{Regexp.escape(@new_resource.gateway.to_s)}\n/)
     end
 
     it "should not include ' via $gateway ' when a gateway is not specified" do
-      expect(@provider.generate_command(:add)).not_to match(/\svia\s#{Regexp.escape(@new_resource.gateway.to_s)}\n/)
+      expect(@provider.generate_command(:add).join(" ")).not_to match(/\svia\s#{Regexp.escape(@new_resource.gateway.to_s)}\n/)
     end
   end
 
@@ -216,10 +226,22 @@ describe Chef::Provider::Route do
 
         route_file = StringIO.new
         expect(File).to receive(:new).with("/etc/sysconfig/network-scripts/route-eth0", "w").and_return(route_file)
-        #Chef::Log.should_receive(:debug).with("route[10.0.0.10] writing route.eth0\n10.0.0.10 via 10.0.0.9\n")
         @run_context.resource_collection << @new_resource
         @provider.generate_config
       end
+
+    end
+    %w{ centos redhat fedora }.each do |platform|
+      it "should write a default route file on #{platform} platform" do
+        @node.automatic_attrs[:platform] = platform
+
+        route_file = StringIO.new
+        allow(File).to receive(:exist?).with("/etc/sysconfig/network").and_return(false)
+        expect(File).to receive(:new).with("/etc/sysconfig/network", "w").and_return(route_file)
+        @run_context.resource_collection << @default_resource
+        @default_provider.generate_config
+        expect(route_file.string).to match(/GATEWAY=10\.0\.0\.9/)
+      end
     end
 
     it "should put all routes for a device in a route config file" do
@@ -230,13 +252,19 @@ describe Chef::Provider::Route do
       @run_context.resource_collection << Chef::Resource::Route.new("192.168.1.0/24 via 192.168.0.1")
       @run_context.resource_collection << Chef::Resource::Route.new("192.168.2.0/24 via 192.168.0.1")
       @run_context.resource_collection << Chef::Resource::Route.new("192.168.3.0/24 via 192.168.0.1")
+      @run_context.resource_collection << Chef::Resource::Route.new("Complex Route").tap do |r|
+        r.target "192.168.4.0"
+        r.gateway "192.168.0.1"
+        r.netmask "255.255.255.0"
+      end
 
       @provider.action = :add
       @provider.generate_config
-      expect(route_file.string.split("\n").size).to eq(3)
+      expect(route_file.string.split("\n").size).to eq(4)
       expect(route_file.string).to match(/^192\.168\.1\.0\/24 via 192\.168\.0\.1$/)
       expect(route_file.string).to match(/^192\.168\.2\.0\/24 via 192\.168\.0\.1$/)
       expect(route_file.string).to match(/^192\.168\.3\.0\/24 via 192\.168\.0\.1$/)
+      expect(route_file.string).to match(/^192\.168\.4\.0\/24 via 192\.168\.0\.1$/)
     end
   end
 end
