@@ -59,11 +59,10 @@ describe Chef::Provider::Service::Debian do
     /etc/rc6.d/K20chef
         UPDATE_RC_D_SUCCESS
 
-        @stdout = StringIO.new(result)
-        @stderr = StringIO.new
-        @status = double("Status", :exitstatus => 0, :stdout => @stdout)
+        @stdout = result
+        @stderr = ""
+        @status = double("Status", :exitstatus => 0, :stdout => @stdout, :stderr => @stderr)
         allow(@provider).to receive(:shell_out!).and_return(@status)
-        allow(@provider).to receive(:popen4).and_yield(@pid, @stdin, @stdout, @stderr).and_return(@status)
       end
 
       it "says the service is enabled" do
@@ -80,13 +79,9 @@ describe Chef::Provider::Service::Debian do
     context "when update-rc.d shows init isn't linked to rc*.d/" do
       before do
         allow(@provider).to receive(:assert_update_rcd_available)
-        @status = double("Status", :exitstatus => 0)
-        @stdout = StringIO.new(
-          " Removing any system startup links for /etc/init.d/chef ...")
-        @stderr = StringIO.new
-        @status = double("Status", :exitstatus => 0, :stdout => @stdout)
+        @stdout = " Removing any system startup links for /etc/init.d/chef ..."
+        @status = double("Status", :exitstatus => 0, :stdout => @stdout, stderr: "")
         allow(@provider).to receive(:shell_out!).and_return(@status)
-        allow(@provider).to receive(:popen4).and_yield(@pid, @stdin, @stdout, @stderr).and_return(@status)
       end
 
       it "says the service is disabled" do
@@ -102,11 +97,12 @@ describe Chef::Provider::Service::Debian do
 
     context "when update-rc.d fails" do
       before do
-        @status = double("Status", :exitstatus => -1)
-        allow(@provider).to receive(:popen4).and_return(@status)
+        @status = double("Status", exitstatus: -1, stdout: "", stderr: "")
+        allow(@provider).to receive(:shell_out!).and_return(@status)
       end
 
       it "raises an error" do
+        @provider.load_current_resource
         @provider.define_resource_requirements
         expect do
           @provider.process_resource_requirements
@@ -198,11 +194,10 @@ insserv: dryrun, not creating .depend.boot, .depend.start, and .depend.stop
           before do
             allow(@provider).to receive(:assert_update_rcd_available)
 
-            @stdout = StringIO.new(expected_results["linked"]["stdout"])
-            @stderr = StringIO.new(expected_results["linked"]["stderr"])
-            @status = double("Status", :exitstatus => 0, :stdout => @stdout)
+            @stdout = expected_results["linked"]["stdout"]
+            @stderr = expected_results["linked"]["stderr"]
+            @status = double("Status", exitstatus: 0, stdout: @stdout, stderr: @stderr)
             allow(@provider).to receive(:shell_out!).and_return(@status)
-            allow(@provider).to receive(:popen4).and_yield(@pid, @stdin, @stdout, @stderr).and_return(@status)
           end
 
           it "says the service is enabled" do
@@ -224,11 +219,10 @@ insserv: dryrun, not creating .depend.boot, .depend.start, and .depend.stop
         context "when update-rc.d shows init isn't linked to rc*.d/" do
           before do
             allow(@provider).to receive(:assert_update_rcd_available)
-            @stdout = StringIO.new(expected_results["not linked"]["stdout"])
-            @stderr = StringIO.new(expected_results["not linked"]["stderr"])
-            @status = double("Status", :exitstatus => 0, :stdout => @stdout)
+            @stdout = expected_results["not linked"]["stdout"]
+            @stderr = expected_results["not linked"]["stderr"]
+            @status = double("Status", exitstatus: 0, stdout: @stdout, stderr: @stderr)
             allow(@provider).to receive(:shell_out!).and_return(@status)
-            allow(@provider).to receive(:popen4).and_yield(@pid, @stdin, @stdout, @stderr).and_return(@status)
           end
 
           it "says the service is disabled" do
