@@ -74,7 +74,10 @@ XML
           let(:service_label) { "io.redis.redis-server" }
           before do
             allow(Dir).to receive(:glob).and_return([plist], [])
-            allow(Etc).to receive(:getlogin).and_return("igor")
+            @stat = double("File::Stat", { :uid => 501 })
+            allow(File).to receive(:stat).and_return(@stat)
+            @getpwuid = double("Etc::Passwd", { :name => "mikedodge04" })
+            allow(Etc).to receive(:getpwuid).and_return(@getpwuid)
             allow(node).to receive(:[]).with("platform_version").and_return(platform_version)
             cmd = "launchctl list #{service_label}"
             allow(provider).to receive(:shell_out_with_systems_locale).
@@ -322,7 +325,7 @@ SVC_LIST
 
               it "stops and then starts service" do
                 expect(provider).to receive(:unload_service)
-                expect(provider).to receive(:load_service);
+                expect(provider).to receive(:load_service)
 
                 provider.restart_service
               end
