@@ -1,6 +1,6 @@
 #
 # Author:: Daniel DeLeo (<dan@kallistec.com>)
-# Copyright:: Copyright 2008-2016, Chef Software Inc.
+# Copyright:: Copyright 2008-2017, Chef Software Inc.
 # License:: Apache License, Version 2.0
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -32,9 +32,18 @@ describe Chef::Provider::Subversion do
     @events = Chef::EventDispatch::Dispatcher.new
     @run_context = Chef::RunContext.new(@node, {}, @events)
     @provider = Chef::Provider::Subversion.new(@resource, @run_context)
+    @original_env = ENV.to_hash
+    # Generated command lines would include any environmental proxies
+    ENV.delete("http_proxy")
+    ENV.delete("https_proxy")
   end
 
-  it "converts resource attributes to options for run_command and popen4" do
+  after do
+    ENV.clear
+    ENV.update(@original_env)
+  end
+
+  it "converts resource attributes to options for shell_out" do
     expect(@provider.run_options).to eq({})
     @resource.user "deployninja"
     expect(@provider.run_options).to eq({ :user => "deployninja" })
