@@ -1,6 +1,6 @@
 #
 # Author:: Stephen Haynes (<sh@nomitor.com>)
-# Copyright:: Copyright 2008-2016, Chef Software Inc.
+# Copyright:: Copyright 2008-2017, Chef Software Inc.
 # License:: Apache License, Version 2.0
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -32,7 +32,7 @@ describe Chef::Provider::User::Pw do
     @new_resource.shell     "/usr/bin/zsh"
     @new_resource.password  "abracadabra"
 
-    @new_resource.supports :manage_home => true
+    @new_resource.manage_home true
 
     @current_resource = Chef::Resource::User::PwUser.new("adam")
     @current_resource.comment  "Adam Jacob"
@@ -63,35 +63,30 @@ describe Chef::Provider::User::Pw do
 
       it "should set the option for #{attribute} if the new resources #{attribute} is not null" do
         allow(@new_resource).to receive(attribute).and_return("hola")
-        expect(@provider.set_options).to eql(" #{@new_resource.username} #{option} '#{@new_resource.send(attribute)}' -m")
-      end
-
-      it "should set the option for #{attribute} if the new resources #{attribute} is not null, without homedir management" do
-        allow(@new_resource).to receive(:supports).and_return({ :manage_home => false })
-        allow(@new_resource).to receive(attribute).and_return("hola")
-        expect(@provider.set_options).to eql(" #{@new_resource.username} #{option} '#{@new_resource.send(attribute)}'")
+        expect(@provider.set_options).to eql([ @new_resource.username, option, @new_resource.send(attribute), "-m"])
       end
     end
 
     it "should combine all the possible options" do
-      match_string = " adam"
-      field_list.sort { |a, b| a[0] <=> b[0] }.each do |attribute, option|
+      match_array = [ "adam" ]
+      field_list.sort_by { |a| a[0] }.each do |attribute, option|
         allow(@new_resource).to receive(attribute).and_return("hola")
-        match_string << " #{option} 'hola'"
+        match_array << option
+        match_array << "hola"
       end
-      match_string << " -m"
-      expect(@provider.set_options).to eql(match_string)
+      match_array << "-m"
+      expect(@provider.set_options).to eql(match_array)
     end
   end
 
   describe "create_user" do
     before(:each) do
-      allow(@provider).to receive(:run_command).and_return(true)
+      allow(@provider).to receive(:shell_out!).and_return(true)
       allow(@provider).to receive(:modify_password).and_return(true)
     end
 
     it "should run pw useradd with the return of set_options" do
-      expect(@provider).to receive(:run_command).with({ :command => "pw useradd adam -m" }).and_return(true)
+      expect(@provider).to receive(:shell_out!).with("pw", "useradd", "adam", "-m").and_return(true)
       @provider.create_user
     end
 
@@ -103,12 +98,12 @@ describe Chef::Provider::User::Pw do
 
   describe "manage_user" do
     before(:each) do
-      allow(@provider).to receive(:run_command).and_return(true)
+      allow(@provider).to receive(:shell_out!).and_return(true)
       allow(@provider).to receive(:modify_password).and_return(true)
     end
 
     it "should run pw usermod with the return of set_options" do
-      expect(@provider).to receive(:run_command).with({ :command => "pw usermod adam -m" }).and_return(true)
+      expect(@provider).to receive(:shell_out!).with("pw", "usermod", "adam", "-m").and_return(true)
       @provider.manage_user
     end
 
@@ -120,13 +115,13 @@ describe Chef::Provider::User::Pw do
 
   describe "remove_user" do
     it "should run pw userdel with the new resources user name" do
-      @new_resource.supports :manage_home => false
-      expect(@provider).to receive(:run_command).with({ :command => "pw userdel #{@new_resource.username}" }).and_return(true)
+      @new_resource.manage_home false
+      expect(@provider).to receive(:shell_out!).with("pw", "userdel", @new_resource.username).and_return(true)
       @provider.remove_user
     end
 
     it "should run pw userdel with the new resources user name and -r if manage_home is true" do
-      expect(@provider).to receive(:run_command).with({ :command => "pw userdel #{@new_resource.username} -r" }).and_return(true)
+      expect(@provider).to receive(:shell_out!).with("pw", "userdel", @new_resource.username, "-r").and_return(true)
       @provider.remove_user
     end
   end
@@ -145,28 +140,27 @@ describe Chef::Provider::User::Pw do
 
   describe "when locking the user" do
     it "should run pw lock with the new resources username" do
-      expect(@provider).to receive(:run_command).with({ :command => "pw lock #{@new_resource.username}" })
+      expect(@provider).to receive(:shell_out!).with("pw", "lock", @new_resource.username)
       @provider.lock_user
     end
   end
 
   describe "when unlocking the user" do
     it "should run pw unlock with the new resources username" do
-      expect(@provider).to receive(:run_command).with({ :command => "pw unlock #{@new_resource.username}" })
+      expect(@provider).to receive(:shell_out!).with("pw", "unlock", @new_resource.username)
       @provider.unlock_user
     end
   end
 
   describe "when modifying the password" do
     before(:each) do
-      @status = double("Status", :exitstatus => 0)
-      allow(@provider).to receive(:popen4).and_return(@status)
-      @pid, @stdin, @stdout, @stderr = nil, nil, nil, nil
+      @status = double("Status", exitstatus: 0)
+      allow(@provider).to receive(:shell_out!).and_return(@status)
     end
 
     describe "and the new password has not been specified" do
       before(:each) do
-        allow(@new_resource).to receive(:password).and_return(nil)
+        @new_resource.password(nil)
       end
 
       it "logs an appropriate message" do
@@ -176,19 +170,19 @@ describe Chef::Provider::User::Pw do
 
     describe "and the new password has been specified" do
       before(:each) do
-        allow(@new_resource).to receive(:password).and_return("abracadabra")
+        @new_resource.password("abracadabra")
       end
 
       it "should check for differences in password between the new and current resources" do
         expect(@current_resource).to receive(:password)
-        expect(@new_resource).to receive(:password)
+        expect(@new_resource).to receive(:password).and_call_original.at_least(:once)
         @provider.modify_password
       end
     end
 
     describe "and the passwords are identical" do
       before(:each) do
-        allow(@new_resource).to receive(:password).and_return("abracadabra")
+        @new_resource.password("abracadabra")
         allow(@current_resource).to receive(:password).and_return("abracadabra")
       end
 
@@ -199,7 +193,7 @@ describe Chef::Provider::User::Pw do
 
     describe "and the passwords are different" do
       before(:each) do
-        allow(@new_resource).to receive(:password).and_return("abracadabra")
+        @new_resource.password("abracadabra")
         allow(@current_resource).to receive(:password).and_return("sesame")
       end
 
@@ -208,24 +202,16 @@ describe Chef::Provider::User::Pw do
       end
 
       it "should run pw usermod with the username and the option -H 0" do
-        expect(@provider).to receive(:popen4).with("pw usermod adam -H 0", :waitlast => true).and_return(@status)
+        expect(@provider).to receive(:shell_out!).with("pw usermod adam -H 0", { :input => "abracadabra" }).and_return(@status)
         @provider.modify_password
       end
 
-      it "should send the new password to the stdin of pw usermod" do
-        @stdin = StringIO.new
-        allow(@provider).to receive(:popen4).and_yield(@pid, @stdin, @stdout, @stderr).and_return(@status)
-        @provider.modify_password
-        expect(@stdin.string).to eq("abracadabra\n")
-      end
-
       it "should raise an exception if pw usermod fails" do
-        expect(@status).to receive(:exitstatus).and_return(1)
-        expect { @provider.modify_password }.to raise_error(Chef::Exceptions::User)
+        expect(@provider).to receive(:shell_out!).and_raise(Mixlib::ShellOut::ShellCommandFailed)
+        expect { @provider.modify_password }.to raise_error(Mixlib::ShellOut::ShellCommandFailed)
       end
 
       it "should not raise an exception if pw usermod succeeds" do
-        expect(@status).to receive(:exitstatus).and_return(0)
         expect { @provider.modify_password }.not_to raise_error
       end
     end
@@ -237,12 +223,12 @@ describe Chef::Provider::User::Pw do
     end
 
     it "should raise an error if the required binary /usr/sbin/pw doesn't exist" do
-      expect(File).to receive(:exists?).with("/usr/sbin/pw").and_return(false)
+      expect(File).to receive(:exist?).with("/usr/sbin/pw").and_return(false)
       expect { @provider.load_current_resource }.to raise_error(Chef::Exceptions::User)
     end
 
     it "shouldn't raise an error if /usr/sbin/pw exists" do
-      allow(File).to receive(:exists?).and_return(true)
+      allow(File).to receive(:exist?).and_return(true)
       expect { @provider.load_current_resource }.not_to raise_error
     end
   end
