@@ -135,6 +135,7 @@ describe Chef::ProviderResolver do
             end
           else
             it "'#{name}' fails to resolve (since #{name.inspect} is unsupported on #{platform} #{platform_version})", *tags do
+              Chef::Config[:treat_deprecation_warnings_as_errors] = false
               expect(resolved_provider).to be_nil
             end
           end
@@ -191,34 +192,34 @@ describe Chef::ProviderResolver do
           stub_service_providers(:debian, :invokercd, :upstart, :systemd)
         end
 
-        it "when only the SysV init script exists, it returns a Service::Debian provider" do
+        it "when both the SysV init and Systemd script exists, it returns a Service::Debian provider" do
           stub_service_configs(:initd, :systemd)
           expect(resolved_provider).to eql(Chef::Provider::Service::Systemd)
         end
 
-        it "when both SysV and Upstart scripts exist, it returns a Service::Upstart provider" do
+        it "when SysV, Upstart, and Systemd scripts exist, it returns a Service::Systemd provider" do
           stub_service_configs(:initd, :upstart, :systemd)
           expect(resolved_provider).to eql(Chef::Provider::Service::Systemd)
         end
 
-        it "when only the Upstart script exists, it returns a Service::Upstart provider" do
+        it "when both the Upstart and Systemd scripts exists, it returns a Service::Systemd provider" do
           stub_service_configs(:upstart, :systemd)
           expect(resolved_provider).to eql(Chef::Provider::Service::Systemd)
         end
 
-        it "when both do not exist, it calls the old style provider resolver and returns a Debian Provider" do
+        it "when both do not exist, it calls the old style provider resolver and returns a Systemd Provider" do
           stub_service_configs(:systemd)
           expect(resolved_provider).to eql(Chef::Provider::Service::Systemd)
         end
 
-        it "when only the SysV init script exists, it returns a Service::Debian provider" do
+        it "when only the SysV init script exists, it returns a Service::Systemd provider" do
           stub_service_configs(:initd)
-          expect(resolved_provider).to eql(Chef::Provider::Service::Debian)
+          expect(resolved_provider).to eql(Chef::Provider::Service::Systemd)
         end
 
-        it "when both SysV and Upstart scripts exist, it returns a Service::Upstart provider" do
+        it "when both SysV and Upstart scripts exist, it returns a Service::Systemd provider" do
           stub_service_configs(:initd, :upstart)
-          expect(resolved_provider).to eql(Chef::Provider::Service::Upstart)
+          expect(resolved_provider).to eql(Chef::Provider::Service::Systemd)
         end
 
         it "when only the Upstart script exists, it returns a Service::Upstart provider" do
@@ -226,7 +227,7 @@ describe Chef::ProviderResolver do
           expect(resolved_provider).to eql(Chef::Provider::Service::Upstart)
         end
 
-        it "when both do not exist, it calls the old style provider resolver and returns a Debian Provider" do
+        it "when both do not exist, it calls the old style provider resolver and returns a Systemd Provider" do
           stub_service_configs
           expect(resolved_provider).to eql(Chef::Provider::Service::Systemd)
         end
@@ -409,7 +410,7 @@ describe Chef::ProviderResolver do
           stub_service_providers(:debian, :invokercd, :upstart, :systemd)
           stub_service_configs(:initd, :upstart)
           mock_shellout_command("/bin/systemctl list-unit-files", exitstatus: 1)
-          expect(resolved_provider).to eql(Chef::Provider::Service::Upstart)
+          expect(resolved_provider).to eql(Chef::Provider::Service::Systemd)
         end
       end
 
@@ -553,14 +554,13 @@ describe Chef::ProviderResolver do
     PROVIDERS =
       {
         bash:                   [ Chef::Resource::Bash, Chef::Provider::Script ],
-        breakpoint:             [ Chef::Resource::Breakpoint, Chef::Provider::Breakpoint ],
+        breakpoint:             [ Chef::Resource::Breakpoint, Chef::Resource::Breakpoint.action_class ],
         chef_gem:               [ Chef::Resource::ChefGem, Chef::Provider::Package::Rubygems ],
         cookbook_file:          [ Chef::Resource::CookbookFile, Chef::Provider::CookbookFile ],
         csh:                    [ Chef::Resource::Csh, Chef::Provider::Script ],
         deploy:                 [ Chef::Resource::Deploy, Chef::Provider::Deploy::Timestamped ],
         deploy_revision:        [ Chef::Resource::DeployRevision, Chef::Provider::Deploy::Revision ],
         directory:              [ Chef::Resource::Directory, Chef::Provider::Directory ],
-        easy_install_package:   [ Chef::Resource::EasyInstallPackage, Chef::Provider::Package::EasyInstall ],
         erl_call:               [ Chef::Resource::ErlCall, Chef::Provider::ErlCall ],
         execute:                [ Chef::Resource::Execute, Chef::Provider::Execute ],
         file:                   [ Chef::Resource::File, Chef::Provider::File ],
@@ -708,18 +708,21 @@ describe Chef::ProviderResolver do
 
           "rhel" => {
     #        service: [ Chef::Resource::SystemdService, Chef::Provider::Service::Systemd ],
-            package:  [ Chef::Resource::YumPackage, Chef::Provider::Package::Yum ],
+            package:  [ Chef::Resource::DnfPackage, Chef::Provider::Package::Dnf ],
             ifconfig: [ Chef::Resource::Ifconfig, Chef::Provider::Ifconfig::Redhat ],
 
             %w{amazon xcp xenserver ibm_powerkvm cloudlinux parallels} => {
               "3.1.4" => {
+                package:  [ Chef::Resource::YumPackage, Chef::Provider::Package::Yum ],
     #            service: [ Chef::Resource::RedhatService, Chef::Provider::Service::Redhat ],
               },
             },
             %w{redhat centos scientific oracle} => {
               "7.0" => {
+                package:  [ Chef::Resource::YumPackage, Chef::Provider::Package::Yum ],
               },
               "6.0" => {
+                package:  [ Chef::Resource::YumPackage, Chef::Provider::Package::Yum ],
     #            service: [ Chef::Resource::RedhatService, Chef::Provider::Service::Redhat ],
               },
             },
