@@ -30,22 +30,22 @@ describe Chef::Resource::FreebsdPackage do
   end
 
   describe "Initialization" do
-    it "should return a Chef::Resource::FreebsdPackage" do
+    it "returns a Chef::Resource::FreebsdPackage" do
       expect(@resource).to be_a_kind_of(Chef::Resource::FreebsdPackage)
     end
 
-    it "should set the resource_name to :freebsd_package" do
+    it "sets the resource_name to :freebsd_package" do
       expect(@resource.resource_name).to eql(:freebsd_package)
     end
 
-    it "should not set the provider" do
+    it "does not set the provider" do
       expect(@resource.provider).to be_nil
     end
   end
 
   describe "Assigning provider after creation" do
     describe "if ports specified as source" do
-      it "should be Freebsd::Port" do
+      it "is Freebsd::Port" do
         @resource.source("ports")
         @resource.after_created
         expect(@resource.provider).to eq(Chef::Provider::Package::Freebsd::Port)
@@ -53,7 +53,7 @@ describe Chef::Resource::FreebsdPackage do
     end
 
     describe "if freebsd_version is greater than or equal to 1000017" do
-      it "should be Freebsd::Pkgng" do
+      it "is Freebsd::Pkgng" do
         [1000017, 1000018, 1000500, 1001001, 1100000].each do |freebsd_version|
           @node.automatic_attrs[:os_version] = freebsd_version
           @resource.after_created
@@ -63,18 +63,18 @@ describe Chef::Resource::FreebsdPackage do
     end
 
     describe "if pkgng enabled" do
-      it "should be Freebsd::Pkgng" do
+      it "is Freebsd::Pkgng" do
         pkg_enabled = OpenStruct.new(:stdout => "yes\n")
-        allow(@resource).to receive(:shell_out!).with("make -V WITH_PKGNG", :env => nil).and_return(pkg_enabled)
+        allow(@resource).to receive(:shell_out!).with("make", "-V", "WITH_PKGNG", :env => nil).and_return(pkg_enabled)
         @resource.after_created
         expect(@resource.provider).to eq(Chef::Provider::Package::Freebsd::Pkgng)
       end
     end
 
     describe "if freebsd_version is less than 1000017 and pkgng not enabled" do
-      it "should be Freebsd::Pkg" do
+      it "is Freebsd::Pkg" do
         pkg_enabled = OpenStruct.new(:stdout => "\n")
-        allow(@resource).to receive(:shell_out!).with("make -V WITH_PKGNG", :env => nil).and_return(pkg_enabled)
+        allow(@resource).to receive(:shell_out!).with("make", "-V", "WITH_PKGNG", :env => nil).and_return(pkg_enabled)
 
         [1000016, 1000000, 901503, 902506, 802511].each do |freebsd_version|
           @node.automatic_attrs[:os_version] = freebsd_version
