@@ -28,23 +28,21 @@ describe Chef::Resource::Git do
     action: :sync
   )
 
-  before(:each) do
-    @git = Chef::Resource::Git.new("my awesome webapp")
-  end
+  let(:resource) { Chef::Resource::Git.new("my awesome webapp") }
 
   it "is a kind of Scm Resource" do
-    expect(@git).to be_a_kind_of(Chef::Resource::Scm)
-    expect(@git).to be_an_instance_of(Chef::Resource::Git)
+    expect(resource).to be_a_kind_of(Chef::Resource::Scm)
+    expect(resource).to be_an_instance_of(Chef::Resource::Git)
   end
 
   it "uses aliases revision as branch" do
-    @git.branch "HEAD"
-    expect(@git.revision).to eql("HEAD")
+    resource.branch "HEAD"
+    expect(resource.revision).to eql("HEAD")
   end
 
   it "aliases revision as reference" do
-    @git.reference "v1.0 tag"
-    expect(@git.revision).to eql("v1.0 tag")
+    resource.reference "v1.0 tag"
+    expect(resource.revision).to eql("v1.0 tag")
   end
 
 end
