@@ -20,21 +20,18 @@ require "spec_helper"
 
 describe Chef::Resource::Python do
 
-  before(:each) do
-    @resource = Chef::Resource::Python.new("fakey_fakerton")
+  let(:resource) { Chef::Resource::Python.new("fakey_fakerton") }
+
+  it "creates a new Chef::Resource::Python" do
+    expect(resource).to be_a_kind_of(Chef::Resource)
+    expect(resource).to be_a_kind_of(Chef::Resource::Python)
   end
 
-  it "should create a new Chef::Resource::Python" do
-    expect(@resource).to be_a_kind_of(Chef::Resource)
-    expect(@resource).to be_a_kind_of(Chef::Resource::Python)
+  it "has a resource name of :python" do
+    expect(resource.resource_name).to eql(:python)
   end
 
-  it "should have a resource name of :python" do
-    expect(@resource.resource_name).to eql(:python)
+  it "has an interpreter of python" do
+    expect(resource.interpreter).to eql("python")
   end
-
-  it "should have an interpreter of python" do
-    expect(@resource.interpreter).to eql("python")
-  end
-
 end
