@@ -28,44 +28,46 @@ describe Chef::Resource::Subversion do
     action: :install
   )
 
-  before do
-    @svn = Chef::Resource::Subversion.new("ohai, svn project!")
-  end
+  let(:resource) { Chef::Resource::Subversion.new("ohai, svn project!") }
 
   it "is a subclass of Resource::Scm" do
-    expect(@svn).to be_an_instance_of(Chef::Resource::Subversion)
-    expect(@svn).to be_a_kind_of(Chef::Resource::Scm)
+    expect(resource).to be_an_instance_of(Chef::Resource::Subversion)
+    expect(resource).to be_a_kind_of(Chef::Resource::Scm)
+  end
+
+  it "set destination property to the name_property" do
+    expect(resource.destination).to eq("ohai, svn project!")
   end
 
   it "allows the force_export action" do
-    expect(@svn.allowed_actions).to include(:force_export)
+    expect(resource.allowed_actions).to include(:force_export)
   end
 
   it "sets svn info arguments to --no-auth-cache by default" do
-    expect(@svn.svn_info_args).to eq("--no-auth-cache")
+    expect(resource.svn_info_args).to eq("--no-auth-cache")
   end
 
   it "resets svn info arguments to nil when given false in the setter" do
-    @svn.svn_info_args(false)
-    expect(@svn.svn_info_args).to be_nil
+    resource.svn_info_args(false)
+    expect(resource.svn_info_args).to be_nil
   end
 
   it "sets svn arguments to --no-auth-cache by default" do
-    expect(@svn.svn_arguments).to eq("--no-auth-cache")
+    expect(resource.svn_arguments).to eq("--no-auth-cache")
   end
 
   it "sets svn binary to nil by default" do
-    expect(@svn.svn_binary).to be_nil
+    expect(resource.svn_binary).to be_nil
   end
 
   it "resets svn arguments to nil when given false in the setter" do
-    @svn.svn_arguments(false)
-    expect(@svn.svn_arguments).to be_nil
+    resource.svn_arguments(false)
+    expect(resource.svn_arguments).to be_nil
   end
 
   it "hides password from custom exception message" do
-    @svn.svn_password "l33th4x0rpa$$w0rd"
-    e = @svn.customize_exception(Chef::Exceptions::Exec.new "Exception with password #{@svn.svn_password}")
-    expect(e.message.include?(@svn.svn_password)).to be_falsey
+    resource.svn_password "l33th4x0rpa$$w0rd"
+    e = resource.customize_exception(Chef::Exceptions::Exec.new "Exception with password #{resource.svn_password}")
+    expect(e.message.include?(resource.svn_password)).to be_falsey
   end
 end
