@@ -1,6 +1,6 @@
 #
 # Author:: Tyler Ball (<tball@chef.io>)
-# Copyright:: Copyright 2014-2016, Chef Software, Inc.
+# Copyright:: Copyright 2014-2017, Chef Software Inc.
 # License:: Apache License, Version 2.0
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -27,6 +27,7 @@ describe Chef::ResourceCollection::ResourceSet do
   let(:zen_master) { Chef::Resource::ZenMaster.new(zen_master_name) }
   let(:zen_master2) { Chef::Resource::ZenMaster.new(zen_master2_name) }
   let(:zen_follower) { Chef::Resource::ZenFollower.new(zen_follower_name) }
+  let(:zen_array) { Chef::Resource::ZenMaster.new( [ zen_master_name, zen_master2_name ]) }
 
   describe "initialize" do
     it "should return a Chef::ResourceSet" do
@@ -113,13 +114,27 @@ describe Chef::ResourceCollection::ResourceSet do
     end
 
     it "should find resources by strings of zen_master[a,b]" do
+      Chef::Config[:treat_deprecation_warnings_as_errors] = false
       collection.insert_as(zen_master)
       collection.insert_as(zen_master2)
       check_by_names(collection.find("zen_master[#{zen_master_name},#{zen_master2_name}]"),
                      zen_master_name, zen_master2_name)
     end
 
+    it "should find array names" do
+      collection.insert_as(zen_array)
+      expect(collection.find("zen_master[#{zen_master_name}, #{zen_master2_name}]")).to eql(zen_array)
+    end
+
+    it "should favor array names over multi resource syntax" do
+      collection.insert_as(zen_master)
+      collection.insert_as(zen_master2)
+      collection.insert_as(zen_array)
+      expect(collection.find("zen_master[#{zen_master_name}, #{zen_master2_name}]")).to eql(zen_array)
+    end
+
     it "should find resources by strings of zen_master[a,b] with custom names" do
+      Chef::Config[:treat_deprecation_warnings_as_errors] = false
       collection.insert_as(zen_master, :zzz, "name1")
       collection.insert_as(zen_master2, :zzz, "name2")
       check_by_names(collection.find("zzz[name1,name2]"),
@@ -134,6 +149,7 @@ describe Chef::ResourceCollection::ResourceSet do
     end
 
     it "should find resources of multiple types by strings of zen_master[a] with custom names" do
+      Chef::Config[:treat_deprecation_warnings_as_errors] = false
       collection.insert_as(zen_master, :zzz, "name1")
       collection.insert_as(zen_master2, :zzz, "name2")
       collection.insert_as(zen_follower, :yyy, "name3")
@@ -162,6 +178,35 @@ describe Chef::ResourceCollection::ResourceSet do
     it "raises an error when attempting to find a resource that does not exist" do
       expect { collection.find("script[nonesuch]") }.to raise_error(Chef::Exceptions::ResourceNotFound)
     end
+
+    context "nameless resources" do
+      let(:zen_master_name) { "" }
+
+      it "looks up nameless resources with find without brackets" do
+        collection.insert_as(zen_master)
+        expect(collection.find("zen_master")).to eq(zen_master)
+      end
+
+      it "looks up nameless resources with find with empty brackets" do
+        collection.insert_as(zen_master)
+        expect(collection.find("zen_master[]")).to eq(zen_master)
+      end
+
+      it "looks up nameless resources with find with empty string hash key" do
+        collection.insert_as(zen_master)
+        expect(collection.find(zen_master: "")).to eq(zen_master)
+      end
+
+      it "looks up nameless resources with lookup with empty brackets" do
+        collection.insert_as(zen_master)
+        expect(collection.lookup("zen_master[]")).to eq(zen_master)
+      end
+
+      it "looks up nameless resources with lookup with the resource" do
+        collection.insert_as(zen_master)
+        expect(collection.lookup(zen_master)).to eq(zen_master)
+      end
+    end
   end
 
   describe "validate_lookup_spec!" do
