@@ -1,7 +1,7 @@
 #
 # Author:: Adam Jacob (<adam@chef.io>)
 # Author:: Christopher Walters (<cw@chef.io>)
-# Copyright:: Copyright 2008-2016, Chef Software Inc.
+# Copyright:: Copyright 2008-2017, Chef Software Inc.
 # License:: Apache License, Version 2.0
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -219,6 +219,7 @@ describe Chef::ResourceCollection do
     end
 
     it "should find resources by strings of zen_master[a,b]" do
+      Chef::Config[:treat_deprecation_warnings_as_errors] = false
       load_up_resources
       results = rc.resources("zen_master[monkey,dog]")
       expect(results.length).to eql(2)
@@ -291,10 +292,10 @@ describe Chef::ResourceCollection do
       expect(rc.respond_to?(:from_json)).to eq(false)
     end
 
-    it "should convert from json using the CHEF::JSONCompat library" do
+    it "should convert from json using the Chef::JSONCompat library" do
       rc << resource
       json = Chef::JSONCompat.to_json(rc)
-      s_rc = Chef::JSONCompat.from_json(json)
+      s_rc = Chef::ResourceCollection.from_json(json)
       expect(s_rc).to be_a_kind_of(Chef::ResourceCollection)
       expect(s_rc[0].name).to eql(resource.name)
     end
