@@ -163,9 +163,7 @@ describe Chef::RunContext::CookbookCompiler do
     describe "event dispatch" do
       let(:recipe) { "dependency1::default" }
       let(:recipe_path) do
-        File.expand_path("../../../data/run_context/cookbooks/dependency1/recipes/default.rb", __FILE__).tap do |path|
-          path.gsub!(File::SEPARATOR, File::ALT_SEPARATOR) if File::ALT_SEPARATOR
-        end
+        File.expand_path("../../../data/run_context/cookbooks/dependency1/recipes/default.rb", __FILE__)
       end
       before do
         node.run_list(recipe)
